<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ccap/response"
	xmlns:ccap-ext="http://www.doj.state.wi.us/dles/cib/ccap/response/extension"
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"
    xmlns:xalan="http://xml.apache.org/xslt"
    exclude-result-prefixes="xsl xsi doj j xalan"
>
	<xsl:import href="../common.xsl"/>
	<xsl:import href="../util.xsl"/>
  <xsl:import href="caselist.xsl"/>
  <xsl:import href="caseDetail.xsl"/>
  <xsl:param name="from"/>
  <xsl:param name="executionUrl">/</xsl:param>
  <xsl:param name="imageBase">
    <xsl:text>../../images/</xsl:text>
  </xsl:param>
  <xsl:param name="readOnly"/>
	<xsl:output method="html"
                version="4.01"
                encoding="UTF-8" 
                omit-xml-declaration="yes"
                doctype-public="-//W3C//DTD HTML 4.01//EN"
                doctype-system="http://www.w3.org/TR/html4/strict.dtd"
                indent="yes"
                media-type="text/html"
                xalan:indent-amount="2"/>

	<xsl:template match="/">
    <xsl:choose>
      <xsl:when test="$from='ebc'">
        <xsl:call-template name="html_main"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="html_head_extension"/>
        <xsl:call-template name="html_body"/>
      </xsl:otherwise>
    </xsl:choose>
	</xsl:template>

	<xsl:template name="html_title">TIME - CCAP Responses</xsl:template>

	<xsl:template name="html_head_extension">
		<style type="text/css">
		  
		  p, div{
		    padding:0; 
		    margin:0;
		  }
		  
			#dataserviceimage {
				float: left;
			}
		
			img.driverimage {
				float: right;
				height: 150px;
				width: 125px;
			}
			
			img.pagerefimage {
				float: left;
				border: none;
				padding-right: 25px;
				padding-left: 15px;
			}
			
			.newsection {
				margin-top: 15px;
			}
			
			.filetype {
				float: none;  /* Override the float setting inherited from external stylesheets */
			}
			
			.caveat {
				color: teal;  /* Override the color inherited from external stylesheets */
			}
			
			.licensetypetitle {
				text-transform: none;  /* Override inherited uppercase setting */
			}
     
      .blueRegular {
        color: blue;
      }
     
      .redRegular {
        color: red;
      }

      .redBold {
        color: red;
        font-weight: bold;
      }
      
      .blackBoldSmall{
        color: black; 
        font-weight: bold; 
        font-size: small; 
      }
      
      .blackBoldSmaller{
        color: black; 
        font-weight: bold; 
        font-size: small; 
      }
      .subjecttitle {
        text-transform: none;  /* Override the text-transform setting inherited from external stylesheets */
      }
      
      .tealRegular{
        color: teal;
      }
      
      .tealSmall{
        color: teal;
        font-size:small;
      }

      .tealBold {
        color: teal;
        font-weight: bold;
      }
      
      .tableName {
        padding-right: 20px;
        white-space: nowrap;
      }
      
      .paddingZero{
        padding:0;
        margin:0;
      }
      .tableValue {
        padding-right: 20px;
        text-transform: capitalize;
      }
      
      .width70{
        width:70%; 
      }
      .width60{
        width:60%; 
      }
      .width15{
        width:15%; 
      }
      .width80{
        width:80%; 
      }
      .width20{
        width:20%; 
      }
      .width25{
        width:25%; 
      }
      .width10{
        width:10%; 
      }
      
      .paddingLeft2{
        padding:0;
        margin: 0 0 0 2em;
      }
      .paddingLeft4{
        padding:0;
        margin:0 0 0 4em;
      }
      .paddingLeft6{
        padding:0;
        margin:0 0 0 6em;
      }
      .floatRight{
        float:right;
      }
		</style>
	</xsl:template>

	<xsl:template name="html_body">
	  <div style="width:100%"> 
	  <xsl:element name="img">
	    <xsl:attribute name="id">dataserviceimage</xsl:attribute>
	    <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'CCAP.gif')"/></xsl:attribute>
	    <xsl:attribute name="alt">Wisconsin CCAP</xsl:attribute>
	  </xsl:element>
	  <!-- 
	  <h2 class="filetype">
	    <xsl:text>WI CCAP</xsl:text>
	  </h2>
	   -->
 	  <!-- Not all of the following will be applicable on a single response -->
	    <xsl:apply-templates select="//doj:Result/doj:ResultText"/>
	    <xsl:apply-templates select="//doj:Result/doj:CCAPCaseResponse"/>
	  <xsl:apply-templates select="//doj:Result/doj:CCAPCaseDetailResponse"/>
	  </div>	    
	</xsl:template>
  
  <xsl:template match="doj:Result/doj:ResultText">
    <h3 class="tealRegular"><xsl:value-of select="."/></h3>
  </xsl:template>
  
  <xsl:template name="EyeColor_to_text">
    <xsl:param name="EyeColorCode"/>
    <xsl:choose>
      <xsl:when test="$EyeColorCode='BLK'">
        <xsl:text>Black</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='BLU'">
        <xsl:text>Blue</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='BRO'">
        <xsl:text>Brown</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='DIC'">
        <xsl:text>Dichromatic</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='GRN'">
        <xsl:text>Green</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='GRY'">
        <xsl:text>Gray</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='HAZ'">
        <xsl:text>Hazel</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='UNK'">
        <xsl:text>Unknown</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$EyeColorCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="FormatDL">
    <xsl:param name="DL"/>
    <xsl:value-of select="substring($DL, 1, 4)"/>
    <xsl:text>-</xsl:text>
    <xsl:value-of select="substring($DL, 5, 4)"/>
    <xsl:text>-</xsl:text>
    <xsl:value-of select="substring($DL, 9, 4)"/>
    <xsl:text>-</xsl:text>
    <xsl:value-of select="substring($DL, 13)"/>
  </xsl:template>
  
  <xsl:template name="HairColor_to_text">
    <xsl:param name="HairColorCode"/>
    <xsl:choose>
      <xsl:when test="$HairColorCode='BAL'">
        <xsl:text>Bald</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='BLD'">
        <xsl:text>Blond</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='BLK'">
        <xsl:text>Black</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='BRO'">
        <xsl:text>Brown</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='GRY'">
        <xsl:text>Gray</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='RED'">
        <xsl:text>Red/Auburn</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='SDY'">
        <xsl:text>Sandy</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='UNK'">
        <xsl:text>Unknown</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='WHI'">
        <xsl:text>White</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$HairColorCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="Race_to_text">
    <xsl:param name="RaceCode"/>
    <xsl:choose>
      <xsl:when test="$RaceCode='A'">
        <xsl:text>Asian</xsl:text>
      </xsl:when>
      <xsl:when test="$RaceCode='B'">
        <xsl:text>Black</xsl:text>
      </xsl:when>
      <xsl:when test="$RaceCode='H'">
        <xsl:text>Hispanic</xsl:text>
      </xsl:when>
      <xsl:when test="$RaceCode='I'">
        <xsl:text>Indian</xsl:text>
      </xsl:when>
      <xsl:when test="$RaceCode='W'">
        <xsl:text>White</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$RaceCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="resolveSexCode">
    <xsl:param name="sexCode"/>
    <xsl:choose>
      <xsl:when test="$sexCode='F'">
        <xsl:text>Female</xsl:text>
      </xsl:when>
      <xsl:when test="$sexCode='M'">
        <xsl:text>Male</xsl:text>
      </xsl:when>
      <xsl:when test="$sexCode='U'">
        <xsl:text>Unknown</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$sexCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="StatusCode_to_text">
    <xsl:param name="StatusCode"/>
    <xsl:choose>
      <xsl:when test="$StatusCode='BLANKS'">
        <xsl:text>Valid</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='CAN'">
        <xsl:text>Cancelled</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='DIS'">
        <xsl:text>Disqualified</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='EXP'">
        <xsl:text>Expired</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='OTH'">
        <xsl:text>Other</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='REV'">
        <xsl:text>Revoked</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='SUR'">
        <xsl:text>Surrendered</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='SUS'">
        <xsl:text>Suspended</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='VAL'">
        <xsl:text>Valid</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='MOS'">
        <xsl:text>Moved Out Of State</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$StatusCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="YYYY-MM-DD_to_MM-DD-YYYY">
    <xsl:param name="YYYY-MM-DD"/>
    <xsl:value-of select="substring($YYYY-MM-DD, 6, 2)"/>
    <xsl:text>/</xsl:text>
    <xsl:value-of select="substring($YYYY-MM-DD, 9, 2)"/>
    <xsl:text>/</xsl:text>
    <xsl:value-of select="substring($YYYY-MM-DD, 1, 4)"/>
  </xsl:template>
  
  <xsl:template name="replaceCharsInString">
    <xsl:param name="stringIn"/>
    <xsl:param name="charsIn"/>
    <xsl:param name="charsOut"/>
    <xsl:choose>
      <xsl:when test="contains($stringIn,$charsIn)">
        <xsl:value-of select="concat(substring-before($stringIn,$charsIn),$charsOut)"/>
        <xsl:call-template name="replaceCharsInString">
          <xsl:with-param name="stringIn" select="substring-after($stringIn,$charsIn)"/>
          <xsl:with-param name="charsIn" select="$charsIn"/>
          <xsl:with-param name="charsOut" select="$charsOut"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$stringIn"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
   <xsl:template match="j:PersonName" mode="PrimaryFirstMiddleLastSuffix">
	  <xsl:for-each select=".">
	  	<xsl:if test="not(@j:commentText)">
	  		<xsl:apply-templates select="." mode="FirstMiddleLastSuffix"/>
	  	</xsl:if>
	  </xsl:for-each>
	</xsl:template>
	
	<xsl:template match="j:PersonName" mode="RecordedFirstMiddleLastSuffix">
  	  <xsl:for-each select=".">
	  	<xsl:if test="@j:commentText = 'recorded'">
	      <xsl:text>Recorded Name: </xsl:text>
	  	  <xsl:apply-templates select="." mode="FirstMiddleLastSuffix"/>
	  	</xsl:if>
	  </xsl:for-each>
	</xsl:template>
	
  <xsl:template name="FormerFirstMiddleLastSuffix">
	  <xsl:for-each select="j:PersonName">
	  	<xsl:if test="not(./@j:commentText)">
	  		<xsl:apply-templates select="." mode="FirstMiddleLastSuffix"/>
	  	</xsl:if>
	  </xsl:for-each>
  </xsl:template>
  
  
</xsl:transform>