<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/internal/ccw/response"
	xmlns:ccw-ext="http://www.doj.state.wi.us/dles/cib/internal/ccw/response/extension"
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2" 
    exclude-result-prefixes="xsl xsi doj j"
>
	<xsl:import href="../common.xsl"/>
	<xsl:import href="../util.xsl"/>
  <xsl:param name="executionUrl">/</xsl:param>
  <xsl:param name="imageBase">
    <xsl:text>../../images/</xsl:text>
  </xsl:param>
	<xsl:template match="/">
    <xsl:choose>
      <xsl:when test="$from='ebc'">
        <xsl:call-template name="html_main"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="html_head_extension"/>
        <xsl:call-template name="html_body"/>
      </xsl:otherwise>
    </xsl:choose>
	</xsl:template>

	<xsl:template name="html_title">TIME - CCW Responses</xsl:template>

	<xsl:template name="html_head_extension">
		<style type="text/css">
		  
		  p, div{
		    padding:0; 
		    margin:0;
		  }
		  
			#dataserviceimage {
				float: left;
				padding-left: 2em; 
			}
		
			img.driverimage {
				float: right;
				height: 150px;
				width: 125px;
			}
			
			img.pagerefimage {
				float: left;
				border: none;
				padding-right: 25px;
				padding-left: 15px;
			}
			
			.newsection {
				margin-top: 15px;
			}
			
			.filetype {
				float: none;  /* Override the float setting inherited from external stylesheets */
			}
			
			.caveat {
				color: teal;  /* Override the color inherited from external stylesheets */
			}
			
			.licensetypetitle {
				text-transform: none;  /* Override inherited uppercase setting */
			}
     
      .blueRegular {
        color: blue;
      }
     
      .redRegular {
        color: red;
      }

      .redBold {
        color: red;
        font-weight: bold;
      }
      
      .blackBoldSmall{
        color: black; 
        font-weight: bold; 
        font-size: small; 
      }
      
      .blackBoldSmaller{
        color: black; 
        font-weight: bold; 
        font-size: small; 
      }
      .subjecttitle {
        text-transform: none;  /* Override the text-transform setting inherited from external stylesheets */
      }
      
      .tealRegular{
        color: teal;
      }
      
      .tealSmall{
        color: teal;
        font-size:small;
      }

      .tealBold {
        color: teal;
        font-weight: bold;
      }
      
      .tableName {
        padding-right: 20px;
        white-space: nowrap;
      }
      
      .paddingZero{
        padding:0;
        margin:0;
      }
      .tableValue {
        padding-right: 20px;
        text-transform: capitalize;
      }
      
      .width70{
        width:70%; 
      }
      .width60{
        width:60%; 
      }
      .width15{
        width:15%; 
      }
      .width80{
        width:80%; 
      }
      .width20{
        width:20%; 
      }
      .width25{
        width:25%; 
      }
      .width10{
        width:10%; 
      }
      
      .paddingLeft1{
        padding-left:1em;
      }
      .paddingLeft2{
        padding:0;
        margin: 0 0 0 2em;
      }
      .paddingLeft4{
        padding:0;
        margin:0 0 0 4em;
      }
      .paddingLeft6{
        padding:0;
        margin:0 0 0 6em;
      }
      .floatRight{
        float:right;
      }
		</style>
	</xsl:template>

	<xsl:template name="html_body">
	  <div>
  	  <xsl:element name="img">
  	    <xsl:attribute name="id">dataserviceimage</xsl:attribute>
  	    <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'ccwGun.jpg')"/></xsl:attribute>
  	    <xsl:attribute name="alt">Wisconsin CCW</xsl:attribute>
  	  </xsl:element>
	    &#160; 
	    <h4 style="vertical-align:bottom;display:inline-block;">WI CCW APPLICATION</h4>
	  </div>
 	  <!-- Not all of the following will be applicable on a single response -->
	  <xsl:apply-templates select="//doj:Result/doj:CCWResponse"/>
	</xsl:template>
  
  <xsl:template match="doj:CCWResponse">
    <hr style="clear:both"/>
    <xsl:apply-templates select="doj:ApplicantInformation"/>
    
    
  </xsl:template>
  
  <xsl:template match="doj:ApplicantInformation">
    
    <xsl:apply-templates select="j:PersonAssignedIDDetails/j:PersonOtherID"></xsl:apply-templates>
    <div class="newsection tealRegular">
      <table>
        <tr><td class="paddingLeft1">
        <xsl:apply-templates select="j:PersonName" mode="FirstMiddleLastSuffix"></xsl:apply-templates><br/>
        </td><td/>
        </tr>
        <tr><td class="paddingLeft1">
        <xsl:value-of select="j:PersonPhysicalDetails/j:PersonSexText"/><xsl:text>&#160;&#160;&#160;</xsl:text>
        <xsl:value-of select="j:PersonPhysicalDetails/j:PersonRaceText"/><br/>
        </td><td/>
        </tr>
        <tr><td class="paddingLeft1">
        <xsl:apply-templates select="j:PersonBirthDate" mode="FormatFullDateAsMMDDYYYY"></xsl:apply-templates>
        </td><td/>
        </tr>
        <tr>
          <td class="paddingLeft1">
            <xsl:if test="j:PersonPhysicalDetails/j:PersonHeightMeasure">
                <xsl:value-of select="substring(j:PersonPhysicalDetails/j:PersonHeightMeasure, 1, 1)"/><xsl:text>'</xsl:text><xsl:value-of select="substring(j:PersonPhysicalDetails/j:PersonHeightMeasure, 2)"/><xsl:text>"</xsl:text>
            </xsl:if>
          </td>
          <td class="paddingLeft1">
            <xsl:if test="j:PersonPhysicalDetails/j:PersonEyeColorText">
              <xsl:value-of select="j:PersonPhysicalDetails/j:PersonEyeColorText"/>&#160;Eyes
            </xsl:if>
          </td>
        </tr>
        <xsl:call-template name="ConditionalRow">
          <xsl:with-param name="label1">Drivers Lic/ID:</xsl:with-param>
          <xsl:with-param name="value1">
            <xsl:value-of select="j:PersonAssignedIDDetails/j:DriverAuthorizationID.Detailed/j:ID"/>
          </xsl:with-param>
          <xsl:with-param name="label_class_name1">paddingZero</xsl:with-param>
        </xsl:call-template>
      </table>
    </div>
    
    <xsl:if test="j:PersonAlias">
      <div class="newsection tealRegular">
        <span class="blackBoldSmall">ALIAS NAME</span><br/>
        <xsl:for-each select="j:PersonAlias">
          <xsl:apply-templates select="j:PersonName" mode="FirstMiddleLastSuffix"/> <br/>       
        </xsl:for-each>
      </div>
    </xsl:if>
    
    <div class="newsection tealRegular">
      <span class="blackBoldSmall">APPLICATION INFO</span><br/>
      <table width="20%">
        <xsl:call-template name="ConditionalRow">
          <xsl:with-param name="label1">Application Id:</xsl:with-param>
          <xsl:with-param name="value1">
            <xsl:value-of select="parent::doj:CCWResponse/doj:RecordIdentifiers/ccw-ext:ApplicationID"/>
          </xsl:with-param>
        </xsl:call-template>
      </table>
    </div>
    
    <div class="newsection tealRegular">
      <span class="blackBoldSmall">YOUR REQUEST</span><br/>
      <table width="50%">
        <xsl:call-template name="ConditionalRow">
          <xsl:with-param name="label1">Initiator Identifier:</xsl:with-param>
          <xsl:with-param name="value1">
            <xsl:value-of select="ancestor::doj:CCWResponseDocument/attribute::doj-ext:initiatorID"/>
          </xsl:with-param>
          <xsl:with-param name="label2">Response Identifier:</xsl:with-param>
          <xsl:with-param name="value2">
            <xsl:value-of select="ancestor::doj:CCWResponseDocument/attribute::doj-ext:responseID"/>
          </xsl:with-param>
        </xsl:call-template>
        <xsl:call-template name="ConditionalRow">
          <xsl:with-param name="label1">Date&amp;Time:</xsl:with-param>
          <xsl:with-param name="value1">
            <xsl:if test="ancestor::doj:Result/preceding-sibling::doj:Header/doj-ext:SubmissionRequestorDetails/doj-ext:SubmissionReceivedDate">
            <xsl:apply-templates 
              select="ancestor::doj:Result/preceding-sibling::doj:Header/doj-ext:SubmissionRequestorDetails/doj-ext:SubmissionReceivedDate"
              mode="FormatFullDateAsMMDDYYYY"
              />&amp; 
            </xsl:if>
            <xsl:value-of select="substring(ancestor::doj:Result/preceding-sibling::doj:Header/doj-ext:SubmissionRequestorDetails/doj-ext:SubmissionReceivedTime,0,6)"/>
          </xsl:with-param>
        </xsl:call-template>
      </table>
      
    </div>
    
  </xsl:template>
  
  <xsl:template match="j:PersonAssignedIDDetails/j:PersonOtherID">
    <div style="align:right;">
      <xsl:element name="img">
        <xsl:attribute name="class">pagerefimage</xsl:attribute>
        <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'RecordDetails.jpg')"/></xsl:attribute>
        <xsl:attribute name="alt">Record Details</xsl:attribute>
      </xsl:element>
      <table>
        <tr>
          <td class="blackBoldSmall">STATUS:</td>
          <td class="tealRegular">
            <xsl:value-of select="j:IDStatus/j:StatusText"/>
          </td>
        </tr>
        <tr>
          <td class="blackBoldSmall">TYPE:</td>
          <td class="tealRegular">
            <xsl:value-of select="j:IDTypeText"/>
          </td>
        </tr>
        <tr>
          <td class="blackBoldSmall">ID:</td>
          <td class="tealRegular">
            <xsl:value-of select="j:ID[@j:commentText='DOJ']"/>
          </td>
        </tr>
        <tr>
          <td class="blackBoldSmall">ISSUED DATE:</td>
          <td class="tealRegular">
            <xsl:apply-templates select="j:IDEffectiveDate" mode="FormatFullDateAsMMDDYYYY"/>
          </td>
        </tr>
        <tr>
          <td class="blackBoldSmall">EXPIRATION DATE:</td>
          <td class="tealRegular">
            <xsl:apply-templates select="j:IDExpirationDate" mode="FormatFullDateAsMMDDYYYY"/>
          </td>
        </tr>
      </table>
    </div>
    
  </xsl:template>
  
  
  <xsl:template name="FormatDL">
    <xsl:param name="DL"/>
    <xsl:value-of select="substring($DL, 1, 4)"/>
    <xsl:text>-</xsl:text>
    <xsl:value-of select="substring($DL, 5, 4)"/>
    <xsl:text>-</xsl:text>
    <xsl:value-of select="substring($DL, 9, 4)"/>
    <xsl:text>-</xsl:text>
    <xsl:value-of select="substring($DL, 13)"/>
  </xsl:template>
  
  <xsl:template name="HairColor_to_text">
    <xsl:param name="HairColorCode"/>
    <xsl:choose>
      <xsl:when test="$HairColorCode='BAL'">
        <xsl:text>Bald</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='BLD'">
        <xsl:text>Blond</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='BLK'">
        <xsl:text>Black</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='BRO'">
        <xsl:text>Brown</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='GRY'">
        <xsl:text>Gray</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='RED'">
        <xsl:text>Red/Auburn</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='SDY'">
        <xsl:text>Sandy</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='UNK'">
        <xsl:text>Unknown</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='WHI'">
        <xsl:text>White</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$HairColorCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="YYYY-MM-DD_to_MM-DD-YYYY">
    <xsl:param name="YYYY-MM-DD"/>
    <xsl:value-of select="substring($YYYY-MM-DD, 6, 2)"/>
    <xsl:text>/</xsl:text>
    <xsl:value-of select="substring($YYYY-MM-DD, 9, 2)"/>
    <xsl:text>/</xsl:text>
    <xsl:value-of select="substring($YYYY-MM-DD, 1, 4)"/>
  </xsl:template>
  
  <xsl:template name="replaceCharsInString">
    <xsl:param name="stringIn"/>
    <xsl:param name="charsIn"/>
    <xsl:param name="charsOut"/>
    <xsl:choose>
      <xsl:when test="contains($stringIn,$charsIn)">
        <xsl:value-of select="concat(substring-before($stringIn,$charsIn),$charsOut)"/>
        <xsl:call-template name="replaceCharsInString">
          <xsl:with-param name="stringIn" select="substring-after($stringIn,$charsIn)"/>
          <xsl:with-param name="charsIn" select="$charsIn"/>
          <xsl:with-param name="charsOut" select="$charsOut"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$stringIn"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
</xsl:transform>