<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/dmv/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:xalan="http://xml.apache.org/xslt"
    exclude-result-prefixes="xsl xsi cib-ext doj doj-ext j">
    
    <!--  DMV - NO FILE TYPE RECORD -->
	<xsl:import href="../common.xsl"/>
	<xsl:import href="../util.xsl"/>
  <xsl:param name="from"/>
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:DMVResponseDocument">
    <xsl:choose>
      <xsl:when test="$from='ebc'">
        <xsl:call-template name="html_main"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="html_head_extension"/>
        <xsl:call-template name="html_body"/>
      </xsl:otherwise>
    </xsl:choose>
	</xsl:template>
	
	<xsl:template name="html_body">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName"> 
				<xsl:apply-templates select="doj:Result/@doj-ext:resultStatusText"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="doj:Result">
		<xsl:apply-templates select="doj:ResultText"/>
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:apply-templates select="@doj-ext:resultStatusText"/>
	</xsl:template>
	
	<xsl:template match="doj:ResultText">
		<xsl:apply-templates select="." mode="header"/>
		<p>
			<xsl:value-of select="."/>
		</p>
	</xsl:template>
	
	<!-- File Type Header -->
	<xsl:template match="*" mode="header"> 
		<!-- Data Service Logo -->	
		<xsl:call-template name="dotLogo"/>
		<!-- File Type Header Section -->
		<table>
			<tr>
				<td class="width90percent">
					<table>
						<tr><td>
							<span class="filetype">
								<xsl:text>DMV</xsl:text>
								<xsl:apply-templates select="../@doj-ext:resultStatusText"/>
								<xsl:text>Response</xsl:text>
							</span>
						</td></tr>
					</table>
				</td>
			</tr>
		</table>
		<!-- Horizontal Line -->
		<hr/>
	</xsl:template>
	
	<xsl:template match="@doj-ext:resultStatusText"> 
		<xsl:choose>
			<xsl:when test=".='Normal'">
				<!--  normal response with no hits -->
				<xsl:text>&#32;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<!-- For advisory, queued, reject or error (with no legacy) responses -->
				<xsl:text>&#32;</xsl:text>
				<xsl:value-of select="."/>
				<xsl:text>&#32;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<xsl:template name="dotLogo">
		<table width="100%" >
			<tr>
				<td align="right">
					<img src="../../images/DOT.gif" alt="Wisconsin Department of Transportation Logo"/>
				</td>
			</tr>
		</table>
	</xsl:template>
	
</xsl:transform>