<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
	xmlns:dnr-ext="http://www.doj.state.wi.us/dles/cib/dnr/response/extension" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/dnr/response" 
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2" 
	xmlns:xalan="http://xml.apache.org/xslt" 
	exclude-result-prefixes="xsl xsi dnr-ext doj j xalan">
	
	<xsl:import href="../common.xsl" />
	<xsl:import href="dnr_common.xsl" />
	<xsl:import href="../util.xsl" />
	
	<xsl:param name="from" />
	<xsl:param name="responseId">
		<xsl:value-of select="doj:DNRResponseDocument/@doj-ext:responseID" />
	</xsl:param>
	
	<xsl:output method="html" 
				version="4.01" 
				encoding="UTF-8" 
				omit-xml-declaration="yes" 
				doctype-public="-//W3C//DTD HTML 4.01//EN" 
				doctype-system="http://www.w3.org/TR/html4/strict.dtd" 
				indent="yes" 
				media-type="text/html" 
				xalan:indent-amount="2" />
	
	
	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="$from='ebc'">
				<xsl:call-template name="html_main" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="html_head_extension" />
				<xsl:call-template name="html_body" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<xsl:template name="html_title">
		TIME - DNR Citation Response
	</xsl:template>
	
	
	<xsl:template name="html_body">
		<xsl:call-template name="dnrLogo" />
		<xsl:call-template name="customerLogo" />
		<hr />
		<!-- Not all of the following will be applicable on a single response -->
		<xsl:apply-templates select="doj:DNRResponseDocument/doj:Result/doj:ResultText" />
		<!-- Hit response -->
		<xsl:apply-templates select="doj:DNRResponseDocument/doj:Result/doj:CitationResponse/doj:InquiryResult/dnr-ext:Citation" />
	</xsl:template>
	
	
	<xsl:template name="customerLogo">
		<h1>
			<img src="../../images/citation.jpg" alt="DNR Citation" />
			<xsl:text>&#160;&#160;</xsl:text>
			<xsl:text>DNR Citation Record</xsl:text>
		</h1>
	</xsl:template>
	
	
	<xsl:template match="doj:ResultText | dnr-ext:ResponseText">
		<div class="resulttext">
			<h1 class="filetype">
				<xsl:value-of select="." />
			</h1>
		</div>
	</xsl:template>
	
	
	<xsl:template match="dnr-ext:Citation">
		<table class="detailvalue" cellspacing="0">
			<tr>
				<td colspan="2">
					<span class="propertyinfo">
						<xsl:value-of select="j:CitationSubject/j:PersonName/j:PersonFullName" />
					</span>
				</td>
			</tr>
			<xsl:if test="j:CitationSubject/j:PersonBirthDate">
				<tr>
					<td colspan="2">
							<xsl:text>DOB:&#160;</xsl:text>
							<xsl:apply-templates select="j:CitationSubject/j:PersonBirthDate" mode="FormatFullDateAsMMDDYYYY" />
					</td>
				</tr>
			</xsl:if>
			<xsl:if test="j:CitationSubject/j:PersonPhysicalDetails/j:PersonSexText
							| j:CitationSubject/j:PersonPhysicalDetails/j:PersonRaceText">
				<tr>
					<td colspan="2">
							<xsl:value-of select="j:CitationSubject/j:PersonPhysicalDetails/j:PersonSexText" />
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="j:CitationSubject/j:PersonPhysicalDetails/j:PersonRaceText" />
					</td>
				</tr>
			</xsl:if>
			<xsl:if test="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationStreet/j:StreetFullText">
				<tr>
					<td colspan="2">
						<xsl:value-of select="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationStreet/j:StreetFullText" />
					</td>
				</tr>
			</xsl:if>
			<xsl:if test="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationCityName
					| j:CitationSubject/j:Residence/j:LocationAddress/j:LocationStateName
					| j:CitationSubject/j:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID
					| j:CitationSubject/j:Residence/j:LocationAddress/j:LocationCountyName">
				<tr>
					<td colspan="2">
						<xsl:if test="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationCityName">
							<xsl:value-of select="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationCityName" />
							<xsl:text>,&#160;</xsl:text>
						</xsl:if>
						<xsl:if test="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationStateName">
							<xsl:value-of select="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationStateName" />
							<xsl:text>&#160;</xsl:text>
						</xsl:if>
						<xsl:if test="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID">
							<xsl:value-of select="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID" />
						</xsl:if>
						<xsl:if test="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationCountyName">
							<xsl:text>&#160;&#160;&#160;County:&#160;</xsl:text>
							<xsl:value-of select="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationCountyName" />
						</xsl:if>
					</td>
				</tr>
			</xsl:if>
			<tr>
				<td><br /></td>
			</tr>
		</table>
		
		<table class="detailvalue" cellspacing="0">
			<tr>
				<td colspan="2">
					<div class="detaillabel" style="margin-top:15px;clear:both;">OFFENSES(S):</div>
				</td>
			</tr>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Offense:'"/>
				<xsl:with-param name="value1" select="j:CitationViolation/j:IncidentViolatedStatute/j:StatuteDescriptionText" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue uppercase width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Statute/Code:'"/>
				<xsl:with-param name="value1" select="j:CitationViolation/j:IncidentViolatedStatute/j:StatuteOffenseID/j:ID" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Fiscal Year:'"/>
				<xsl:with-param name="value1" select="dnr-ext:CitationFiscalYear" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Arrest #:'"/>
				<xsl:with-param name="value1" select="dnr-ext:ArrestID/j:ID" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Arrest Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:CitationViolation/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY" />
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Citation #:'"/>
				<xsl:with-param name="value1" select="dnr-ext:CitationID/j:ID" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'County:'"/>
				<xsl:with-param name="value1" select="j:CitationViolation/j:IncidentLocation/j:LocationAddress/j:LocationCountyName" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Adjudication:'"/>
				<xsl:with-param name="value1" select="dnr-ext:ChargeDisposition/j:ChargeDispositionVerdict/j:VerdictDescriptionText" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Adjudication Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="dnr-ext:ChargeDisposition/j:ChargeDispositionDate" mode="FormatFullDateAsMMDDYYYY" />
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Revocation Code:'"/>
				<xsl:with-param name="value1" select="dnr-ext:ChargeDisposition/dnr-ext:Revocation/dnr-ext:RevocationCode" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Revocation Type:'"/>
				<xsl:with-param name="value1" select="dnr-ext:ChargeDisposition/dnr-ext:Revocation/dnr-ext:RevocationType" />
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Revocation until Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="dnr-ext:ChargeDisposition/dnr-ext:Revocation/dnr-ext:RevocationEndDate" mode="FormatFullDateAsMMDDYYYY" />
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
</xsl:transform>