<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
	xmlns:dnr-ext="http://www.doj.state.wi.us/dles/cib/dnr/response/extension"
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/dnr/response" 
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2" 
	xmlns:xalan="http://xml.apache.org/xslt" 
	exclude-result-prefixes="xsl xsi dnr-ext doj j xalan">
	
	<xsl:import href="../common.xsl" />
	<xsl:import href="dnr_common.xsl" />
	<xsl:import href="../util.xsl" />
	
	<xsl:param name="from" />
	<xsl:param name="responseId">
		<xsl:value-of select="doj:DNRResponseDocument/@doj-ext:responseID" />
	</xsl:param>
	
	<xsl:output method="html" 
				version="4.01" 
				encoding="UTF-8" 
				omit-xml-declaration="yes" 
				doctype-public="-//W3C//DTD HTML 4.01//EN" 
				doctype-system="http://www.w3.org/TR/html4/strict.dtd" 
				indent="yes" 
				media-type="text/html" 
				xalan:indent-amount="2" />
	
	
	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="$from='ebc'">
				<xsl:call-template name="html_main" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="html_head_extension" />
				<xsl:call-template name="html_body" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<xsl:template name="html_title">
		TIME - DNR Person Registration
	</xsl:template>
	
	
	<xsl:template name="html_body">
		<xsl:call-template name="dnrLogo" />
		<xsl:call-template name="customerLogo" />
		<hr />
		<!-- Not all of the following will be applicable on a single response -->
		<xsl:apply-templates select="doj:DNRResponseDocument/doj:Result/doj:ResultText" />
		<!-- Hit response -->
		<xsl:apply-templates select="doj:DNRResponseDocument/doj:Result/doj:CustomerResponse/doj:InquiryResult/dnr-ext:Customer" />
	</xsl:template>
	
	
	<xsl:template name="customerLogo">
		<h1>
			<img src="../../images/customer.jpg" alt="DNR Person" />
			<xsl:text>&#160;&#160;</xsl:text>
			<xsl:text>DNR Person Record</xsl:text>
		</h1>
	</xsl:template>
	
	
	<xsl:template match="doj:ResultText | dnr-ext:ResponseText">
		<div class="resulttext">
			<h1 class="filetype">
				<xsl:value-of select="." />
			</h1>
		</div>
	</xsl:template>
	
	
	<xsl:template match="dnr-ext:Customer">
		<table class="detailvalue" cellspacing="0">
			<tr>
				<td>
					<span class="propertyinfo"><xsl:value-of select="j:PersonName/j:PersonFullName" /></span>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonSexText">
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonSexText" />
						<xsl:text>&#160;&#160;</xsl:text>
					</xsl:if>
					<xsl:apply-templates select="j:PersonBirthDate" mode="FormatFullDateAsMMDDYYYY" />
				</td>
			</tr>
			<tr>
				<td>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHeightMeasure">
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonHeightMeasure" />
						<xsl:text>&#160;&#160;</xsl:text>
					</xsl:if>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonWeightMeasure">
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonWeightMeasure" />
						<xsl:text>&#160;lbs&#160;&#160;</xsl:text>
					</xsl:if>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonEyeColorText">
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonEyeColorText" />
						<xsl:text>&#160;Eyes&#160;&#160;</xsl:text>
					</xsl:if>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHairColorText">
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonHairColorText" />
						<xsl:text>&#160;Hair</xsl:text>
					</xsl:if>
				</td>
			</tr>
			<xsl:if test="j:Residence/j:LocationAddress/j:LocationStreet/j:StreetFullText">
				<tr>
					<td>
						<xsl:value-of select="j:Residence/j:LocationAddress/j:LocationStreet/j:StreetFullText" />
					</td>
				</tr>
			</xsl:if>
			<xsl:if test="j:Residence/j:LocationAddress/j:LocationCityName
					| j:Residence/j:LocationAddress/j:LocationStateName
					| j:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID
					| j:Residence/j:LocationAddress/j:LocationCountyName">
				<tr>
					<td>
						<xsl:if test="j:Residence/j:LocationAddress/j:LocationCityName">
							<xsl:value-of select="j:Residence/j:LocationAddress/j:LocationCityName" />
							<xsl:text>,&#160;</xsl:text>
						</xsl:if>
						<xsl:if test="j:Residence/j:LocationAddress/j:LocationStateName">
							<xsl:value-of select="j:Residence/j:LocationAddress/j:LocationStateName" />
							<xsl:text>&#160;</xsl:text>
						</xsl:if>
						<xsl:if test="j:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID">
							<xsl:value-of select="j:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID" />
						</xsl:if>
						<xsl:if test="j:Residence/j:LocationAddress/j:LocationCountyName">
							<xsl:text>&#160;&#160;&#160;County:&#160;</xsl:text>
							<xsl:value-of select="j:Residence/j:LocationAddress/j:LocationCountyName" />
						</xsl:if>
					</td>
				</tr>
			</xsl:if>
		</table>
		<br />
		<table cellspacing="0">
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Customer ID:'"/>
				<xsl:with-param name="value1" select="dnr-ext:PersonID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detaillabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Customer Type:'"/>
				<xsl:with-param name="value2" select="j:PersonSocialDetails/j:PersonResidentText"/>
				<xsl:with-param name="label_class_name2" select="'detaillabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Driver License #:'"/>
				<xsl:with-param name="value1" select="j:DriverLicense/j:DriverAuthorizationID.Detailed/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detaillabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Driver State:'"/>
				<xsl:with-param name="value2" select="j:DriverLicense/j:DriverAuthorizationID.Detailed/j:IDIssuingAuthorityText"/>
				<xsl:with-param name="label_class_name2" select="'detaillabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Social security #:'"/>
				<xsl:with-param name="value1" select="j:PersonAssignedIDDetails/j:PersonSSNID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detaillabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Address Update:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates 
							select="j:Residence/@j:lastUpdatedDate" 
							mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detaillabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Telephone #:'"/>
				<xsl:with-param name="value1" select="j:PrimaryContactInformation/j:ContactTelephoneNumber/j:TelephoneNumberFullID"/>
				<xsl:with-param name="label_class_name1" select="'detaillabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="''"/>
				<xsl:with-param name="value2" select="''" />
				<xsl:with-param name="label_class_name2" select="'detaillabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
	</table>
	
	<table class="detailvalue" cellspacing="0">
			<!-- Backtags -->
			<xsl:apply-templates select="dnr-ext:BackTagID" />
			
			<!-- License(s) and Permit(s) -->
			<xsl:apply-templates select="dnr-ext:LicensePermit" />
			
			<!-- Certification(s) -->
			<xsl:apply-templates select="dnr-ext:Certification" />
			
			<!-- Citation(s) -->
			<xsl:apply-templates select="dnr-ext:Citation" />
			
			<!-- Boat(s) -->
			<xsl:apply-templates select="dnr-ext:Boat" />
			
			<!-- Snowmobile(s) -->
			<xsl:apply-templates select="dnr-ext:Snowmobile" />
			
			<!-- ATV(s) -->
			<xsl:apply-templates select="dnr-ext:AllTerrainVehicle" />
			
			<tr>
				<td><br /></td>
			</tr>
		</table>
	</xsl:template>
	
	
	<!-- Backtag(s) -->
	<xsl:template match="dnr-ext:BackTagID">
	 	<tr>
			<td colspan="4"><br /></td>
		</tr>
		<xsl:if test="position()=1">
			<tr>
				<td colspan="4"><br /></td>
			</tr>
			<tr>
				<td colspan="4">
					<div class="detaillabel" style="margin-top:15px;clear:both;">BACKTAG(S):</div>
				</td>
			</tr>
			
		</xsl:if>
		<xsl:if test="j:ID">
			<tr>
				<td><span class="detailsublabel">Backtag number/Type:</span></td>
				<td colspan="3"><span class="detailvalue">
					<xsl:value-of select="j:ID" />
					<xsl:if test="j:IDTypeText">
						<xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
						<xsl:value-of select="j:IDTypeText" />
					</xsl:if>
				</span></td>
			</tr>
		</xsl:if>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Backtag Year:'"/>
			<xsl:with-param name="value1" select="dnr-ext:IDYear"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="''"/>
			<xsl:with-param name="value2" select="''" />
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
	</xsl:template>
	
	
	<!-- License(s) and Permit(s) -->
	<xsl:template match="dnr-ext:LicensePermit">
		<tr>
			<td colspan="4"><br /></td>
		</tr>
		<xsl:if test="position()=1">
			<tr>
				<td colspan="4"><br /></td>
			</tr>
			<tr>
				<td colspan="4">
					<div class="detaillabel" style="margin-top:15px;clear:both;">LICENSE(S) AND PERMIT(S):</div>
				</td>
			</tr>
		</xsl:if>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Transaction:'"/>
			<xsl:with-param name="value1" select="dnr-ext:TransactionNumber"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Status:'"/>
			<xsl:with-param name="value2" select="j:StatusText"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Purchase Date/Time:'"/>
			<xsl:with-param name="value1">
				<xsl:apply-templates 
						select="dnr-ext:PurchaseDateTime/j:ActivityDate" 
						mode="FormatFullDateAsMMDDYYYY">
				</xsl:apply-templates>
				<xsl:if test="dnr-ext:PurchaseDateTime/j:ActivityTime">
					<xsl:text>&#160;</xsl:text>
					<xsl:value-of select="dnr-ext:PurchaseDateTime/j:ActivityTime" />
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Agent Number:'"/>
			<xsl:with-param name="value2" select="j:Organization/j:OrganizationID/j:ID"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Agent Name:'"/>
				<xsl:with-param name="value1" select="j:Organization/j:OrganizationName"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="''"/>
				<xsl:with-param name="value2" select="''" />
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:for-each select="dnr-ext:LicensePermitType">
			<tr>
				<td><span class="detailsublabel">Permit Type:</span></td>
				<td colspan="3"><span class="detailvalue"><xsl:value-of select="dnr-ext:LicensePermitTypeText" /></span></td>
			</tr>
			<xsl:if test="dnr-ext:Zone">
				<tr>
					<td><span class="detailsublabel">Zone:</span></td>
					<td colspan="3"><span class="detailvalue"><xsl:value-of select="dnr-ext:Zone" /></span></td>
				</tr>
			</xsl:if>
			<tr>
				<td><span class="detailsublabel">Effective Date:</span></td>
				<td>
					<span class="detailvalue">
						<xsl:apply-templates select="dnr-ext:EffectiveDate" mode="FormatFullDateAsMMDDYYYY" />
					</span>
				</td>
				<td><span class="detailsublabel">Expiration Date:</span></td>
				<td>
					<span class="detailvalue">
						<xsl:apply-templates select="dnr-ext:ExpirationDate" mode="FormatFullDateAsMMDDYYYY" />
					</span>
				</td>
			</tr>
		</xsl:for-each>
		<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Tag Number:'"/>
				<xsl:with-param name="value1" select="dnr-ext:TagNumber"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="''"/>
				<xsl:with-param name="value2" select="''" />
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
	</xsl:template>
	
	
	<!-- Certification(s) -->
	<xsl:template match="dnr-ext:Certification">
 		<tr>
			<td colspan="4"><br /></td>
		</tr>
		<xsl:if test="position()=1">
			<tr>
				<td colspan="4"><br /></td>
			</tr>
			<tr>
				<td colspan="4">
					<div class="detaillabel" style="margin-top:15px;clear:both;">CERTIFICATION(S):</div>
				</td>
			</tr>
		</xsl:if>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'ID:'"/>
			<xsl:with-param name="value1" select="j:ID"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Type:'"/>
			<xsl:with-param name="value2" select="j:IDTypeText"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Effective Date:'"/>
			<xsl:with-param name="value1">
			<xsl:apply-templates 
						select="j:IDEffectiveDate" 
						mode="FormatFullDateAsMMDDYYYY">
				</xsl:apply-templates>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="''"/>
			<xsl:with-param name="value2" select="''" />
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
	</xsl:template>
	
	
	<!-- Citation(s) -->
	<xsl:template match="dnr-ext:Citation">
		<tr>
			<td colspan="4"><br /></td>
		</tr>
		<xsl:if test="position()=1">
			<tr>
				<td colspan="4"><br /></td>
			</tr>
			<tr>
				<td colspan="4">
					<div class="detaillabel" style="margin-top:15px;clear:both;">CITATION(S):</div>
				</td>
			</tr>
		</xsl:if>
		
		<tr>
			<td><span class="detailsublabel">Offense:</span></td>
			<td colspan="3"><span class="detailvalue">
			<xsl:value-of select="j:CitationViolation/j:IncidentViolatedStatute/j:StatuteDescriptionText"/>
			</span></td>
		</tr>
		<xsl:if test="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationStreet/j:StreetFullText
					| j:CitationSubject/j:Residence/j:LocationAddress/j:LocationCityName
					| j:CitationSubject/j:Residence/j:LocationAddress/j:LocationStateName
					| j:CitationSubject/j:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID
					| j:CitationSubject/j:Residence/j:LocationAddress/j:LocationCountyName">
			<tr>
				<td><span class="detailsublabel">Address:</span></td>
				<td colspan="3">
					<span class="detailvalue">
					<xsl:if test="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationStreet/j:StreetFullText">
						<xsl:value-of select="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationStreet/j:StreetFullText" />
						<xsl:text>&#160;</xsl:text>
					</xsl:if>
					<xsl:if test="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationCityName">
						<xsl:value-of select="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationCityName" />
						<xsl:text>,&#160;</xsl:text>
					</xsl:if>
					<xsl:if test="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationStateName">
						<xsl:value-of select="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationStateName" />
						<xsl:text>&#160;</xsl:text>
					</xsl:if>
					<xsl:if test="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID">
						<xsl:value-of select="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID" />
					</xsl:if>
					<xsl:if test="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationCountyName">
						<xsl:text>&#160;&#160;&#160;County:&#160;</xsl:text>
						<xsl:value-of select="j:CitationSubject/j:Residence/j:LocationAddress/j:LocationCountyName" />
					</xsl:if>
					</span>
				</td>
			</tr>
		</xsl:if>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Statute/Code:'"/>
			<xsl:with-param name="value1" select="j:CitationViolation/j:IncidentViolatedStatute/j:StatuteOffenseID/j:ID"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Fiscal Year:'"/>
			<xsl:with-param name="value2" select="dnr-ext:CitationFiscalYear"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Arrest #:'"/>
			<xsl:with-param name="value1" select="j:IncidentViolatedStatute/j:StatuteOffenseID/j:ID"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Arrest Date:'"/>
			<xsl:with-param name="value2">
				<xsl:apply-templates 
						select="j:CitationViolation/j:ActivityDate" 
						mode="FormatFullDateAsMMDDYYYY">
				</xsl:apply-templates>
			</xsl:with-param>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Citation #:'"/>
			<xsl:with-param name="value1" select="dnr-ext:CitationID/j:ID"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'County:'"/>
			<xsl:with-param name="value2" select="j:CitationViolation/j:IncidentLocation/j:LocationAddress/j:LocationCountyName"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Adjudication:'"/>
			<xsl:with-param name="value1" select="dnr-ext:ChargeDisposition/j:ChargeDispositionVerdict/j:VerdictDescriptionText"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Adjudication Date:'"/>
			<xsl:with-param name="value2">
				<xsl:apply-templates 
						select="dnr-ext:ChargeDisposition/j:ChargeDispositionDate" 
						mode="FormatFullDateAsMMDDYYYY">
				</xsl:apply-templates>
			</xsl:with-param>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Revocation Code:'"/>
			<xsl:with-param name="value1" select="dnr-ext:ChargeDisposition/dnr-ext:Revocation/dnr-ext:RevocationCode"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="''"/>
			<xsl:with-param name="value2" select="''" />
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Revocation Type:'"/>
			<xsl:with-param name="value1" select="dnr-ext:ChargeDisposition/dnr-ext:Revocation/dnr-ext:RevocationType"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="''"/>
			<xsl:with-param name="value2" select="''" />
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Revocation until Date:'"/>
			<xsl:with-param name="value1">
				<xsl:apply-templates 
						select="dnr-ext:ChargeDisposition/dnr-ext:Revocation/dnr-ext:RevocationEndDate" 
						mode="FormatFullDateAsMMDDYYYY">
				</xsl:apply-templates>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="''"/>
			<xsl:with-param name="value2" select="''" />
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- Boat(s) -->
	<xsl:template match="dnr-ext:Boat">
		<tr>
			<td colspan="4"><br /></td>
		</tr>
		<xsl:if test="position()=1">
			<tr>
				<td colspan="4"><br /></td>
			</tr>
			<tr>
				<td colspan="4">
					<div class="detaillabel" style="margin-top:15px;clear:both;">BOAT(S):</div>
				</td>
			</tr>
		</xsl:if>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Registration:'"/>
			<xsl:with-param name="value1" select="dnr-ext:VehicleRegistration/j:RegistrationID/j:ID"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Expiration Year:'"/>
			<xsl:with-param name="value2" select="dnr-ext:VehicleRegistration/dnr-ext:RegistrationExpirationYear"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Hull #:'"/>
			<xsl:with-param name="value1" select="j:BoatHullID/j:ID"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Year:'"/>
			<xsl:with-param name="value2" select="dnr-ext:PropertyPhysicalDetails/j:PropertyYearDate"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Make:'"/>
			<xsl:with-param name="value1" select="dnr-ext:PropertyPhysicalDetails/j:PropertyMakeName"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Model:'"/>
			<xsl:with-param name="value2" select="dnr-ext:PropertyPhysicalDetails/j:PropertyModelName"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Length:'"/>
			<xsl:with-param name="value1">
					<xsl:apply-templates select="dnr-ext:PropertyPhysicalDetails/j:PropertyLengthMeasure" mode="LengthConversion" />
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="''"/>
			<xsl:with-param name="value2" select="''" />
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
	</xsl:template>
	
	
	<!-- Snowmobile(s) -->
	<xsl:template match="dnr-ext:Snowmobile">
		<tr>
			<td colspan="4"><br /></td>
		</tr>
		<xsl:if test="position()=1">
			<tr>
				<td colspan="4"><br /></td>
			</tr>
			<tr>
				<td colspan="4">
					<div class="detaillabel" style="margin-top:15px;clear:both;">SNOWMOBILE(S):</div>
				</td>
			</tr>
		</xsl:if>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Registration:'"/>
			<xsl:with-param name="value1" select="dnr-ext:VehicleRegistration/j:RegistrationID/j:ID"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Serial #:'"/>
			<xsl:with-param name="value2" select="j:PropertyAssignedIDDetails/j:PropertySerialID/j:ID"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Decal Number:'"/>
			<xsl:with-param name="value1" select="dnr-ext:VehicleRegistration/dnr-ext:DecalID/j:ID"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Make:'"/>
			<xsl:with-param name="value2" select="dnr-ext:PropertyPhysicalDetails/j:PropertyMakeName"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Type:'"/>
			<xsl:with-param name="value1" select="dnr-ext:VehicleRegistration/dnr-ext:DecalID/j:IDTypeText"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Year:'"/>
			<xsl:with-param name="value2" select="dnr-ext:PropertyPhysicalDetails/j:PropertyYearDate"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Expiration Year:'"/>
			<xsl:with-param name="value1" select="dnr-ext:VehicleRegistration/dnr-ext:DecalID/dnr-ext:IDExpirationYear"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="''"/>
			<xsl:with-param name="value2" select="''" />
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:for-each select="j:PropertyOwner.Person">
			<tr>
				<td colspan="4">
					Additional Owner:&#160;
					<xsl:value-of select="j:PersonName/j:PersonFullName"/>
					<xsl:apply-templates select = "j:Residence" mode="additionalowner"/>
				</td>
			</tr>
		</xsl:for-each>
	</xsl:template>
	
	<!-- ATV(s) -->
	<xsl:template match="dnr-ext:AllTerrainVehicle">
		<tr>
			<td colspan="4"><br /></td>
		</tr>
		<xsl:if test="position()=1">
			<tr>
				<td colspan="4"><br /></td>
			</tr>
			<tr>
				<td colspan="4">
					<div class="detaillabel" style="margin-top:15px;clear:both;">ATV(S):</div>
				</td>
			</tr>
		</xsl:if>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Registration:'"/>
			<xsl:with-param name="value1" select="dnr-ext:VehicleRegistration/j:RegistrationID/j:ID"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Serial #:'"/>
			<xsl:with-param name="value2" select="j:PropertyAssignedIDDetails/j:PropertySerialID/j:ID"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Decal Number:'"/>
			<xsl:with-param name="value1" select="dnr-ext:VehicleRegistration/dnr-ext:DecalID/j:ID"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Make:'"/>
			<xsl:with-param name="value2" select="dnr-ext:PropertyPhysicalDetails/j:PropertyMakeName"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Type:'"/>
			<xsl:with-param name="value1" select="dnr-ext:VehicleRegistration/dnr-ext:DecalID/j:IDTypeText"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="'Year:'"/>
			<xsl:with-param name="value2" select="dnr-ext:PropertyPhysicalDetails/j:PropertyYearDate"/>
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Expiration Year:'"/>
			<xsl:with-param name="value1" select="dnr-ext:VehicleRegistration/dnr-ext:DecalID/dnr-ext:IDExpirationYear"/>
			<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			<xsl:with-param name="label2" select="''"/>
			<xsl:with-param name="value2" select="''" />
			<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
			<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<xsl:for-each select="j:PropertyOwner.Person">
			<tr>
				<td colspan="4">
					Additional Owner:&#160;
					<xsl:value-of select="j:PersonName/j:PersonFullName"/>
					<xsl:apply-templates select = "j:Residence" mode="additionalowner"/>
				</td>
			</tr>
		</xsl:for-each>
	</xsl:template>
	
</xsl:transform>