<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:doc-ext="http://www.doj.state.wi.us/dles/cib/doc/response/extension"
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/doc/response" 
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"
    xmlns:xalan="http://xml.apache.org/xslt"
    exclude-result-prefixes="xsl xsi doc-ext doj j xalan">
    
	<xsl:import href="../common.xsl"/>
	<xsl:import href="../util.xsl"/>

	<!--  DOC - Offender -->
	<!-- ############### -->
	<!-- main template   -->
	<!-- ############### -->
	<xsl:template match="/doj:DOCResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - DOC Offender</xsl:text> 
	</xsl:template>
	
    <xsl:template match="doj:Result">
		<xsl:param name="fileName" select="."/>
		
	    <xsl:choose>
	      <xsl:when test="$from='ebc'">
	        <xsl:call-template name="html_main">
				<xsl:with-param name="fileName" select="$fileName"/>
			</xsl:call-template>
	      </xsl:when>
	      <xsl:otherwise>
	        <xsl:call-template name="html_head_extension" />
	        <!-- This prevents the solid black lines from displaying in online validations (FB 189) -->
	        <div id="container">
	        	<xsl:call-template name="html_body" />
	        </div>
	      </xsl:otherwise>
	    </xsl:choose>
	</xsl:template>
	
	<xsl:template name="html_head_extension">
		<style type="text/css">
			img.image {
				float: right;
				height: 150px;
				width: 125px;
			}
		</style>
		
 		<script language="JavaScript">
	 		function confirmPhoto(id, from) {
	 			if (from=='ebc') {
					var msg = "Click OK to send a photo request";
		        	if (confirm(msg)) {
	    	    		document.getElementById(id).submit();  
					}
	 			}
	 			else {
		 			alert('Photo is not available');
 					return;
	 			}
			}
		</script>
	</xsl:template>
	
	<xsl:template name="html_body">
		<xsl:choose>
			<xsl:when test="FormattedResultText">
				<xsl:apply-templates select="FormattedResultText"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="doj:ResultText"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="child::node()/doj:InquiryResult"/>
	</xsl:template>

	<xsl:template name="docLogo">
		<table width="100%" >
			<tr>
				<td align="right">
					<xsl:element name="img">
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'DOC.gif')"/></xsl:attribute>
						<xsl:attribute name="alt">DOC Logo</xsl:attribute>
						<xsl:attribute name="width">50</xsl:attribute>
						<xsl:attribute name="height">50</xsl:attribute>
					</xsl:element>
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template match="doj:ResultText">
	    <div class="resulttext">
	      <xsl:apply-templates select="." mode="TitleCase"/>
	    </div>
 	</xsl:template>
  
	<!-- ################### -->
	<!-- doj:InquiryResult   -->
	<!-- ################### -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:choose>
			<xsl:when test="j:Binary/j:BinaryObject.Base64">
				<!-- Photo response which only need certain templates else adds extra empty tables -->
				<xsl:apply-templates select="j:Binary" mode="image"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="." mode="file_type_details"/>
				<xsl:apply-templates select="doc-ext:OffenderSubject" mode="subject_details"/> 
				<xsl:apply-templates select="doc-ext:OffenderSubject" mode="FBItoDNA"/>
		 		<xsl:call-template name="vehicle_all">
					<xsl:with-param name="parent" select="."/>
				</xsl:call-template>
				<xsl:call-template name="licensePlate_all">
					<xsl:with-param name="parent" select="."/>
				</xsl:call-template>
				<xsl:apply-templates select="doc-ext:OffenderSubject" mode="alias"/>
				<xsl:apply-templates select="doc-ext:OffenderSubject/j:Employment" />
				<xsl:apply-templates select="doc-ext:OffenderSubject" mode="offense" />
				<xsl:apply-templates select="doc-ext:OffenderSubject/doc-ext:SupervisedReleaseReport" mode="supervisionInfo"/>
				<xsl:apply-templates select="doc-ext:OffenderSubject" mode="supervisionOfficial" />
				<xsl:apply-templates select="doc-ext:OffenderSubject/doc-ext:IncarcerationReport"/>
				<xsl:apply-templates select="j:Binary" mode="imageInfo"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- ################# -->
	<!-- File Type Header  -->
	<!-- ################# -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Data Service Logo -->	
		<xsl:call-template name="docLogo"/>
		<!-- File Type Header Section -->
		<table>
			<tr>
				<td class="width10percent">
					<!-- Display File Type Logo depending on role -->	
					<xsl:if test="doc-ext:OffenderSubject/doc-ext:OffenderRole/doc-ext:ParoleIndicator or doc-ext:OffenderSubject/doc-ext:OffenderRole/doc-ext:ProbationIndicator">
						<xsl:element name="img">
							<xsl:attribute name="src">
								<xsl:value-of select="concat($imageBase,'probation.gif')"/>
							</xsl:attribute>
							<xsl:attribute name="alt">Probation/Parole</xsl:attribute>
						</xsl:element>
					</xsl:if>
					<xsl:if test="doc-ext:OffenderSubject/doc-ext:OffenderRole/doc-ext:SexOffenderIndicator">
						<xsl:element name="img">
							<xsl:attribute name="src">
								<xsl:value-of select="concat($imageBase,'sexOffender.gif')"/>
							</xsl:attribute>
							<xsl:attribute name="alt">Sex Offender</xsl:attribute>
						</xsl:element>
					</xsl:if>
					<xsl:if test="doc-ext:OffenderSubject/doc-ext:OffenderRole/doc-ext:InmateIndicator">
						<xsl:element name="img">
							<xsl:attribute name="src">
								<xsl:value-of select="concat($imageBase,'inmate.jpg')"/>
							</xsl:attribute>
							<xsl:attribute name="alt">Inmate</xsl:attribute>
						</xsl:element>
					</xsl:if>
					<xsl:if test="j:Binary/j:BinaryObject.Base64">
						<xsl:element name="img">
							<xsl:attribute name="src">
								<xsl:value-of select="concat($imageBase,'camera.gif')"/>
							</xsl:attribute>
							<xsl:attribute name="alt">Image</xsl:attribute>
						</xsl:element>
					</xsl:if>
				</td>
				<td class="width90percent">
					<table> 
						<tr><td>
							<!-- File Description --> 	
							<span class="filetype">
								<xsl:if test="doc-ext:OffenderSubject/doc-ext:PersonJuvenileIndicator='true'"> 
									<xsl:text>Juvenile Offender</xsl:text>
									<br />
								</xsl:if>
								<xsl:apply-templates select="doc-ext:OffenderSubject/doc-ext:OffenderRole"/>	
								<xsl:if test="j:Binary/j:BinaryObject.Base64">
									<xsl:text>Corrections Photo</xsl:text>
								</xsl:if>	
							</span>
						</td></tr>
						<tr><td>	
							<!-- Caveat Text -->
							<xsl:for-each select="j:CaveatText">
								<div class="caveat">
		  							<xsl:value-of select="."/> 
		  							<xsl:if test="position() != last()">
		  								<div style="white-space: pre;"><xsl:text>&#10;</xsl:text></div>
		  							</xsl:if>
								</div>
							</xsl:for-each>
						 </td></tr>
					</table>
				</td>
			</tr>
		</table>
		<!-- Horizontal Line -->
		<hr/>
	</xsl:template>

	<xsl:template match="doc-ext:OffenderRole">
		<xsl:variable name="roles">
			<xsl:if test="doc-ext:ConvictedSubjectIndicator='true'">
				<xsl:text>Convicted Subject; </xsl:text>
			</xsl:if>
			<xsl:if test="doc-ext:ParoleIndicator='true'">
				<xsl:text>Parole; </xsl:text>
			</xsl:if>
			<xsl:if test="doc-ext:ProbationIndicator='true'">
				<xsl:text>Probation; </xsl:text>
			</xsl:if>
			<xsl:if test="doc-ext:SexOffenderIndicator='true'">
				<xsl:text>Sex Offender; </xsl:text>
			</xsl:if>
			<xsl:if test="doc-ext:InmateIndicator='true'">
				<xsl:text>Inmate; </xsl:text>
			</xsl:if>
		</xsl:variable>
		<xsl:value-of select="substring($roles, 1, string-length($roles) - 2)"/>
	</xsl:template>
	
	<!-- Information at top of page -->
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Offender Details-->	
		<table>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Offender Status:'"/>
				<xsl:with-param name="value1">
				<xsl:apply-templates select="doc-ext:OffenderSubject/doc-ext:OffenderStatusText"  mode="TitleCase"/>
			</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Supervising Officer:'"/>
				<xsl:with-param name="value1" select="doc-ext:OffenderSubject/doc-ext:SupervisedReleaseReport/j:SupervisionOfficial/j:PersonAssignedIDDetails/j:PersonHumanResourcesID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Supervising PH Number:'"/>
			<xsl:with-param name="value1" select="doc-ext:OffenderSubject/doc-ext:SupervisedReleaseReport/j:SupervisionOfficial/j:PrimaryContactInformation/j:ContactTelephoneNumber/j:TelephoneNumberFullID"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Conditions:'"/>
				<xsl:with-param name="value1">
				<xsl:for-each select ="doc-ext:OffenderSubject/doc-ext:SupervisedReleaseReport/doc-ext:SupervisedRelease/j:SupervisionCondition/j:ActivityDescriptionText">
					<xsl:value-of select="."/>
					<xsl:if test="position() != last()">&#59;&#32;</xsl:if>
				</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue defaultcase width70percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
	<xsl:template match="doc-ext:OffenderSubject" mode="subject_details">
		<br/>	
		<table class="subjectvalue width60percent">
			<tr>
				<td colspan="4" class="width80percent">
					<!-- Name -->
					<xsl:apply-templates select="j:PersonName" />
					<br/>
					<!-- Gender/Race -->
					<xsl:if test="j:PersonPhysicalDetails/j:PersonSexText or j:PersonPhysicalDetails/j:PersonRaceText">
						<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonSexText" mode="TitleCase"/>	
						<xsl:text>&#160;&#160;</xsl:text>
						<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonRaceText" mode="TitleCase"/>	
						<br/>	
					</xsl:if>	
					<!-- more person details --> 
					<!-- Person birthdate -->
					<xsl:for-each select="j:PersonBirthDate">
						<xsl:apply-templates select="." mode="FormatFullDateAsMMDDYYYY"/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#32;</xsl:text>
						</xsl:if>
					</xsl:for-each>
				</td>
				<td class="width20percent" valign="left">
					<xsl:if test="j:PersonAlternateName">
						<br/>
						<a href="#alias{$responseId}">
							<xsl:element name="img">
								<xsl:attribute name="src">
									<xsl:value-of select="concat($imageBase,'aliasfraudlink.jpg')"/>
								</xsl:attribute>
								<xsl:attribute name="alt">Link to alias info</xsl:attribute>
							</xsl:element>
						</a>
					</xsl:if>
				</td>
			</tr>
			<xsl:if test="j:PersonPhysicalDetails/j:PersonHeightMeasure or 
					j:PersonPhysicalDetails/j:PersonWeightMeasure or 
					j:PersonPhysicalDetails/j:PersonEyeColorText or
					j:PersonPhysicalDetails/j:PersonHairColorText or 
					j:PersonPhysicalDetails/j:PersonHairLengthText">
			<tr>
				<td>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHeightMeasure">
						<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonHeightMeasure" mode="LengthConversion" />
					</xsl:if>
				</td>
				<td>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonWeightMeasure">
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonWeightMeasure"/>
						<xsl:text>&#160;lbs</xsl:text>
					</xsl:if>
				</td>
				<td>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonEyeColorText">
						<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonEyeColorText" mode="TitleCase"/>
						<xsl:text>&#160;Eyes</xsl:text>
					</xsl:if>
				</td>
				<td>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHairColorText"> 
						<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonHairColorText"  mode="TitleCase"/>
						<xsl:text>&#160;Hair</xsl:text>
					</xsl:if>
				</td>
				<td>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHairLengthText">
						<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonHairLengthText"  mode="TitleCase"/>
					</xsl:if>
				</td>
			</tr>
			</xsl:if>
			
			<xsl:if test="j:PersonPhysicalDetails/j:PersonHairFacialText or j:PersonPhysicalDetails/j:PersonEyewearDescriptionText">
			<tr>
				<td>&#160;</td>
				<td>&#160;</td>
				<xsl:choose>
					<!--  DOC can send 2  j:PersonHairFacialText -->
					<xsl:when test="j:PersonPhysicalDetails/j:PersonHairFacialText">
						<xsl:choose>
							<xsl:when test="count(j:PersonPhysicalDetails/j:PersonHairFacialText) > 1">
								<xsl:for-each select = "j:PersonPhysicalDetails/j:PersonHairFacialText">
									<td>
										<xsl:apply-templates select="." mode="TitleCase"/>
									</td>
								</xsl:for-each>
							</xsl:when>
							<xsl:otherwise>
								<xsl:for-each select = "j:PersonPhysicalDetails/j:PersonHairFacialText">
									<td>
										<xsl:apply-templates select="." mode="TitleCase"/>
									</td>
								</xsl:for-each>
								<td>&#160;</td>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<td colspan="2">&#160;</td>
					</xsl:otherwise>
				</xsl:choose>
				<td>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonEyewearDescriptionText">
							<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonEyewearDescriptionText"  mode="TitleCase"/>	
					</xsl:if>	
				</td>
			</tr>	
			</xsl:if>

			<xsl:if test="j:Residence or j:PrimaryContactInformation/j:ContactTelephoneNumber">
			<tr>	
				<td colspan="5">				
					<!-- Address -->
					<xsl:for-each select="j:Residence">
						<xsl:if test="j:LocationAddress/j:LocationStreet/j:StreetFullText">
							<xsl:value-of select="j:LocationAddress/j:LocationStreet/j:StreetFullText" />
							<xsl:text>,&#160;</xsl:text>
						</xsl:if>
						<xsl:if test="j:LocationAddress/j:LocationSecondaryUnitText">
							<xsl:value-of select="j:LocationAddress/j:LocationSecondaryUnitText"/>
							<xsl:text>,&#160;</xsl:text>
						</xsl:if>
						<xsl:if test="j:LocationAddress/j:LocationCityName">
							<xsl:apply-templates select="j:LocationAddress/j:LocationCityName" mode="TitleCase"/>
							<xsl:text>,&#160;</xsl:text>
						</xsl:if>			
						<xsl:if test="j:LocationAddress/j:LocationStateName">
						<!--  DOC is returning the state code however the value is title case (Wi) -->
							<span class="uppercase">
							<xsl:value-of select="j:LocationAddress/j:LocationStateName" />
							</span>
						</xsl:if>	
						<xsl:if test="j:LocationAddress/j:LocationPostalCodeID">
							<xsl:text>,&#160;</xsl:text>
							<xsl:value-of select="j:LocationAddress/j:LocationPostalCodeID"/>
							<xsl:if test="j:LocationAddress/j:LocationPostalCodeExtensionID">
								<xsl:text>-</xsl:text>
								<xsl:value-of select="j:LocationAddress/j:LocationPostalCodeExtensionID"/>
							</xsl:if>
						</xsl:if>	
						<xsl:if test="j:LocationAddress/j:LocationCountryName">
							<xsl:text>,&#160;</xsl:text>
							<xsl:apply-templates select="j:LocationAddress/j:LocationCountryName" />
						</xsl:if>
						<br/> 
						<xsl:choose>
							<xsl:when test="j:ResidenceTypeText">
								<xsl:value-of select="j:ResidenceTypeText"/>
									<xsl:if test="@j:lastUpdatedDate">
										<xsl:text>&#32;as&#32;of&#32;</xsl:text>
										<xsl:apply-templates select="@j:lastUpdatedDate" mode="FormatFullDateAsMMDDYYYY"/>
									</xsl:if>
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="@j:lastUpdatedDate">
									<xsl:text>Residence&#32;as&#32;of&#32;</xsl:text>
									<xsl:apply-templates select="@j:lastUpdatedDate" mode="FormatFullDateAsMMDDYYYY"/>
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
						<br/> 
					</xsl:for-each>
					<!--  telephone number -->
					<xsl:for-each select="j:PrimaryContactInformation/j:ContactTelephoneNumber">
						<xsl:value-of select="j:TelephoneNumberFullID"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:apply-templates select="j:TelephoneNumberCommentText" mode="TitleCase"/>
						<br/>
					</xsl:for-each> 
				</td>
			</tr>
			</xsl:if>
		</table>
	</xsl:template> 


	<!-- Name in format First, Middle, Last, Suffix -->
	<xsl:template match="j:PersonName">
		<span class="subjecttitle">
			<xsl:choose>
				<!--  j:PersonFullName is used for the photo response -->
				<xsl:when test="j:PersonFullName">
					<xsl:value-of select="j:PersonFullName"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select = "." mode="FirstMiddleLastSuffix"/>
				</xsl:otherwise>
			</xsl:choose>
		</span>
	</xsl:template> 
	
	<!-- SSN, FBI, SID, MMNU DOC#, SMT, DL, DNA-->
	<xsl:template match="doc-ext:OffenderSubject" mode="FBItoDNA">
		<xsl:if test="j:PersonAssignedIDDetails">
			<br/>
		</xsl:if>
		<table>
			<!-- SSN -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Social Security #:'"/>
				<xsl:with-param name="value1">
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonSSNID">
						<xsl:apply-templates select="j:ID" mode="FormatSSN"/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#32;</xsl:text>
						</xsl:if>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>		
			</xsl:call-template>
			<!-- FBI -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'FBI:'"/>
				<xsl:with-param name="value1">
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonFBIID">
						<xsl:value-of select="j:ID"/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#32;</xsl:text>
						</xsl:if>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>		
			</xsl:call-template>
			<!-- Stata ID: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'State ID:'"/>
				<xsl:with-param name="value1">
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonStateID">
						<xsl:value-of select="j:ID"/>
						<xsl:text>,&#32;</xsl:text>
						<xsl:value-of select="j:IDJurisdictionText"/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#32;</xsl:text>
						</xsl:if>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>		
			</xsl:call-template>
			<!-- Miscellaneous # -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Miscellaneous #:'"/>
				<xsl:with-param name="value1">
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonOtherID">
						<xsl:if test="j:IDTypeText">
							<xsl:value-of select="j:IDTypeText"/>
							<xsl:text>-</xsl:text>
						</xsl:if>
						<xsl:value-of select="j:ID"/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#32;</xsl:text>
						</xsl:if>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>		
			</xsl:call-template>
			<!-- DOC # -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'DOC #:'"/>
				<xsl:with-param name="value1" select="doc-ext:DOCNumberID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<!-- SMT: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Scarmark:'"/>
				<xsl:with-param name="value1">
					<xsl:for-each select="j:PersonPhysicalDetails/j:PersonPhysicalFeature">
						<xsl:value-of select="j:PhysicalFeatureTypeText"/>
						<xsl:if test="j:PhysicalFeatureDescriptionText">
							<xsl:text>&#32;&#45;&#32;</xsl:text>
							<xsl:apply-templates select="j:PhysicalFeatureDescriptionText" mode="TitleCase"/>
						</xsl:if>
						<xsl:if test="position() != last()">
							<xsl:text>;&#32;</xsl:text>
						</xsl:if>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>		
			</xsl:call-template>
			<!-- ethnicity -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Ethnicity:'"/>
				<xsl:with-param name="value1" select="j:PersonSocialDetails/j:PersonEthnicityText"/>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:apply-templates select="." mode="DriverLicense"/> 
			<xsl:apply-templates select="j:PersonBiometricDetails/j:PersonDNA"/>
		</table>
	</xsl:template>
	
	<!-- Drivers License which can be multiples -->
	<xsl:template match="doc-ext:OffenderSubject" mode="DriverLicense">
		<xsl:if test="j:DriverLicense">
			<table>
				  <tr>
					<td class="detaillabel uppercase width25percent">
						<xsl:text>Drivers License #:</xsl:text>
					</td>
					<td class="detailvalue width75percent">
						<xsl:for-each select="j:DriverLicense/j:DriverAuthorizationID.Detailed">
							<xsl:value-of select="j:ID"/>
							<xsl:text>,&#160;</xsl:text>
							<xsl:apply-templates select="j:IDJurisdictionText" mode="TitleCase"/>
							<xsl:if test="j:IDIssuingAuthorityText">
								<xsl:text>,&#160;</xsl:text>
								<xsl:apply-templates select="j:IDIssuingAuthorityText" mode="TitleCase"/>
							</xsl:if>
							<xsl:if test="j:IDSourceText">
								<xsl:text>,&#160;</xsl:text>
								<xsl:apply-templates select="j:IDSourceText" mode="TitleCase"/>
							</xsl:if>
						    <xsl:if test="position() != last()">
						    <br />
						    </xsl:if>
						</xsl:for-each>
					</td>
				</tr>
			</table>
		  </xsl:if>
	</xsl:template>
	
	<!-- DNA Available (on its own line)   -->
	<xsl:template match="j:PersonDNA">
		<br/>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'DNA Available:'"/>
			<xsl:with-param name="value1">
				<xsl:if test="@j:commentText = 'available'">
					<xsl:text>Yes</xsl:text>
				</xsl:if>
				<xsl:if test="@j:commentText = 'unavailable'">
					<xsl:text>No</xsl:text>
				</xsl:if>				
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>	
	</xsl:template>
	
	<!-- vehicle -->
		<xsl:template name="vehicle_all">
		<xsl:param name="parent" select="."/>
		<xsl:if test="$parent/doc-ext:Vehicle">
			<br/>
			<table>
				<tr>
					<td class="width25percent">
						<xsl:element name="img">
							<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'VehicleIcon.jpg')"/></xsl:attribute>
							<xsl:attribute name="alt">Vehicle</xsl:attribute>
						</xsl:element>
					</td>
					<td class="width75percent">
						<xsl:for-each select="$parent/doc-ext:Vehicle">
							<xsl:call-template name="Vehicle"/>
						</xsl:for-each>
					</td> 
				</tr>
			</table>
		</xsl:if> 
	</xsl:template>
	
	<!-- Vehicle  -->
	<xsl:template name="Vehicle">
		<span class="detailvalue">
			<xsl:value-of select="j:VehicleModelYearDate"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:apply-templates select="doc-ext:VehicleMakeText"  mode="TitleCase"/>
			<xsl:if test="j:VehicleModelCodeText">
				<xsl:text>&#160;</xsl:text>
				<xsl:apply-templates select="j:VehicleModelCodeText"  mode="TitleCase"/>
			</xsl:if>
			<xsl:if test="j:VehicleColorPrimaryText">
				<xsl:text>,&#160;</xsl:text>
				<xsl:apply-templates select="j:VehicleColorPrimaryText"  mode="TitleCase"/>
			</xsl:if>
			<xsl:if test="j:VehicleID/j:ID">
				<xsl:text>,&#160;&#160;</xsl:text>
				<xsl:value-of select="j:VehicleID/j:ID" /> 
			</xsl:if>
		</span>
		<br/>
	</xsl:template>
	
	<!-- plate -->
	<xsl:template name="licensePlate_all">
		<xsl:param name="parent" select="."/>
		<xsl:if test="$parent/doc-ext:Vehicle/j:VehicleLicensePlateID">
			<br/>
			<table>
				<tr>
					<td class="width25percent" valing="top">
						<xsl:element name="img">
							<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'Plate1.jpg')"/></xsl:attribute>
							<xsl:attribute name="alt">License Plate</xsl:attribute>
						</xsl:element>
					</td>
					<td class="width75percent">
						<xsl:for-each select="$parent/doc-ext:Vehicle/j:VehicleLicensePlateID" >
							<xsl:call-template name="LicensePlate"/>
						</xsl:for-each> 
					</td> 
				</tr>
			</table>
		</xsl:if>
	</xsl:template>
	
	<!-- Plates -->
	<xsl:template name="LicensePlate">
		<span class="detailvalue">
			<xsl:value-of select="j:ID"/>	
			<xsl:text>,&#160;</xsl:text>		
			<xsl:value-of select="j:IDJurisdictionText"/>
		</span><br/>
	</xsl:template>
	
	<!-- alternate names -->
	<xsl:template name="aliasHeader">
		<br/>
		<a name="alias{$responseId}">
		<span class="detaillabel">ALIAS NAMES/FRAUDULENT DATA:</span>
		</a>
	</xsl:template>
	
	<!-- Alias Names -->
	<xsl:template match="doc-ext:OffenderSubject" mode="alias">
		<xsl:if test="j:PersonAlternateName">
			<xsl:call-template name="aliasHeader"/>
				<table>
					<tr>
						<td class="detailsublabel width25percent">Alias Names:</td>
						<td class="width75percent">
							<xsl:call-template name="listAlias"/>
						</td>
					</tr>
				</table>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="listAlias">
		<table>
			<xsl:for-each select="j:PersonAlternateName[position() mod 2 != 0]">
                <xsl:sort select="j:PersonSurName" data-type="text" order="ascending"/>
                <xsl:sort select="j:PersonGivenName" data-type="text" order="ascending"/>
                <xsl:variable name="startposition" select="((number(position())-1)*2)+1"/>
                    <tr>
                        <xsl:apply-templates select="../j:PersonAlternateName" mode="aliasNames">
                             <xsl:sort select="j:PersonSurName" data-type="text" order="ascending"/>
                             <xsl:sort select="j:PersonGivenName" data-type="text" order="ascending"/>
                             <xsl:with-param name="startposition" select="$startposition"/>
                        </xsl:apply-templates>
                    </tr>
            </xsl:for-each>
          </table>
	</xsl:template>
	
	<xsl:template match="j:PersonAlternateName" mode="aliasNames">
        <xsl:param name="startposition"/>
        <xsl:if test="position() = number($startposition) or position() = number($startposition)+1">
            <td class="width50percent"><xsl:apply-templates select="." mode="alias"/></td>
        </xsl:if>
    </xsl:template>
	
	<!-- Name in format Last, First, Middle, Suffix -->
	<xsl:template match="*" mode="alias">
		<span class="detailvalue">
			<xsl:apply-templates select="j:PersonSurName" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
			<xsl:apply-templates select="j:PersonGivenName" mode="TitleCase"/>
			<xsl:if test="j:PersonMiddleName or j:PersonSuffixName">
				<xsl:text>&#160;</xsl:text>
			</xsl:if>
			<xsl:apply-templates select="j:PersonMiddleName" mode="TitleCase"/>		
			<xsl:if test="j:PersonSuffixName">
				<xsl:text>&#160;</xsl:text>
				<xsl:apply-templates select="j:PersonSuffixName" mode="TitleCase"/>
			</xsl:if>
		</span>
	</xsl:template>
	
	
	<!-- Employment -->
	<xsl:template match="j:Employment">
		<br/>
		<xsl:if test="position() = 1">
			<span class="detaillabel uppercase">Employment:</span>
		</xsl:if>		
		<table>
		  <!--Employer type and name-->
		  <xsl:if test="j:EmploymentEmployer.Organization/j:OrganizationTypeText or j:EmploymentEmployer.Organization/j:OrganizationName"> 
		  	<tr>
				<td class="detailsublabel width25percent">
					<xsl:text>Type:</xsl:text>
				</td>
				<td class="detailvalue width25percent">
					<xsl:apply-templates select="j:EmploymentEmployer.Organization/j:OrganizationTypeText"  mode="TitleCase"/>
				</td>
				<td colspan="2" class="detailvalue width50percent">
					<xsl:apply-templates select="j:EmploymentEmployer.Organization/j:OrganizationName"  mode="TitleCase"/>
				</td>
			</tr>
		  </xsl:if>
		  <!--Employer Address-->
          <xsl:if test="j:EmploymentEmployer.Organization/j:OrganizationLocation">
          	<xsl:for-each select="j:EmploymentEmployer.Organization/j:OrganizationLocation">
          	  <tr>
				<td class="detailsublabel width25percent">
					<xsl:text>Address:</xsl:text>
				</td>
				<td colspan="3" class="detailvalue width75percent">
					<xsl:value-of select="j:LocationAddress/j:LocationStreet/j:StreetFullText"/>
					<xsl:if test="j:LocationAddress/j:LocationStreet/j:StreetFullText">
						<xsl:text>,&#32;</xsl:text>
					</xsl:if>
					<xsl:value-of select="j:LocationAddress/j:LocationSecondaryUnitText"/>
					<xsl:if test="j:LocationAddress/j:LocationSecondaryUnitText">
						<xsl:text>&#32;</xsl:text>
					</xsl:if>
					<xsl:apply-templates select="j:LocationAddress/j:LocationCityName" mode="TitleCase"/>
					<xsl:if test="j:LocationAddress/j:LocationCityName">
						<xsl:text>&#32;</xsl:text>
					</xsl:if>
					<xsl:value-of select="j:LocationAddress/j:LocationStateName" />
					<xsl:if test="j:LocationAddress/j:LocationStateName">
						<xsl:text>&#32;</xsl:text>
					</xsl:if>
					<xsl:value-of select="j:LocationAddress/j:LocationPostalCodeID/j:ID "/>
					<xsl:if test="j:LocationAddress/j:LocationPostalCodeID/j:ID ">
						<xsl:text>&#32;</xsl:text>
					</xsl:if>
					<xsl:value-of select="j:LocationAddress/j:LocationCountryName "/>
				</td>
			 </tr>
         </xsl:for-each>
	  </xsl:if>

			<xsl:if test="j:EmploymentEndDate">
				<tr>
				<td class="detailsublabel width25percent">
					<xsl:text>End Date:</xsl:text>
				</td>
				<td colspan="3" class="detailvalue width75percent">
					<xsl:apply-templates select="j:EmploymentEndDate" mode="FormatFullDateAsMMDDYYYY"/>
				</td>
				</tr>
			</xsl:if>
		</table>
	</xsl:template>	
	
	<xsl:template match="doc-ext:OffenderSubject" mode="offense">
		<xsl:for-each select="child::node()/doc-ext:Offense"> 
			<br/>
			<xsl:if test="position() = 1">
				<span class="detaillabel uppercase">Offense Information:</span>
			</xsl:if>	
			<xsl:apply-templates select="."/>
		</xsl:for-each>
	</xsl:template>
	
	<!-- Offense -->
	<xsl:template match="doc-ext:Offense">
		
		<table>
		<!-- Statute  and Offense date-->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Statute:'"/>
				<xsl:with-param name="value1" select="j:IncidentViolatedStatute/j:StatuteCodeID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Offense Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Statute description  -->
			<xsl:if test="j:IncidentViolatedStatute/j:StatuteDescriptionText">
				<tr>
					<td class="width25percent">&#32;</td>
					<td colspan="3" class="detailvalue width75percent">
						<xsl:apply-templates select="j:IncidentViolatedStatute/j:StatuteDescriptionText" mode="TitleCase"/>
					</td>
				</tr>
			</xsl:if>
			<!-- code offese category -->
			<xsl:if test="doc-ext:OffenseDescription or doc-ext:OffenseCategoryText">
				<tr>
					<td class="detailsublabel width25percent">
						<xsl:text>Code:</xsl:text>
					</td>
					<td class="detailvalue width25percent">
						<xsl:apply-templates select="doc-ext:OffenseDescription" mode="TitleCase"/>
					</td>
					<td colspan="2" class="detailvalue width50percent">
						<xsl:apply-templates select="doc-ext:OffenseCategoryText" mode="TitleCase"/>
					</td>
				</tr>
			</xsl:if>
			
		<!-- Juvenile offense and treated as adult -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Juvenile Offense:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="doc-ext:JuvenileOffenderIndicator" mode="FormatBooleanAsYesNo"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Treated as Adult:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="doc-ext:TreatAsAdultIndicator" mode="FormatBooleanAsYesNo"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		
		</table>
	</xsl:template>
	
	<!-- Supervision Information -->
	<xsl:template match="doc-ext:SupervisedReleaseReport" mode="supervisionInfo">
		<br/>
		<span class="detaillabel uppercase">Supervision Information:</span>
		<table>
			<!-- Category and status -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Category:'"/>
				<xsl:with-param name="value1" select="doc-ext:SupervisedRelease/doc-ext:SupervisedReleaseCategory"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
				<xsl:with-param name="label2" select="'Status:'"/>
				<xsl:with-param name="value2" select="doc-ext:SupervisedRelease/j:ActivityStatus/j:StatusText"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Start date and projected end date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Start Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="doc-ext:SupervisedRelease/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
				<xsl:with-param name="label2" select="'Projected End Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="doc-ext:SupervisedRelease/doc-ext:ProjectedEndDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- revocation end date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Revocation End Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="doc-ext:SupervisedRelease/doc-ext:SupervisedReleaseRevocationDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
			</xsl:call-template>
			<!-- Registered offender start date and end date-->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Reg. Sex Off. Start Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="doc-ext:RegisteredOffender/j:RegisteredOffenderStartDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
				<xsl:with-param name="label2" select="'Reg. Sex Off. End Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="doc-ext:RegisteredOffender/j:RegisteredOffenderEndDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Registered offender entry date and registration required -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Reg. Sex Off. Entry Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="doc-ext:RegisteredOffender/j:RegisteredOffenderEntryDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
				<xsl:with-param name="label2" select="'Reg. Required:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="doc-ext:RegisteredOffender/doc-ext:RegisteredOffenderRegistrationRequiredIndicator" mode="FormatBooleanAsYesNo"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Life registration and Two strike indicator -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Life Registration:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="doc-ext:RegisteredOffender/doc-ext:RegisteredOffenderNonExpiringRegistrationIndicator" mode="FormatBooleanAsYesNo"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
				<xsl:with-param name="label2" select="'Two Strike Indicator:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="doc-ext:RegisteredOffender/doc-ext:RegisteredOffenderMultipleIndicator" mode="FormatBooleanAsYesNo"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- absconded -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Absconded:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="doc-ext:RegisteredOffender/doc-ext:RegisteredOffenderAbsconderIndicator" mode="FormatBooleanAsYesNo"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
			</xsl:call-template>
		</table>
	</xsl:template>
	
	<xsl:template match="doc-ext:OffenderSubject" mode="supervisionOfficial">
		<xsl:for-each select="child::node()/j:SupervisionOfficial"> 
			<xsl:apply-templates select="."/>
		</xsl:for-each>
	</xsl:template>
	
	<!-- Supervising Officer -->
	<xsl:template match="j:SupervisionOfficial">
		<br/>
		<span class="detaillabel uppercase">Supervising Officer:</span>
		<table>
		<!-- officer number -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Supervising Officer Number:'"/>
				<xsl:with-param name="value1" select="j:PersonAssignedIDDetails/j:PersonHumanResourcesID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Supervising Phone Number:'"/>
				<xsl:with-param name="value1">
					<xsl:for-each select ="j:PrimaryContactInformation/j:ContactTelephoneNumber"> 
						<xsl:value-of select="j:TelephoneNumberFullID"/>	
						<xsl:text>&#32;</xsl:text>
						<xsl:value-of select="j:TelephoneNumberCommentText"/>	
						<xsl:if test="position() != last()">&#59;&#32;</xsl:if>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
	<!-- Incarceration doc-ext:IncarcerationReport -->
	<xsl:template match="doc-ext:IncarcerationReport">
		<xsl:if test="doc-ext:Incarceration">
			<br/>
			<span class="detaillabel uppercase">Incarceration Information:</span>
			<table>
				<xsl:if test="doc-ext:Incarceration/j:SupervisionAgency">
				 	<tr>
						<td class="detailvalue" colspan="4">
							<xsl:value-of select="doc-ext:Incarceration/j:SupervisionAgency/j:OrganizationName"/>
							<xsl:if test="doc-ext:Incarceration/j:SupervisionAgency/j:OrganizationID/j:ID"> 
								<xsl:text>,&#32;</xsl:text>
								<xsl:value-of select ="doc-ext:Incarceration/j:SupervisionAgency/j:OrganizationID/j:ID"/>
							</xsl:if>
							<xsl:if test="doc-ext:Incarceration/j:SupervisionAgency/j:OrganizationTypeText"> 
								<xsl:text>,&#32;</xsl:text>
								<xsl:apply-templates select="doc-ext:Incarceration/j:SupervisionAgency/j:OrganizationTypeText" mode="TitleCase"/>	
							</xsl:if>
						</td>
					</tr>
				</xsl:if>
				<!-- Start date and projected release date -->
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Start Date:'"/>
					<xsl:with-param name="value1">
						<xsl:apply-templates select="doc-ext:Incarceration/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
					<xsl:with-param name="label2" select="'Projected Release Date:'"/>
					<xsl:with-param name="value2">
						<xsl:apply-templates select="doc-ext:Incarceration/doc-ext:ProjectedEndDate" mode="FormatFullDateAsMMDDYYYY"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
				</xsl:call-template>
				<!--  Status and parole eligible -->
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Status:'"/>
					<xsl:with-param name="value1" select="doc-ext:Incarceration/j:ActivityStatus/j:StatusText"/>
					<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
					<xsl:with-param name="label2" select="'Parole Eligible:'"/>
					<xsl:with-param name="value2">
						<xsl:apply-templates select="doc-ext:Incarceration/doc-ext:ParoleEligibilityDate" mode="FormatFullDateAsMMDDYYYY"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
					<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
				</xsl:call-template>
			</table>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template match="doc-ext:IncarcerationReportOLD">
		<br/>
		<span class="detaillabel uppercase">Incarceration Information:</span>
		<table>
			<!-- Category and status -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Incarcerated at '"/>
				<xsl:with-param name="value1"> 
					<xsl:value-of select="doc-ext:Incarceration/j:SupervisionAgency/j:OrganizationName"/>
					<xsl:if test="doc-ext:Incarceration/j:SupervisionAgency/j:OrganizationID/j:ID"> 
						<xsl:text>,&#32;</xsl:text>
						<xsl:value-of select ="doc-ext:Incarceration/j:SupervisionAgency/j:OrganizationID/j:ID"/>
					</xsl:if>
					<xsl:if test="doc-ext:Incarceration/j:SupervisionAgency/j:OrganizationTypeText"> 
						<xsl:text>,&#32;</xsl:text>
						<xsl:apply-templates select="doc-ext:Incarceration/j:SupervisionAgency/j:OrganizationTypeText" mode="TitleCase"/>	
					</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
			</xsl:call-template>
			<!-- Start date and projected release date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Start Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="doc-ext:Incarceration/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
				<xsl:with-param name="label2" select="'Projected Release Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="doc-ext:Incarceration/doc-ext:ProjectedEndDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!--  Status and parole eligible -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Status:'"/>
				<xsl:with-param name="value1" select="j:ActivityStatus/j:StatusText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
				<xsl:with-param name="label2" select="'Parole Eligible:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="doc-ext:Incarceration/doc-ext:ParoleEligibilityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
	<xsl:template match="j:Binary" mode="imageInfo">
		<br/>
		<xsl:if test="position() = 1">
			<span class="detaillabel uppercase">Image Information:</span>
		</xsl:if>	
		<xsl:variable name="oboORI" select="/doj:DOCResponseDocument/doj:Header/doj-ext:SubmissionRequestorDetails/doj-ext:SubmissionRequestor.OnBehalfOfOrganization/doj-ext:OrganizationORIID/doj-ext:ID" />
		<xsl:variable name="imageID" select="j:BinaryReferenceID/j:ID"/>
	 	<form id="photoRequest_{$imageID}_{$oboORI}" action="/secure/personsearch/builddocphoto.jsp" method="post" style="display:inline" >   
			<input name="image" type="hidden" value="{$imageID}" />	
			<xsl:if test="$oboORI">
				<input name="ori" type="hidden" value="{$oboORI}" />			
			</xsl:if>	
		</form>
		<table>
		   <tr>
				<td class="detailsublabel width25percent">Photo URL:</td>
				<td class="detailvalue width75percent">
				<a href="#" onclick="confirmPhoto('photoRequest_{$imageID}_{$oboORI}', '{$from}');" > 
						<xsl:value-of select="j:BinaryReferenceID/j:ID"/>      
					</a>
					<xsl:if test="j:BinaryTypeText or j:BinaryDescriptionText"> 
						<br/>
					</xsl:if>
					<xsl:if test="j:BinaryTypeText"> 
						<xsl:value-of select="j:BinaryTypeText"/>
						 <xsl:text>, </xsl:text>
					</xsl:if>
					<xsl:value-of select="j:BinaryDescriptionText"/> 
				</td>
			</tr>
		</table>
	</xsl:template>

	<!-- Template for displayng the image and data -->
	<xsl:template match="j:Binary" mode="image">
		<xsl:variable name="responseID" select="/doj:DOCResponseDocument/@doj-ext:responseID"/>
		<img class="image" src="image?ETIMEResponseId={$responseID}&amp;ImageIndex=0&amp;Resize=false" alt="IMG"/>
		<br/>	
			<table cellspacing="0" style="width:auto;">
				<tr>
					<td colspan="2"><xsl:apply-templates select="../doc-ext:OffenderSubject/j:PersonName" /></td>
				</tr>
				<tr>
					<td colspan="2" class="detailvalue"><xsl:apply-templates select="../doc-ext:OffenderSubject/j:PersonBirthDate" mode="FormatFullDateAsMMDDYYYY"/></td>				
				</tr>
 				<xsl:if test="j:BinaryTypeText or j:BinaryDescriptionText">
 				<tr><td>&#160;</td></tr>
 				<tr><td>&#160;</td></tr>
					<tr>
						<td colspan="2" class="detailvalue">
							<xsl:if test="j:BinaryTypeText">
								<xsl:value-of select="j:BinaryTypeText"/>
								<xsl:if test="j:BinaryDescriptionText">
									<xsl:text>,&#32;</xsl:text>
								</xsl:if>
							</xsl:if>
							<xsl:value-of select="j:BinaryDescriptionText"/>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="j:BinaryCaptureDate">
					<tr>
						<td colspan="2" class="detailvalue">
							<xsl:text>Taken&#32;</xsl:text>
							<xsl:apply-templates select="j:BinaryCaptureDate" mode="FormatFullDateAsMMDDYYYY"/>
						</td>
					</tr>
				</xsl:if>
				<tr><td colspan="2">&#160;</td></tr>
 				<tr><td colspan="2">&#160;</td></tr>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Photo URL:'"/>
					<xsl:with-param name="value1">
					<xsl:apply-templates select="j:BinaryReferenceID/j:ID"/>
				</xsl:with-param>
					<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width20percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width80percent'"/>
				</xsl:call-template>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Photo Details:'"/>
					<xsl:with-param name="value1">
						<xsl:if test="j:BinaryFormatText">
							<xsl:value-of select="j:BinaryFormatText"/>
							<xsl:if test="j:BinarySizeValue">
								<xsl:text>,&#32;</xsl:text>
							</xsl:if>
						</xsl:if>
						<xsl:value-of select="j:BinarySizeValue"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width20percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width80percent'"/>
				</xsl:call-template>
		</table>
		
	</xsl:template>
	
 
</xsl:transform> 