<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:dot-drv="http://www.doj.state.wi.us/dles/cib/dot/response/broker/driver"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/dot/response" 
  xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"
    xmlns:xalan="http://xml.apache.org/xslt"
    exclude-result-prefixes="xsl xsi dot-drv doj j xalan"
>
	<xsl:import href="../common.xsl"/>
	<xsl:import href="../util.xsl"/>
  <xsl:param name="from"/>
  <xsl:param name="readOnly"/>
  <xsl:param name="executionUrl"/>
  <xsl:param name="showCertDriverStatusLink" />
  <xsl:param name="imageBase">
    <xsl:text>../../images/</xsl:text>
  </xsl:param>
  <xsl:param name="responseId">
    <xsl:value-of select="doj:DOTResponseDocument/@*[local-name()='responseID']"/>
  </xsl:param>
	<xsl:output method="html"
                version="4.01"
                encoding="UTF-8" 
                omit-xml-declaration="yes"
                doctype-public="-//W3C//DTD HTML 4.01//EN"
                doctype-system="http://www.w3.org/TR/html4/strict.dtd"
                indent="yes"
                media-type="text/html"
                xalan:indent-amount="2"/>

	<xsl:template match="/">
    <xsl:choose>
      <xsl:when test="$from='ebc'">
        <xsl:call-template name="html_main"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="html_head_extension"/>
        <xsl:call-template name="html_body"/>
      </xsl:otherwise>
    </xsl:choose>
	</xsl:template>

	<xsl:template name="html_title">TIME - Driver</xsl:template>

	<xsl:template name="html_head_extension">
		<style type="text/css">
			#dataserviceimage {
				float: right;
			}
			
			p.certifiedstatus {
				margin-top: 10px;
				margin-bottom: 10px;
				vertical-align: text-top;
				color: red;
			}
			
			img.driverimage {
				float: right;
				height: 150px;
				width: 125px;
			}
			
			img.pagerefimage {
				float: right;
				border: none;
				padding-right: 25px;
				padding-left: 15px;
			}
			
			.newsection {
				margin-top: 15px;
			}
			
			.filetype {
				float: none;  /* Override the float setting inherited from external stylesheets */
			}
			
			.caveat {
				color: teal;  /* Override the color inherited from external stylesheets */
			}
			
			.licensetypetitle {
				text-transform: none;  /* Override inherited uppercase setting */
			}
     
      .blueRegular {
        color: blue;
      }
     
      .redRegular {
        color: red;
      }

      .redBold {
        color: red;
        font-weight: bold;
      }
      
      .subjecttitle {
        text-transform: none;  /* Override the text-transform setting inherited from external stylesheets */
      }
      
      .tealRegular {
        color: teal;
      }

      .tealBold {
        color: teal;
        font-weight: bold;
      }
      
      .tableName {
        padding-right: 20px;
        white-space: nowrap;
      }
      
      .tableValue {
        padding-right: 20px;
        text-transform: capitalize;
      }

      .savexmlbuttonimage {
		width: 110px;
		height: 24px;
		border-style: none;
		background-color : transparent;
		cursor: pointer;
		margin-top: 10px;
		margin-bottom: 10px;
      }
		</style>
	  <script language="JavaScript">
  		function copyxml(){
			document.form1.savexmltext1.value = document.form2.savexmltext2.value;
		}
	  </script>
	</xsl:template>

	<xsl:template name="html_body">
	  <xsl:element name="img">
	    <xsl:attribute name="id">dataserviceimage</xsl:attribute>
	    <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'DOT.gif')"/></xsl:attribute>
	    <xsl:attribute name="alt">Wisconsin Department of Transportation</xsl:attribute>
	  </xsl:element>
 	  <!-- Not all of the following will be applicable on a single response -->
		<xsl:apply-templates select="doj:DOTResponseDocument/doj:Result/doj:ResultText"/>
		<xsl:apply-templates select="doj:DOTResponseDocument/doj:Result/dot-drv:DOTDriver/dot-drv:Response/dot-drv:ResponseText"/>
    <xsl:apply-templates select="doj:DOTResponseDocument/doj:Result/dot-drv:DOTDriver/dot-drv:Response/dot-drv:DriverRecord"/>
    <xsl:apply-templates select="doj:DOTResponseDocument/doj:Result/dot-drv:DOTDriver/dot-drv:Response/dot-drv:PossibleHits"/>
	</xsl:template>

  <xsl:template match="dot-drv:Accident">
    <tr>
      <td class="tableName tealRegular">
        <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
          <xsl:with-param name="YYYY-MM-DD" select="dot-drv:AccidentDate"/>
        </xsl:call-template>
      </td>
      <td class="tableName">
      </td>
      <td class="tableValue tealRegular">
        <span class="blueRegular">
          <xsl:text>Accident</xsl:text>
        </span>
        <xsl:text> # </xsl:text>
        <xsl:value-of select="dot-drv:AccidentNumber"/>
        <xsl:text> </xsl:text>
        <xsl:choose>
          <xsl:when test="j:DrivingAccidentSeverityText">
            <xsl:apply-templates select="j:DrivingAccidentSeverityText" mode="TitleCase"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="dot-drv:DrivingAccidentSeverityCode"/>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:text> </xsl:text>
        <xsl:choose>
          <xsl:when test="dot-drv:IncidentTypeText">
            <xsl:apply-templates select="dot-drv:IncidentTypeText" mode="TitleCase"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="dot-drv:IncidentTypeCode"/>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:text> </xsl:text>
        <xsl:choose>
          <xsl:when test="j:ActivityPrimaryWorker/j:PersonAssignmentUnit.Organization/j:OrganizationDescriptionText">
            <xsl:text>On Duty:</xsl:text>
            <xsl:apply-templates select="j:ActivityPrimaryWorker/j:PersonAssignmentUnit.Organization/j:OrganizationDescriptionText" mode="TitleCase"/>
          </xsl:when>
          <xsl:when test="j:ActivityPrimaryWorker/j:PersonAssignmentUnit.Organization/j:OrganizationTypeText">
            <xsl:text>On Duty:</xsl:text>
            <xsl:apply-templates select="j:ActivityPrimaryWorker/j:PersonAssignmentUnit.Organization/j:OrganizationTypeText" mode="TitleCase"/>
          </xsl:when>
        </xsl:choose>
        <xsl:if test="dot-drv:ProductClassCode">
          <xsl:text> Class: </xsl:text>
          <xsl:value-of select="dot-drv:ProductClassCode"/>
        </xsl:if>
        <xsl:for-each select="dot-drv:ClassCode">
          <xsl:text> Endorsement: </xsl:text>
          <xsl:value-of select="."/>
        </xsl:for-each>
        <xsl:if test="j:IncidentLocation/j:LocationAddress/j:LocationCountyName">
          <xsl:text> County: </xsl:text>
          <xsl:apply-templates select="j:IncidentLocation/j:LocationAddress/j:LocationCountyName" mode="TitleCase"/>
        </xsl:if>
        <xsl:if test="dot-drv:OutOfStateAccident/j:VehicleCMVIndicator">
          <xsl:text> Out-of-State Commercial Accident: </xsl:text>
          <xsl:call-template name="true-false_to_Y-N">
            <xsl:with-param name="true-false" select="dot-drv:OutOfStateAccident/j:VehicleCMVIndicator"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:text> </xsl:text>
        <xsl:apply-templates select="dot-drv:OutOfStateAccident/j:LocationStateName" mode="TitleCase"/>
        <xsl:text> </xsl:text>
        <xsl:for-each select="dot-drv:WithdrawalCaseNumber">
          <xsl:if test="position() > 1">
            <xsl:text>, </xsl:text>
          </xsl:if>
          <xsl:value-of select="."/>
        </xsl:for-each>
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="dot-drv:Arrest">
    <tr>
      <td class="tableName tealRegular">
        <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
          <xsl:with-param name="YYYY-MM-DD" select="j:ActivityDate"/>
        </xsl:call-template>
      </td>
      <td class="tableName">
      </td>
      <td class="tableValue tealRegular">
        <span class="blueRegular">
          <xsl:text>Arrest </xsl:text>
        </span>
        <xsl:value-of select="j:ArrestAgency/j:OrganizationName"/>
        <xsl:if test="dot-drv:UniformTrafficCitation/j:ID">
          <xsl:text> Citation: </xsl:text>
          <xsl:value-of select="dot-drv:UniformTrafficCitation/j:ID"/>
          <xsl:text>-</xsl:text>
          <xsl:value-of select="dot-drv:UniformTrafficCitation/dot-drv:CheckDigit"/>
        </xsl:if>
        <xsl:text> </xsl:text>
        <xsl:apply-templates select="dot-drv:ArrestTypeDescription" mode="TitleCase"/>
        <xsl:for-each select="dot-drv:PersonIntoxication">
          <br/>
          <xsl:text> </xsl:text>
          <xsl:apply-templates select="j:IntoxicationTestDescriptionText" mode="TitleCase"/>
          <xsl:text> </xsl:text>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="j:IntoxicationTestDate"/>
          </xsl:call-template>
          <xsl:if test="j:IntoxicationLevelText">
            <xsl:text> BAC= </xsl:text>
            <xsl:value-of select="j:IntoxicationLevelText"/>
          </xsl:if>
        </xsl:for-each>
      </td>
    </tr>
  </xsl:template>
    
	<xsl:template match="dot-drv:DriverRecord">
		<h1 class="filetype">
			<xsl:choose>
				<xsl:when test="count(dot-drv:DriverLicenseDetails/dot-drv:DriverLicense) = 1 
				                and dot-drv:DriverLicenseDetails/dot-drv:DriverLicense[dot-drv:DriverLicenseTypeText = 'ID']">
					<xsl:text>Personal ID</xsl:text>
				</xsl:when>
				<xsl:when test="count(dot-drv:DriverLicenseDetails/dot-drv:DriverLicense) > 1 
				                and dot-drv:DriverLicenseDetails/dot-drv:DriverLicense[dot-drv:DriverLicenseTypeText = 'ID']">
					<xsl:text>Driver Record and Personal ID</xsl:text>
				</xsl:when>
			    <xsl:when test="dot-drv:PersonDetails/j:PersonBiometricDetails/j:PersonDigitalImage">
			      <xsl:element name="img">
			        <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'camera.gif')"/></xsl:attribute>
			        <xsl:attribute name="alt">DOT Driver Photo</xsl:attribute>
			      </xsl:element>
			      
			    	<xsl:text>&#160;&#160;</xsl:text>
					<xsl:text>Driver Photo</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Driver Record</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</h1>
		
		<xsl:for-each select="dot-drv:DriverLicenseDetails/j:CaveatText">
			<div class="caveat">
				<xsl:apply-templates select="." mode="TitleCase"/>
			</div>
		</xsl:for-each>
		<xsl:if test="dot-drv:PersonDetails/j:PersonBiometricDetails/j:PersonDigitalImage/@sensitivityText">
				<span class="redBold">
				<p style="font-family: times new roman; text-transform:uppercase;">
					<xsl:value-of select="dot-drv:PersonDetails/j:PersonBiometricDetails/j:PersonDigitalImage/@sensitivityText"/>
				</p>
				</span>
		</xsl:if>

	<table border="0" width="100%">
	<tr>
      <td align="left">
        <xsl:if test="$from='ebc' and $showCertDriverStatusLink='yes'">
		  <p class="certifiedstatus">
		    <xsl:element name="img">
		      <xsl:attribute name="src">
		        <xsl:value-of select="concat($imageBase, 'DOT.gif')"></xsl:value-of>
		      </xsl:attribute>
		      <xsl:attribute name="height">25</xsl:attribute>
		      <xsl:attribute name="width">25</xsl:attribute>
		      <xsl:attribute name="alt">Wisconsin Department of Transportation</xsl:attribute>
		    </xsl:element>
		    <xsl:text>&#160;&#160;</xsl:text>
			  <a href="DOTDriverCert?erid={$REQUEST_DATA/erid}">Certified Driver Status</a>
		  </p>
	    </xsl:if>	    
 	 </td>    
	 <td align="right">
		<form name="form1" method="post" action="/servlet/SaveXMLResponseServlet">		
				<textarea name="saveresponsetext1" id="saveresponsetext1" style="display:none" rows="1" cols="1">
					<xsl:text>DL_</xsl:text>
					<xsl:value-of select="dot-drv:ProductDetails/j:DriverAuthorizationID.Detailed/j:ID"/>
				</textarea>
			   	<textarea name="savexmltext1" id="savexmltext1" style="display:none" rows="1" cols="1"/>
		    <table border="0" align="right" cellspacing="0" cellpadding="0">
		     <tr>
		        <td></td>		               
				<xsl:choose>
					<xsl:when test="dot-drv:PersonDetails/j:PersonBiometricDetails/j:PersonDigitalImage">
						<td></td>
					</xsl:when>
				 	<xsl:otherwise>
				 	  <xsl:if test="$from != 'firearm'">
							<td align="right" valign="bottom" height="24">
					    		<button type="submit" class="savexmlbuttonimage" name="savexmlbutton1" onclick="copyxml();" >
					    			<u>
					    			  <xsl:element name="img">
					    			    <xsl:attribute name="src">
					    			      <xsl:value-of select="concat($imageBase, 'savexmlfileicon.gif')"></xsl:value-of>
					    			    </xsl:attribute>
					    			    <xsl:attribute name="height">24</xsl:attribute>
					    			    <xsl:attribute name="width">100</xsl:attribute>
					    			    <xsl:attribute name="alt">Save XML File</xsl:attribute>
					    			  </xsl:element>
					    			</u>
					    		</button>
					    	</td>	
				 	  </xsl:if>
					</xsl:otherwise>
			    </xsl:choose>	
		     </tr>
		    </table>
		  </form>
		</td> 
	   </tr>
	  </table> 
		<hr/>
		
		<!-- Allow space for the driver image -->
		<xsl:if test="dot-drv:PersonDetails/j:PersonBiometricDetails/j:PersonDigitalImage">
				<xsl:variable name="responseID" select="/doj:DOTResponseDocument/@doj-ext:responseID"/>
				<img class="driverimage" src="image?ETIMEResponseId={$responseID}&amp;ImageIndex=0&amp;Resize=false" alt="IMG"/>
				<br/><br/>					
		</xsl:if>
		<!-- Record Details image link -->
		<xsl:if test="dot-drv:DriverHistoryRecordDetails">
		<div style="align:right;">
		  <a href="#recorddetails{$responseId}">
		    <xsl:element name="img">
		      <xsl:attribute name="class">pagerefimage</xsl:attribute>
		      <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'RecordDetails.jpg')"/></xsl:attribute>
		      <xsl:attribute name="alt">Record Details</xsl:attribute>
		    </xsl:element>
		  </a>
			</div>
		</xsl:if>
		
		<!-- Driver Name -->
		<div class="subjecttitle">
		  <!-- Call template to display primary name -->
		  <xsl:apply-templates select="dot-drv:PersonDetails/j:PersonName" mode="PrimaryFirstMiddleLastSuffix"/>
		</div>
		<div class="tableValue tealRegular">
		  <!-- Call template to display recorded name -->
		  <xsl:apply-templates select="dot-drv:PersonDetails/j:PersonName" mode="RecordedFirstMiddleLastSuffix" />
		  <xsl:if test="dot-drv:ProductDetails/dot-drv:AdditionalInformation/dot-drv:CardSurfaceName">
		    <br />
		    <xsl:text>Name on Product: </xsl:text>
		  	<xsl:value-of select="dot-drv:ProductDetails/dot-drv:AdditionalInformation/dot-drv:CardSurfaceName" />
		  </xsl:if>
		</div>	
		<xsl:apply-templates select="dot-drv:ProductDetails"/>
		
		<!-- Driver Image Details -->
		<xsl:if test="dot-drv:PersonDetails/j:PersonBiometricDetails/j:PersonDigitalImage">
		<xsl:variable name="imageID">
			<xsl:call-template name="trim">
			 	<xsl:with-param name="s" select="dot-drv:PersonDetails/j:PersonBiometricDetails/j:PersonDigitalImage/j:BinaryReferenceID/j:ID"/>			
			</xsl:call-template>
		</xsl:variable>
		<table cellspacing="0" style="width:auto;">
		<tr>
         	<td class="width15percent tableValue tealRegular">
					<div class="detaillabel">
						<xsl:text> Image Id: </xsl:text>
					</div>
		 </td>
         	<td class="tableValue tealRegular">	       					
					<xsl:value-of select="dot-drv:PersonDetails/j:PersonBiometricDetails/j:PersonDigitalImage/j:BinaryReferenceID/j:ID"/>
		  </td>
		</tr>
		<tr>
          <td  class="width15percent tableValue tealRegular">
					<div class="detaillabel">
						<xsl:text> Photo Taken Date: </xsl:text>
					</div>
		  </td>
          <td class="tableValue tealRegular">
          			<xsl:choose>
          				<xsl:when test="$imageID='NOTFOUND'">
          					<xsl:text>&#160;&#160;</xsl:text>
          				</xsl:when>
          				<xsl:otherwise>
         					<xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
                        		<xsl:with-param name="YYYY-MM-DD" select="dot-drv:PersonDetails/j:PersonBiometricDetails/j:PersonDigitalImage/j:BinaryCaptureDate"/>
                    		</xsl:call-template>
                    	</xsl:otherwise>          				
          			</xsl:choose>		
		  </td>
		</tr>                  	
        </table>			
		</xsl:if>
    <div class="newsection">
    <xsl:if test="dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonSexText
                 or dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonRaceText
                 or dot-drv:PersonDetails/dot-drv:PersonBirthDateText 
                 or dot-drv:PersonDetails/j:PersonDeathDate
                 or dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonHeightMeasure
                 or dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonWeightMeasure
                 or dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonEyeColorText
                 or dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonHairColorText
                 or dot-drv:PersonDetails/dot-drv:PersonOrganDonorIndicator
                 or dot-drv:PersonDetails/j:Residence/j:LocationStreet/j:StreetFullText
                 or dot-drv:PersonDetails/j:Residence/j:AddressMailDeliveryUnitText
                 or dot-drv:PersonDetails/j:Residence/j:LocationCityName
                 or dot-drv:PersonDetails/j:Residence/j:LocationPostalCodeExtensionID/j:ID
                 or dot-drv:PersonDetails/j:PersonAssignedIDDetails/j:PersonNationalID
                 or dot-drv:PersonDetails/j:Residence/j:LocationCountyName
                 or dot-drv:PersonDetails/j:Residence/j:LocationCountyName
                 or dot-drv:PersonDetails/j:Residence/@j:reportedDate">
      <span class="detaillabel">
        <xsl:text>PERSON DATA:</xsl:text>
      </span>
      <table cellspacing="0" style="width:auto;">
        <tr>
          <xsl:if test="dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonSexText">
            <td class="tableValue tealRegular">
              <xsl:call-template name="Sex_to_text">
                <xsl:with-param name="SexCode" select="dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonSexText"/>
              </xsl:call-template>
            </td>
          </xsl:if>
          <xsl:if test="dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonRaceText">
            <td class="tableValue tealRegular">
              <xsl:call-template name="Race_to_text">
                <xsl:with-param name="RaceCode" select="dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonRaceText"/>
              </xsl:call-template>
            </td>
          </xsl:if>
          <xsl:if test="dot-drv:PersonDetails/dot-drv:PersonBirthDateText">
            <td class="tableValue tealRegular">
              <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
                <xsl:with-param name="YYYY-MM-DD" select="dot-drv:PersonDetails/dot-drv:PersonBirthDateText"/>
              </xsl:call-template>
            </td>
          </xsl:if>
          <xsl:if test="dot-drv:PersonDetails/j:PersonDeathDate">
            <td class="tableValue tealRegular">
              <xsl:text>Deceased:</xsl:text>
              <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
                <xsl:with-param name="YYYY-MM-DD" select="dot-drv:PersonDetails/j:PersonDeathDate"/>
              </xsl:call-template>
            </td>
          </xsl:if>
        </tr>
      </table>
      <table cellspacing="0" style="width:auto;">
        <tr>
          <xsl:if test="dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonHeightMeasure">
            <td class="tableValue tealRegular">
              <xsl:value-of select="substring(dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonHeightMeasure, 1, 1)"/><xsl:text>'</xsl:text><xsl:value-of select="substring(dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonHeightMeasure, 2)"/><xsl:text>"</xsl:text>
            </td>
          </xsl:if>
          <xsl:if test="dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonWeightMeasure">
            <td class="tableValue tealRegular">
              <xsl:value-of select="dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonWeightMeasure"/>
              <xsl:text> lbs</xsl:text>
            </td>
          </xsl:if>
          <xsl:if test="dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonEyeColorText">
            <td class="tableValue tealRegular">
              <xsl:call-template name="EyeColor_to_text">
                <xsl:with-param name="EyeColorCode" select="dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonEyeColorText"/>
              </xsl:call-template>
              <xsl:text> Eyes</xsl:text>
            </td>
          </xsl:if>
          <xsl:if test="dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonHairColorText">
            <td class="tableValue tealRegular">
              <xsl:call-template name="HairColor_to_text">
                <xsl:with-param name="HairColorCode" select="dot-drv:PersonDetails/j:PersonPhysicalDetails/j:PersonHairColorText"/>
              </xsl:call-template>
              <xsl:text> Hair</xsl:text>
            </td>
          </xsl:if>
          <xsl:if test="dot-drv:PersonDetails/dot-drv:PersonOrganDonorIndicator">
            <td class="tableValue tealRegular">
              <xsl:text>Organ Donor: </xsl:text>
              <xsl:call-template name="true-false_to_Y-N">
                <xsl:with-param name="true-false" select="dot-drv:PersonDetails/dot-drv:PersonOrganDonorIndicator"/>
              </xsl:call-template>
            </td>
          </xsl:if>
        </tr>
      </table>
      <table cellspacing="0" style="width:auto;">
        <tr>
          <td class="tableValue tealRegular">
            <xsl:for-each select="dot-drv:PersonDetails/j:Residence/j:LocationStreet/j:StreetFullText">
              <xsl:apply-templates select="." mode="TitleCase"/>
              <xsl:text> </xsl:text>
            </xsl:for-each>
            <xsl:if test="dot-drv:PersonDetails/j:Residence/j:AddressMailDeliveryUnitText">
              <xsl:text>PO Box </xsl:text>
              <xsl:apply-templates select="dot-drv:PersonDetails/j:Residence/j:AddressMailDeliveryUnitText" mode="TitleCase"/>
            </xsl:if>
          </td>
        </tr>
        <tr>
          <td class="tableValue tealRegular">
            <xsl:if test="dot-drv:PersonDetails/j:Residence/j:LocationCityName">
              <xsl:apply-templates select="dot-drv:PersonDetails/j:Residence/j:LocationCityName" mode="TitleCase"/>,
            </xsl:if>
            <xsl:text> </xsl:text>
            <xsl:value-of select="dot-drv:PersonDetails/j:Residence/j:LocationStateName"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="dot-drv:PersonDetails/j:Residence/j:LocationPostalCodeID/j:ID"/>
            <xsl:if test="dot-drv:PersonDetails/j:Residence/j:LocationPostalCodeExtensionID/j:ID">
              <xsl:text>-</xsl:text>
              <xsl:value-of select="dot-drv:PersonDetails/j:Residence/j:LocationPostalCodeExtensionID/j:ID"/>
            </xsl:if>
            <xsl:if test="dot-drv:PersonDetails/j:PersonAssignedIDDetails/j:PersonNationalID" >
              <xsl:text> </xsl:text>
              <xsl:value-of select="dot-drv:PersonDetails/j:PersonAssignedIDDetails/j:PersonNationalID/j:ID" />
            </xsl:if>
            <xsl:if test="dot-drv:PersonDetails/j:Residence/j:LocationCountyName">
              <xsl:text> County: </xsl:text>
              <xsl:apply-templates select="dot-drv:PersonDetails/j:Residence/j:LocationCountyName" mode="TitleCase"/>
            </xsl:if>
            <xsl:if test="dot-drv:PersonDetails/j:Residence/@j:reportedDate">
              <br />
              <xsl:text> Address Updated: </xsl:text>
              <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
          		<xsl:with-param name="YYYY-MM-DD" select="dot-drv:PersonDetails/j:Residence/@j:reportedDate"/>
       		  </xsl:call-template>
            </xsl:if>
          </td>
        </tr>
      </table>
    </xsl:if>
    </div>
    <xsl:if test="dot-drv:DriverHistoryRecordDetails/dot-drv:InsuranceFilingTerminationDate">
      <div class="newsection">
        <table cellspacing="0" style="width:auto;">
          <tr>
            <td class="tableName detaillabel">
              <xsl:text>INSURANCE FILING PERIOD TERMINATION DATE: </xsl:text>
            </td>
            <td class="tableValue tealRegular">
              <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
                <xsl:with-param name="YYYY-MM-DD" select="dot-drv:DriverHistoryRecordDetails/dot-drv:InsuranceFilingTerminationDate"/>
              </xsl:call-template>
            </td>
          </tr>
        </table>
      </div>
    </xsl:if>
    <xsl:if test="dot-drv:PersonDetails.Former">
      <div class="newsection">
        <table cellspacing="0" style="width:auto;">
          <xsl:for-each select="dot-drv:PersonDetails.Former">
            <tr>
              <td class="tableName detaillabel">
                <xsl:text>FORMER:</xsl:text>
              </td>
              <xsl:choose>
	              <xsl:when test="dot-drv:DOTNotifiedDate">
	              	<td class="tableValue tealRegular">
	                	<xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
	                	  <xsl:with-param name="YYYY-MM-DD" select="dot-drv:DOTNotifiedDate"/>
	                	</xsl:call-template>
	              	</td>
	              </xsl:when>
	              <xsl:otherwise>
					<td>&#160;</td>              
	              </xsl:otherwise>
              </xsl:choose>
              <td class="tableValue tealRegular">
              <!-- Call template to get the name that's not recorded -->
              <xsl:call-template name="FormerFirstMiddleLastSuffix" />
                <xsl:text> </xsl:text>
                <xsl:if test="dot-drv:PersonBirthDateText">
                  <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
                    <xsl:with-param name="YYYY-MM-DD" select="dot-drv:PersonBirthDateText"/>
                  </xsl:call-template>
                  <xsl:text> </xsl:text>
                </xsl:if>
                <xsl:if test="j:PersonPhysicalDetails/j:PersonSexText">
                  <xsl:call-template name="Sex_to_text">
                    <xsl:with-param name="SexCode" select="j:PersonPhysicalDetails/j:PersonSexText"/>
                  </xsl:call-template>
                  <xsl:text> </xsl:text>
                </xsl:if>
                <xsl:value-of select="j:DriverLicense/j:DriverAuthorizationID.Detailed/j:ID"/>
              </td>
            </tr>
		<!-- Call template to get the recorded name-->
            <xsl:call-template name="FormerRecordedFirstMiddleLastSuffix" />
            <xsl:if test="position() != last()">
              <tr>
                <td colspan="3">&#160;</td>
              </tr>
            </xsl:if>
          </xsl:for-each>
        </table>
      </div>
    </xsl:if>
    <div class="newsection">
      <xsl:if test="dot-drv:DriverHistoryRecordDetails/dot-drv:PriorOWIViolationsCount
                 or dot-drv:DriverHistoryRecordDetails/dot-drv:PriorOAROWSOWDCount
                 or dot-drv:DriverHistoryRecordDetails/dot-drv:ProductNotation 
                 or dot-drv:DriverHistoryRecordDetails/dot-drv:SpecialNotation
                 or dot-drv:DriverHistoryRecordDetails/dot-drv:OutOfStateProduct
                 or dot-drv:DriverHistoryRecordDetails/dot-drv:Event/dot-drv:CorrespondenceInformation
                 or dot-drv:DriverHistoryRecordDetails/dot-drv:DisqualifyNonCDLText">
      <a name="recorddetails{$responseId}">
        <span class="detaillabel">
          <xsl:text>Record Details:</xsl:text>
        </span>
	  </a>
	  <xsl:if test="dot-drv:DriverHistoryRecordDetails/dot-drv:PriorOWIViolationsCount 
	  				or dot-drv:DriverHistoryRecordDetails/dot-drv:PriorOAROWSOWDCount">
	    <table cellspacing="0" style="width:auto;">
          <xsl:if test="dot-drv:DriverHistoryRecordDetails/dot-drv:PriorOWIViolationsCount">
            <tr>
              <td class="tableName tealBold">
                <xsl:text>Prior OWI Count:</xsl:text>
              </td>
              <td class="tableValue tealBold">
                <xsl:value-of select="dot-drv:DriverHistoryRecordDetails/dot-drv:PriorOWIViolationsCount"/>
              </td>
            </tr>
          </xsl:if>
          <xsl:if test="dot-drv:DriverHistoryRecordDetails/dot-drv:PriorOAROWSOWDCount">
            <tr>
              <td class="tableName tealBold">
            	  <xsl:text>Prior OWS OAR OWD Count:</xsl:text>
              </td>
              <td class="tableValue tealBold">
                <xsl:value-of select="dot-drv:DriverHistoryRecordDetails/dot-drv:PriorOAROWSOWDCount"/>
              </td>
            </tr>
          </xsl:if>
        </table>
        <p/>
	  </xsl:if>
      <xsl:if test="dot-drv:DriverHistoryRecordDetails/dot-drv:ProductNotation">
        <table cellspacing="0" style="width:auto;">
          <xsl:for-each select="dot-drv:DriverHistoryRecordDetails/dot-drv:ProductNotation">
            <tr>
              <td class="tableName blueRegular">
                <xsl:text>Notation:</xsl:text>
              </td>
              <td class="tableValue tealRegular">
                <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
                  <xsl:with-param name="YYYY-MM-DD" select="j:ActivityDate"/>
                </xsl:call-template>
                <xsl:if test="j:ActivityEndDate">
                  <xsl:text> </xsl:text>
                  <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
                    <xsl:with-param name="YYYY-MM-DD" select="j:ActivityEndDate"/>
                  </xsl:call-template>
                </xsl:if>
                <xsl:text> </xsl:text>
                <xsl:apply-templates select="j:ActivityDescription" mode="TitleCase"/>
              </td>
            </tr>
          </xsl:for-each>
        </table>
      </xsl:if>
      <xsl:if test="dot-drv:DriverHistoryRecordDetails/dot-drv:SpecialNotation">
        <table cellspacing="0" style="width:auto;">
          <tr>
            <td class="tableName blueRegular">
              <xsl:text>Notation:</xsl:text>
            </td>
            <td class="tableValue tealRegular">
              <xsl:apply-templates select="dot-drv:DriverHistoryRecordDetails/dot-drv:SpecialNotation" mode="TitleCase"/>
            </td>
          </tr>
        </table>
      </xsl:if>
      <xsl:if test="dot-drv:DriverHistoryRecordDetails/dot-drv:OutOfStateProduct">
        <table cellspacing="0" style="width:auto;">
          <xsl:for-each select="dot-drv:DriverHistoryRecordDetails/dot-drv:OutOfStateProduct">
            <tr>
              <td class="tableName blueRegular">
                <xsl:text>Notation:</xsl:text>
              </td>
              <td class="tableValue tealRegular">
                <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
                  <xsl:with-param name="YYYY-MM-DD" select="j:ActivityDate"/>
                </xsl:call-template>
                <xsl:text> Moved </xsl:text>
                <xsl:apply-templates select="dot-drv:FromTo" mode="TitleCase"/>
                <xsl:text> </xsl:text>
                <xsl:apply-templates select="j:LocationStateName" mode="TitleCase"/>
              </td>
            </tr>
          </xsl:for-each>
        </table>
      </xsl:if>
      <xsl:if test="dot-drv:DriverHistoryRecordDetails/dot-drv:Event/dot-drv:CorrespondenceInformation">
        <table cellspacing="0" style="width:auto;">
          <xsl:for-each select="dot-drv:DriverHistoryRecordDetails/dot-drv:Event/dot-drv:CorrespondenceInformation">
            <tr>
              <td class="tableName blueRegular">
                <xsl:text>Notation:</xsl:text>
              </td>
              <td class="tableValue tealRegular">
                <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
                  <xsl:with-param name="YYYY-MM-DD" select="dot-drv:CorrespondenceMailedDate"/>
                </xsl:call-template>
                <xsl:text> </xsl:text>
                <xsl:apply-templates select="dot-drv:CorrespondenceVersionName" mode="TitleCase"/>
              </td>
            </tr>
          </xsl:for-each>
        </table>
      </xsl:if>
      <xsl:if test="dot-drv:DriverHistoryRecordDetails/dot-drv:DisqualifyNonCDLText">
        <table cellspacing="0" style="width:auto;">
          <tr>
            <td class="tableName blueRegular">
              <xsl:text>Notation:</xsl:text>
            </td>
            <td class="tableValue tealRegular">
              <xsl:apply-templates select="dot-drv:DriverHistoryRecordDetails/dot-drv:DisqualifyNonCDLText" mode="TitleCase"/>
            </td>
          </tr>
        </table>
      </xsl:if>
      <p/>
    </xsl:if>
    </div>
    <table cellspacing="0" style="width:auto;">
      <xsl:apply-templates select="dot-drv:DriverHistoryRecordDetails/dot-drv:Event"/>
    </table>
  </xsl:template>

  <xsl:template match="dot-drv:DrivingIncident">
    <xsl:if test="dot-drv:ConfidentialIndicator = 'true'">
      <tr>
        <td colspan="3" class="redRegular">
          <xsl:text>** Confidential Next Entry **</xsl:text>
        </td>
      </tr>
    </xsl:if>
    <tr>
      <td class="tableName tealRegular">
        <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
          <xsl:with-param name="YYYY-MM-DD" select="j:ActivityDate"/>
        </xsl:call-template>
      </td>
      <td class="tableName tealRegular">
        <xsl:if test="j:ActivityDisposition/j:ActivityCrimeCase/j:CaseDisposition/j:CaseDispositionFinalDate">
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="j:ActivityDisposition/j:ActivityCrimeCase/j:CaseDisposition/j:CaseDispositionFinalDate"/>
          </xsl:call-template>
        </xsl:if>
      </td>
      <td class="tableValue tealRegular">
        <span class="blueRegular">
          <xsl:text>Violation </xsl:text>
        </span>
        <xsl:apply-templates select="j:ActivityDisposition/j:ActivityCrimeCase/j:CaseDisposition/j:CaseDispositionDecision/j:CaseDispositionDecisionText" mode="TitleCase"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="dot-drv:WisconsinChargeCodeAbbreviation"/>
        <xsl:text>(</xsl:text>
        <xsl:apply-templates select="dot-drv:WisconsinChargeCodeDescription" mode="TitleCase"/>
        <xsl:for-each select="dot-drv:RoadwayZonedDescription">
          <xsl:text> </xsl:text>
          <xsl:value-of select="."/>
        </xsl:for-each>
        <xsl:if test="dot-drv:OverLegalSpeedRate">
          <xsl:text> </xsl:text>
          <xsl:value-of select="dot-drv:OverLegalSpeedRate"/>
        </xsl:if>
        <xsl:if test="j:DrivingIncidentLegalSpeedRate">
          <xsl:text> over in a </xsl:text>
          <xsl:value-of select="j:DrivingIncidentLegalSpeedRate"/>
          <xsl:text>mph</xsl:text>
        </xsl:if>
        <xsl:if test="dot-drv:PersonIntoxication/j:IntoxicationLevelText">
          <xsl:text> BAC=</xsl:text>
          <xsl:value-of select="dot-drv:PersonIntoxication/j:IntoxicationLevelText"/>
        </xsl:if>
        <xsl:if test="dot-drv:MinorInVehicleIndicator = 'true'">
          <xsl:text> Minor in Vehicle</xsl:text>
        </xsl:if>
        <xsl:text> </xsl:text>
        <xsl:value-of select="j:IncidentViolatedStatute/j:StatuteCodeID/j:ID"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="dot-drv:WisconsinDOTRuleNumber"/>
        <xsl:text>)</xsl:text>
        <xsl:if test="dot-drv:PointsLost">
          <xsl:text> Points:</xsl:text>
          <xsl:value-of select="dot-drv:PointsLost"/>
        </xsl:if>
        <xsl:if test="dot-drv:ActivityCourt/j:CourtName">
          <xsl:text> Court:</xsl:text>
          <xsl:apply-templates select="dot-drv:ActivityCourt/j:CourtName" mode="TitleCase"/>
        </xsl:if>
        <xsl:if test="dot-drv:ActivityCourt/j:OrganizationLocation/j:LocationAddress/j:LocationCountyName">
          <xsl:text> County:</xsl:text>
          <xsl:apply-templates select="dot-drv:ActivityCourt/j:OrganizationLocation/j:LocationAddress/j:LocationCountyName" mode="TitleCase"/>
        </xsl:if>
        <xsl:if test="dot-drv:IncidentLocation/dot-drv:LocationAddress/j:LocationStateName">
          <xsl:text> State:</xsl:text>
          <xsl:value-of select="dot-drv:IncidentLocation/dot-drv:LocationAddress/j:LocationStateName"/>
        </xsl:if>
        <xsl:choose>
        	<xsl:when test="dot-drv:VehicleClassCode">
        		<xsl:text> Class:</xsl:text>
          		<xsl:value-of select="dot-drv:VehicleClassCode"/>
        	</xsl:when>
        	<xsl:otherwise>
        		<xsl:text> Non Driving Violation</xsl:text>
        	</xsl:otherwise>
        </xsl:choose>
        <xsl:for-each select="dot-drv:DriverAuthorizationEndorsementCode">
          <xsl:text> Endorsement:</xsl:text>
          <xsl:apply-templates select="." mode="TitleCase"/>
        </xsl:for-each>
        <xsl:if test="dot-drv:UniformTrafficCitation/j:ID or dot-drv:UniformTrafficCitation/dot-drv:CheckDigit">
          <xsl:text> UTC Citation #:</xsl:text>
          <xsl:value-of select="dot-drv:UniformTrafficCitation/j:ID"/>
          <xsl:text>-</xsl:text>
          <xsl:value-of select="dot-drv:UniformTrafficCitation/dot-drv:CheckDigit"/>
        </xsl:if>
        <xsl:if test="dot-drv:NonUniformTrafficCitation/j:ID">
          <xsl:text> Non-UTC Citation #:</xsl:text>
          <xsl:value-of select="dot-drv:NonUniformTrafficCitation/j:ID"/>
        </xsl:if>
        <xsl:if test="j:ActivityDisposition/j:ActivityCrimeCase/j:CaseDocketID/j:ID">
          <xsl:text> Court Case #:</xsl:text>
          <xsl:value-of select="j:ActivityDisposition/j:ActivityCrimeCase/j:CaseDocketID/j:ID"/>
        </xsl:if>
        <xsl:if test="dot-drv:WithdrawalCaseNumber">
          <xsl:text> See File #:</xsl:text>
          <xsl:value-of select="translate(dot-drv:WithdrawalCaseNumber, ',', ' ')"/>
        </xsl:if>
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="dot-drv:Event">
    <!--
      The format of every Event is duplicated in transformDOTResponse2008V01To2007V02.xsl in CVS project
      ETIMEApplicationForBadgernetTZ. Whatever you change here change there also.
    -->
    <xsl:apply-templates select="dot-drv:Accident"/>
    <xsl:apply-templates select="dot-drv:Arrest"/>
    <xsl:apply-templates select="dot-drv:DrivingIncident"/>
    <xsl:apply-templates select="dot-drv:Reinstatement"/>
    <xsl:apply-templates select="dot-drv:TrafficSafetySchool"/>
    <xsl:apply-templates select="dot-drv:Withdrawal"/>
  </xsl:template>

  <xsl:template match="dot-drv:PossibleHits">
    <h1 class="filetype">
      <xsl:text>Candidate List</xsl:text>
    </h1>
    <xsl:if test="dot-drv:MoreHitsIndicator='true'">
      <xsl:text>More than 50 hits found, only 50 returned.</xsl:text>
      <p/>
    </xsl:if>
    <table cellspacing="10" style="width:auto;" class="dataTable">
      <xsl:choose>
        <xsl:when test="$from='firearm'">
          <thead>
            <tr>
              <xsl:if test="$readOnly != 'true'">
                <th><input type='checkbox' class="checkAll"></input></th>
              </xsl:if>
              <th>Photo ID</th>      
              <th>Candidate</th>
              <th>Address</th>
            </tr>
          </thead>
          <tbody>
            <xsl:apply-templates select="dot-drv:PossibleHit" mode="firearm"/>
          </tbody>
          <xsl:if test="$readOnly != 'true'">
            <tr>
              <td></td>
              <td colspan='3'>
                <input type="button" class="launch" value="Launch DOT Full Inquiry" style="display:none" hidden="true"/>
              </td>
            </tr>
          </xsl:if>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates select="dot-drv:PossibleHit"/>
        </xsl:otherwise>
      </xsl:choose>
    </table>
  </xsl:template>
  
  <xsl:template match="dot-drv:PossibleHit" mode="firearm">
    <tr>
      <xsl:if test="$from='firearm' and $readOnly != 'true'">
        <td>
          <xsl:element name="input">
            <xsl:attribute name="type">checkbox</xsl:attribute>
            <xsl:attribute name="class">possibleHit</xsl:attribute>
            <xsl:attribute name="value">
              <xsl:value-of select="$executionUrl"/>
              <xsl:text>&amp;</xsl:text>
              <xsl:value-of select="j:DriverLicense/j:DriverAuthorizationID.Detailed/j:ID"/>
            </xsl:attribute>
            <xsl:attribute name="id">
              <xsl:value-of select="j:DriverLicense/j:DriverAuthorizationID.Detailed/j:ID"/>
            </xsl:attribute>
          </xsl:element>
        </td>
      </xsl:if>
      <td>
          <xsl:value-of select="j:DriverLicense/j:DriverAuthorizationID.Detailed/j:ID"/>
      </td>
      <td>
          <xsl:apply-templates select="j:PersonName/j:PersonSurName" mode="TitleCase"/>
          <xsl:text>, </xsl:text>
          <xsl:apply-templates select="j:PersonName/j:PersonGivenName" mode="TitleCase"/>
          <xsl:text> </xsl:text>
          <xsl:apply-templates select="j:PersonName/j:PersonMiddleName" mode="TitleCase"/>
          <xsl:text> </xsl:text>
          <xsl:apply-templates select="j:PersonName/j:PersonSuffixName" mode="TitleCase"/>
          <xsl:text> </xsl:text>
          <xsl:if test="dot-drv:PersonPhysicalDetails/j:PersonSexText">
            <xsl:call-template name="Sex_to_text">
              <xsl:with-param name="SexCode" select="dot-drv:PersonPhysicalDetails/j:PersonSexText"/>
            </xsl:call-template>
            <xsl:text>/</xsl:text>
          </xsl:if>
          <xsl:if test="dot-drv:PersonPhysicalDetails/j:PersonRaceText">
            <xsl:call-template name="Race_to_text">
              <xsl:with-param name="RaceCode" select="dot-drv:PersonPhysicalDetails/j:PersonRaceText"/>
            </xsl:call-template>
            <xsl:text> </xsl:text>
          </xsl:if>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="dot-drv:PersonBirthDateText"/>
          </xsl:call-template>
      </td>
      <td>
        <xsl:apply-templates select="dot-drv:Residence/j:LocationAddress/j:LocationStreet/j:StreetFullText" mode="TitleCase"/>,
        <xsl:text> </xsl:text>
        <xsl:apply-templates select="dot-drv:Residence/j:LocationAddress/j:LocationCityName" mode="TitleCase"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="dot-drv:Residence/j:LocationAddress/j:LocationStateName"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="dot-drv:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID"/>
        <xsl:text> </xsl:text>
        <xsl:apply-templates select="dot-drv:Residence/j:LocationAddress/j:LocationCountryName" mode="TitleCase"/>
      </td>
    </tr>
  </xsl:template>
  
  <xsl:template match="dot-drv:PossibleHit">
    <xsl:variable name="REQUESTOR_DETAILS" select="/*/*[local-name()='Header']/doj-ext:SubmissionRequestorDetails"/>
    <tr>
      <td>
        <a>
          <xsl:attribute name="href">
            <xsl:text>/secure/personsearch/personsearch.jsp?dotDRCbx=yes&amp;driversLicense=</xsl:text>
            <xsl:value-of select="j:DriverLicense/j:DriverAuthorizationID.Detailed/j:ID"/>
            <xsl:text>&amp;agencyORI=</xsl:text>
            <xsl:value-of select="$REQUESTOR_DETAILS/doj-ext:SubmissionRequestor.OnBehalfOfOrganization/doj-ext:OrganizationORIID/doj-ext:ID"/>
            <xsl:text>&amp;WhatToDo=personSearch</xsl:text>
          </xsl:attribute>
          <xsl:value-of select="j:DriverLicense/j:DriverAuthorizationID.Detailed/j:ID"/>
        </a>
      </td>
      <td>
        <a>
          <xsl:attribute name="href">
            <xsl:variable name="modifiedLastName">
              <xsl:call-template name="replaceCharsInString">
                <xsl:with-param name="stringIn" select="j:PersonName/j:PersonSurName"/>
                <xsl:with-param name="charsIn" select="&quot;'&quot;"/>
                <xsl:with-param name="charsOut" select="''"/>
              </xsl:call-template>
            </xsl:variable>
            <xsl:text>/secure/personsearch/personsearch.jsp?dotDRCbx=yes&amp;lastName=</xsl:text>
            <xsl:value-of select="$modifiedLastName"/>
            <xsl:text>&amp;firstName=</xsl:text>
            <xsl:value-of select="j:PersonName/j:PersonGivenName"/>
            <xsl:text>&amp;middleName=</xsl:text>
            <xsl:value-of select="j:PersonName/j:PersonMiddleName"/>
            <xsl:text>&amp;birthMM=</xsl:text>
            <xsl:value-of select="substring(dot-drv:PersonBirthDateText, 6, 2)"/>
            <xsl:text>&amp;birthDD=</xsl:text>
            <xsl:value-of select="substring(dot-drv:PersonBirthDateText, 9, 2)"/>
            <xsl:text>&amp;birthYYYY=</xsl:text>
            <xsl:value-of select="substring(dot-drv:PersonBirthDateText, 1, 4)"/>
            <xsl:text>&amp;sexCd=</xsl:text>
            <xsl:value-of select="dot-drv:PersonPhysicalDetails/j:PersonSexText"/>
            <xsl:text>&amp;raceCd=</xsl:text>
            <xsl:value-of select="dot-drv:PersonPhysicalDetails/j:PersonRaceText"/>
            <xsl:text>&amp;agencyORI=</xsl:text>
            <xsl:value-of select="$REQUESTOR_DETAILS/doj-ext:SubmissionRequestor.OnBehalfOfOrganization/doj-ext:OrganizationORIID/doj-ext:ID"/>
            <xsl:text>&amp;WhatToDo=personSearch</xsl:text>
          </xsl:attribute>
          <xsl:apply-templates select="j:PersonName/j:PersonSurName" mode="TitleCase"/>
          <xsl:text>, </xsl:text>
          <xsl:apply-templates select="j:PersonName/j:PersonGivenName" mode="TitleCase"/>
          <xsl:text> </xsl:text>
          <xsl:apply-templates select="j:PersonName/j:PersonMiddleName" mode="TitleCase"/>
          <xsl:text> </xsl:text>
          <xsl:apply-templates select="j:PersonName/j:PersonSuffixName" mode="TitleCase"/>
          <xsl:text> </xsl:text>
          <xsl:if test="dot-drv:PersonPhysicalDetails/j:PersonSexText">
            <xsl:call-template name="Sex_to_text">
              <xsl:with-param name="SexCode" select="dot-drv:PersonPhysicalDetails/j:PersonSexText"/>
            </xsl:call-template>
            <xsl:text>/</xsl:text>
          </xsl:if>
          <xsl:if test="dot-drv:PersonPhysicalDetails/j:PersonRaceText">
            <xsl:call-template name="Race_to_text">
              <xsl:with-param name="RaceCode" select="dot-drv:PersonPhysicalDetails/j:PersonRaceText"/>
            </xsl:call-template>
            <xsl:text> </xsl:text>
          </xsl:if>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="dot-drv:PersonBirthDateText"/>
          </xsl:call-template>
        </a>
        <br/>
        <xsl:apply-templates select="dot-drv:Residence/j:LocationAddress/j:LocationStreet/j:StreetFullText" mode="TitleCase"/>,
        <xsl:text> </xsl:text>
        <xsl:apply-templates select="dot-drv:Residence/j:LocationAddress/j:LocationCityName" mode="TitleCase"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="dot-drv:Residence/j:LocationAddress/j:LocationStateName"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="dot-drv:Residence/j:LocationAddress/j:LocationPostalCodeID/j:ID"/>
        <xsl:text> </xsl:text>
        <xsl:apply-templates select="dot-drv:Residence/j:LocationAddress/j:LocationCountryName" mode="TitleCase"/>
      </td>
    </tr>
  </xsl:template>
  
  <xsl:template match="dot-drv:ProductDetails">
    <div class="subjecttitle">
      <xsl:if test="position() = 1">
        <br />
        <xsl:text>Drivers License or ID Card # </xsl:text>
        <xsl:call-template name="FormatDL">
          <xsl:with-param name="DL" select="j:DriverAuthorizationID.Detailed/j:ID"/>
        </xsl:call-template>
      </xsl:if>
      <p/>
      <xsl:if test="dot-drv:DriverLicenseConfidentialIndicator = 'true'">
        <span class="redRegular">
          <xsl:text>* Confidential Next Product *</xsl:text>
        </span>
        <br/>
      </xsl:if>
      <xsl:value-of select="dot-drv:AdditionalInformation/dot-drv:DriverLicenseStatus"/>
      <xsl:if test="dot-drv:AdditionalInformation/dot-drv:DriverLicenseStatusConfidentialIndicator = 'true'">
        <span class="redRegular">
          <xsl:text> (Confidential)</xsl:text>
        </span>
      </xsl:if>
      <xsl:text> </xsl:text>
      <xsl:value-of select="dot-drv:DriverLicenseTypeText"/>
      <xsl:text> </xsl:text>
      <xsl:apply-templates select="dot-drv:AdditionalInformation/dot-drv:ProductDescriptionText" mode="TitleCase"/>
      <xsl:if test="position()>1">
      	  <xsl:text>; </xsl:text>
      </xsl:if>
      <xsl:for-each select="dot-drv:AdditionalInformation/dot-drv:ProductClass">
        <xsl:if test="position()>1">
          <xsl:text>, </xsl:text>
        </xsl:if>
        <xsl:call-template name="StatusCode_to_text">
          <xsl:with-param name="StatusCode" select="dot-drv:ClassStatusCode"/>
        </xsl:call-template>
        <xsl:text> Class </xsl:text>
        <xsl:value-of select="dot-drv:ClassCode"/>
      </xsl:for-each>
    </div>
    <table cellspacing="0" style="width:auto;">
      <xsl:if test="j:DriverAuthorizationExpirationDate">
        <tr>
          <td class="tableName tealRegular">
            <xsl:text>Expiration:</xsl:text>
          </td>
          <td class="tableValue tealBold">
            <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
              <xsl:with-param name="YYYY-MM-DD" select="j:DriverAuthorizationExpirationDate"/>
            </xsl:call-template>
          </td>
        </tr>
      </xsl:if>
      <xsl:if test="dot-drv:AdditionalInformation/dot-drv:Restriction">
        <tr>
          <td class="tableName tealRegular">
            <xsl:text>Restrictions:</xsl:text>
          </td>
          <td class="tableValue tealBold">
            <xsl:for-each select="dot-drv:AdditionalInformation/dot-drv:Restriction">
              <xsl:if test="position() > 1">
                <xsl:text>, </xsl:text>
              </xsl:if>
              <xsl:apply-templates select="." mode="TitleCase"/>
            </xsl:for-each>
          </td>
        </tr>
      </xsl:if>
      <xsl:if test="dot-drv:AdditionalInformation/dot-drv:ProductEndorsement">
        <tr>
          <td class="tableName tealRegular">
            <xsl:text>Endorsements:</xsl:text>
          </td>
          <td class="tableValue tealBold">
            <xsl:for-each select="dot-drv:AdditionalInformation/dot-drv:ProductEndorsement">
              <xsl:if test="position() > 1">
                <xsl:text>, </xsl:text>
              </xsl:if>
              <xsl:call-template name="StatusCode_to_text">
                <xsl:with-param name="StatusCode" select="dot-drv:EndorsementStatusCode"/>
              </xsl:call-template>
              <xsl:text> </xsl:text>
              <xsl:call-template name="EndorsementCode_to_text">
                <xsl:with-param name="EndorsementCode" select="dot-drv:EndorsementCode"/>
              </xsl:call-template>
            </xsl:for-each>
          </td>
        </tr>
      </xsl:if>
      <xsl:if test="j:DriverAuthorizationIssueDate">
        <tr>
          <td class="tableName tealRegular">
            <xsl:text>Issue Date:</xsl:text>
          </td>
          <td class="tableValue tealRegular">
            <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
              <xsl:with-param name="YYYY-MM-DD" select="j:DriverAuthorizationIssueDate"/>
            </xsl:call-template>
          </td>
        </tr>
      </xsl:if>
      <xsl:if test="dot-drv:DriverAuthorizationIssueDate.Original">
        <tr>
          <td class="tableName tealRegular">
            <xsl:text>Original Issue Date:</xsl:text>
          </td>
          <td class="tableValue tealRegular">
            <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
              <xsl:with-param name="YYYY-MM-DD" select="dot-drv:DriverAuthorizationIssueDate.Original"/>
            </xsl:call-template>
          </td>
        </tr>
      </xsl:if>
      <tr>
        <td>
          <xsl:text>&#160;</xsl:text>
        </td>
      </tr>
      <xsl:if test="dot-drv:AdditionalInformation/dot-drv:ProductPhotoCode or dot-drv:AdditionalInformation/dot-drv:ProductPhotoDescription or dot-drv:AdditionalInformation/dot-drv:ProductPhotoMissingReasonCode or dot-drv:AdditionalInformation/dot-drv:ProductPhotoMissingReasonDescription">
        <tr>
          <td class="tableName tealRegular">
            <xsl:text>Photo Available:</xsl:text>
          </td>
          <td class="tableValue tealRegular">
            <xsl:choose>
              <xsl:when test="dot-drv:AdditionalInformation/dot-drv:ProductPhotoDescription">
                <xsl:choose>
                  <xsl:when test="dot-drv:AdditionalInformation/dot-drv:ProductPhotoDescription='PHOTO'">
                    <xsl:text>Yes</xsl:text>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:apply-templates select="dot-drv:AdditionalInformation/dot-drv:ProductPhotoDescription" mode="TitleCase"/>
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:when>
              <xsl:when test="dot-drv:AdditionalInformation/dot-drv:ProductPhotoCode">
                <xsl:value-of select="dot-drv:AdditionalInformation/dot-drv:ProductPhotoCode"/>
              </xsl:when>
            </xsl:choose>
            <xsl:if test="(dot-drv:AdditionalInformation/dot-drv:ProductPhotoCode or dot-drv:AdditionalInformation/dot-drv:ProductPhotoDescription) and (dot-drv:AdditionalInformation/dot-drv:ProductPhotoMissingReasonCode or dot-drv:AdditionalInformation/dot-drv:ProductPhotoMissingReasonDescription)">
              <xsl:text> - </xsl:text>
            </xsl:if>
            <xsl:choose>
              <xsl:when test="dot-drv:AdditionalInformation/dot-drv:ProductPhotoMissingReasonDescription">
                <xsl:apply-templates select="dot-drv:AdditionalInformation/dot-drv:ProductPhotoMissingReasonDescription" mode="TitleCase"/>
              </xsl:when>
              <xsl:when test="dot-drv:AdditionalInformation/dot-drv:ProductPhotoMissingReasonCode">
                <xsl:value-of select="dot-drv:AdditionalInformation/dot-drv:ProductPhotoMissingReasonCode"/>
              </xsl:when>
            </xsl:choose>
          </td>
        </tr>
      </xsl:if>
      <xsl:if test="dot-drv:AdditionalInformation/dot-drv:RealIDIndicator">
        <tr>
          <td class="tableName tealRegular">
            <xsl:text>Real ID Indicator:</xsl:text>
          </td>
          <td class="tableValue tealRegular">
            <xsl:choose>
              <xsl:when test="dot-drv:AdditionalInformation/dot-drv:RealIDIndicator = 'true'">
                <xsl:text>Yes</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>No</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </td>
        </tr>
      </xsl:if>
      <xsl:if test="dot-drv:AdditionalInformation/dot-drv:ProductDescriptionText">
        <tr>
          <td class="tableName tealRegular">
            <xsl:text>Product Description:</xsl:text>
          </td>
          <td class="tableValue tealRegular">
            <xsl:apply-templates select="dot-drv:AdditionalInformation/dot-drv:ProductDescriptionText" mode="TitleCase"/>
          </td>
        </tr>
      </xsl:if>
      <tr>
        <td class="tableName tealRegular">
          <xsl:if test="dot-drv:AdditionalInformation/dot-drv:TypeOfApplicationCode or dot-drv:AdditionalInformation/dot-drv:TypeOfApplicationDescription">
            <xsl:text>Application Type:</xsl:text>
          </xsl:if>
        </td>
        <td class="tableValue tealRegular">
          <xsl:choose>
            <xsl:when test="dot-drv:AdditionalInformation/dot-drv:TypeOfApplicationDescription">
              <xsl:apply-templates select="dot-drv:AdditionalInformation/dot-drv:TypeOfApplicationDescription" mode="TitleCase"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="dot-drv:AdditionalInformation/dot-drv:TypeOfApplicationCode"/>
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <xsl:if test="dot-drv:AdditionalInformation/dot-drv:FederalMedicalCardIndicator">
        <tr>
          <td class="tableName tealRegular">
            <xsl:text>Federal Medical:</xsl:text>
          </td>
          <td class="tableValue tealRegular">
            <xsl:call-template name="true-false_to_Y-N">
              <xsl:with-param name="true-false" select="dot-drv:AdditionalInformation/dot-drv:FederalMedicalCardIndicator"/>
            </xsl:call-template>
          </td>
        </tr>
      </xsl:if>
      <tr>
        <td class="tableName tealRegular">
          <xsl:if test="dot-drv:AdditionalInformation/dot-drv:ExaminerDetails/dot-drv:ExaminerID/j:ID">
            <xsl:text>Examiner License #:</xsl:text>
          </xsl:if>
        </td>
        <td class="tableValue tealRegular">
          <xsl:value-of select="dot-drv:AdditionalInformation/dot-drv:ExaminerDetails/dot-drv:ExaminerID/j:ID"/>
        </td>
      </tr>
      <xsl:if test="dot-drv:AdditionalInformation/dot-drv:WaiverOrExemption">
        <tr>
          <td class="tableName tealRegular">
            <xsl:text>Waiver or Exemption:</xsl:text>
          </td>
          <td class="tableValue tealRegular">
            <xsl:apply-templates select="dot-drv:AdditionalInformation/dot-drv:WaiverOrExemption" mode="TitleCase"/>
          </td>
        </tr>
      </xsl:if>
      <xsl:if test="dot-drv:AdditionalInformation/dot-drv:InstructorDetails/dot-drv:InstructorLicenseID/j:ID">
        <tr>
          <td class="tableName tealRegular">
            <xsl:text>Instructor #:</xsl:text>
          </td>
          <td class="tableValue tealRegular">
            <xsl:value-of select="dot-drv:AdditionalInformation/dot-drv:InstructorDetails/dot-drv:InstructorLicenseID/j:ID"/>
          </td>
        </tr>
      </xsl:if>
      <xsl:if test="dot-drv:AdditionalInformation/dot-drv:InstructorDetails/dot-drv:InstructorCertifiedCourseCode or dot-drv:AdditionalInformation/dot-drv:InstructorDetails/dot-drv:InstructorCertifiedCourseDescription">
        <tr>
          <td class="tableName tealRegular">
            <xsl:text>Course Description:</xsl:text>
          </td>
          <td class="tableValue tealRegular">
            <xsl:choose>
              <xsl:when test="dot-drv:AdditionalInformation/dot-drv:InstructorDetails/dot-drv:InstructorCertifiedCourseDescription">
                <xsl:apply-templates select="dot-drv:AdditionalInformation/dot-drv:InstructorDetails/dot-drv:InstructorCertifiedCourseDescription" mode="TitleCase"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="dot-drv:AdditionalInformation/dot-drv:InstructorDetails/dot-drv:InstructorCertifiedCourseCode"/>
              </xsl:otherwise>
            </xsl:choose>
          </td>
        </tr>
      </xsl:if>
    </table>
  </xsl:template>

  <xsl:template match="dot-drv:Reinstatement">
    <tr>
      <td class="tableName tealRegular">
        <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
          <xsl:with-param name="YYYY-MM-DD" select="dot-drv:ReinstatementDate"/>
        </xsl:call-template>
      </td>
      <td class="tableName">
      </td>
      <td class="tableValue tealRegular">
        <span class="blueRegular">
          <xsl:text>Reinstatement </xsl:text>
        </span>
        <xsl:apply-templates select="dot-drv:LicenseType" mode="TitleCase"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="dot-drv:WithdrawalCaseNumber"/>
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="dot-drv:ResponseText">
    <div class="resulttext">
      <h2 class="filetype"><xsl:apply-templates select="." mode="TitleCase"/></h2>
    </div>
  </xsl:template>

  <xsl:template match="doj:ResultText">
    <div class="resulttext">
      <h1 class="filetype"><xsl:apply-templates select="." mode="TitleCase"/></h1>
    </div>
  </xsl:template>

  <xsl:template match="dot-drv:TrafficSafetySchool">
    <tr>
      <td class="tableName tealRegular">
        <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
          <xsl:with-param name="YYYY-MM-DD" select="j:ActivityDate"/>
        </xsl:call-template>
      </td>
      <td class="tableName">
      </td>
      <td class="tableValue tealRegular">
        <span class="blueRegular">
          <xsl:text>Traffic Safety School </xsl:text>
        </span>
        <xsl:if test="dot-drv:WIDOTPointsAcceptedIndicator">
          <xsl:text> Accepted=</xsl:text>
          <xsl:call-template name="true-false_to_Y-N">
            <xsl:with-param name="true-false" select="dot-drv:WIDOTPointsAcceptedIndicator"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="dot-drv:PointReductionCount">
          <xsl:text> Points:</xsl:text>
          <xsl:value-of select="dot-drv:PointReductionCount"/>
        </xsl:if>
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="dot-drv:Withdrawal">
    <xsl:if test="dot-drv:ConfidentialIndicator = 'true'">
      <tr>
        <td class="redRegular" colspan="3">
          <xsl:text>** Confidential Next Entry **</xsl:text>
        </td>
      </tr>
    </xsl:if>
    <tr>
      <td class="tableName tealRegular">
        <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
          <xsl:with-param name="YYYY-MM-DD" select="dot-drv:WithdrawalStartDate"/>
        </xsl:call-template>
      </td>
      <td class="tableName">
      </td>
      <td class="tableValue tealRegular">
        <span class="blueRegular">
          <xsl:text>Withdrawal </xsl:text>
        </span>
        <xsl:apply-templates select="dot-drv:Authority" mode="TitleCase"/>
        <xsl:text> </xsl:text>
        <xsl:apply-templates select="dot-drv:WithdrawalDescription" mode="TitleCase"/>
        <xsl:for-each select="dot-drv:ClassCode">
          <xsl:text> Class:</xsl:text>
          <xsl:value-of select="."/>
        </xsl:for-each>
        <xsl:for-each select="dot-drv:EndorsementCode">
          <xsl:text> Endorsement:</xsl:text>
          <xsl:value-of select="."/>
        </xsl:for-each>
        <xsl:text> </xsl:text>
        <xsl:value-of select="dot-drv:WithdrawalPeriod"/>
        <xsl:text> </xsl:text>
        <xsl:apply-templates select="dot-drv:WithdrawalPeriodType" mode="TitleCase"/>
        <xsl:text> </xsl:text>
        <xsl:if test="dot-drv:JailTimeDuration">
        	<xsl:text>&#32;&#43;&#32;</xsl:text>
        	<xsl:value-of select="dot-drv:JailTimeDuration"/>
        	<xsl:text> </xsl:text>
       		<xsl:apply-templates select="dot-drv:JailTimeDurationPeriod" mode="TitleCase"/>
       		<xsl:text> </xsl:text>
        </xsl:if>
        <xsl:value-of select="dot-drv:WisconsinChargeCodeAbbreviation"/>
        <xsl:text> </xsl:text>
        <xsl:apply-templates select="dot-drv:WisconsinChargeCodeDescription" mode="TitleCase"/>
        <xsl:if test="dot-drv:FileHandlerFileNumber">
          <xsl:text> Case #:</xsl:text>
          <xsl:value-of select="dot-drv:FileHandlerFileNumber"/>
        </xsl:if>
        <xsl:if test="dot-drv:ActivityCourt/j:CourtName">
          <xsl:text> Court:</xsl:text>
          <xsl:apply-templates select="dot-drv:ActivityCourt/j:CourtName" mode="TitleCase"/>
        </xsl:if>
        <xsl:if test="dot-drv:ActivityCourt/j:OrganizationLocation/j:LocationAddress/j:LocationCountyName">
          <xsl:text> County:</xsl:text>
          <xsl:apply-templates select="dot-drv:ActivityCourt/j:OrganizationLocation/j:LocationAddress/j:LocationCountyName" mode="TitleCase"/>
        </xsl:if>
        <xsl:if test="dot-drv:ActivityCrimeCase/j:CaseDocketID/j:ID">
          <xsl:text> Court Case #:</xsl:text>
          <xsl:value-of select="dot-drv:ActivityCrimeCase/j:CaseDocketID/j:ID"/>
        </xsl:if>
        <xsl:if test="dot-drv:IncidentCaseNumber">
          <xsl:text> Same Incident #:</xsl:text>
          <xsl:value-of select="dot-drv:IncidentCaseNumber"/>
        </xsl:if>
        <xsl:if test="dot-drv:AccidentNumber">
          <xsl:text> Accident #:</xsl:text>
          <xsl:value-of select="dot-drv:AccidentNumber"/>
        </xsl:if>
        <xsl:if test="dot-drv:TestRefusalDate">
          <xsl:text> Refusal Date:</xsl:text>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="dot-drv:TestRefusalDate"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="dot-drv:ReinstatementEligibilityDate">
          <xsl:text> Eligible For Reinstatement:</xsl:text>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="dot-drv:ReinstatementEligibilityDate"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="dot-drv:ReinstatementDate">
          <xsl:text> Reinstated:</xsl:text>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="dot-drv:ReinstatementDate"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="dot-drv:ReleaseDate">
          <xsl:text> Released:</xsl:text>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="dot-drv:ReleaseDate"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="dot-drv:OccupationalReinstatementDate">
          <xsl:text> Occupational Reinstated:</xsl:text>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="dot-drv:OccupationalReinstatementDate"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="dot-drv:CorrespondenceMailedDate">
          <xsl:text> Mailed:</xsl:text>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="dot-drv:CorrespondenceMailedDate"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="dot-drv:CorrespondenceReturnedDate">
          <xsl:text> Returned Unclaimed:</xsl:text>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="dot-drv:CorrespondenceReturnedDate"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="dot-drv:AmendedOrderMailedDate">
          <xsl:text> Amended Mailed:</xsl:text>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="dot-drv:AmendedOrderMailedDate"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="dot-drv:AmendedOrderReturnedDate">
          <xsl:text> Amended Unclaimed:</xsl:text>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="dot-drv:AmendedOrderReturnedDate"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="j:ActivityDate">
          <xsl:text> BAC Incident Date:</xsl:text>
          <xsl:call-template name="YYYY-MM-DD_to_MM-DD-YYYY">
            <xsl:with-param name="YYYY-MM-DD" select="j:ActivityDate"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="dot-drv:PrivilegeWithdrawalNotation">
          <xsl:text> Notation:</xsl:text>
          <xsl:apply-templates select="dot-drv:PrivilegeWithdrawalNotation" mode="TitleCase"/>
        </xsl:if>
      </td>
    </tr>
  </xsl:template>

  <xsl:template name="EndorsementCode_to_text">
    <xsl:param name="EndorsementCode"/>
    <xsl:choose>
      <xsl:when test="$EndorsementCode='F'">
        <xsl:text>Farm Service CDL</xsl:text>
      </xsl:when>
      <xsl:when test="$EndorsementCode='H'">
        <xsl:text>Haz. Material</xsl:text>
      </xsl:when>
      <xsl:when test="$EndorsementCode='N'">
        <xsl:text>Tanker</xsl:text>
      </xsl:when>
      <xsl:when test="$EndorsementCode='P'">
        <xsl:text>Passenger Bus</xsl:text>
      </xsl:when>
      <xsl:when test="$EndorsementCode='S'">
        <xsl:text>School Bus</xsl:text>
      </xsl:when>
      <xsl:when test="$EndorsementCode='T'">
        <xsl:text>Doubles/Triples</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$EndorsementCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="EyeColor_to_text">
    <xsl:param name="EyeColorCode"/>
    <xsl:choose>
      <xsl:when test="$EyeColorCode='BLK'">
        <xsl:text>Black</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='BLU'">
        <xsl:text>Blue</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='BRO'">
        <xsl:text>Brown</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='DIC'">
        <xsl:text>Dichromatic</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='GRN'">
        <xsl:text>Green</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='GRY'">
        <xsl:text>Gray</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='HAZ'">
        <xsl:text>Hazel</xsl:text>
      </xsl:when>
      <xsl:when test="$EyeColorCode='UNK'">
        <xsl:text>Unknown</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$EyeColorCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="FormatDL">
    <xsl:param name="DL"/>
    <xsl:value-of select="substring($DL, 1, 4)"/>
    <xsl:text>-</xsl:text>
    <xsl:value-of select="substring($DL, 5, 4)"/>
    <xsl:text>-</xsl:text>
    <xsl:value-of select="substring($DL, 9, 4)"/>
    <xsl:text>-</xsl:text>
    <xsl:value-of select="substring($DL, 13)"/>
  </xsl:template>
  
  <xsl:template name="HairColor_to_text">
    <xsl:param name="HairColorCode"/>
    <xsl:choose>
      <xsl:when test="$HairColorCode='BAL'">
        <xsl:text>Bald</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='BLD'">
        <xsl:text>Blond</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='BLK'">
        <xsl:text>Black</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='BRO'">
        <xsl:text>Brown</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='GRY'">
        <xsl:text>Gray</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='RED'">
        <xsl:text>Red/Auburn</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='SDY'">
        <xsl:text>Sandy</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='UNK'">
        <xsl:text>Unknown</xsl:text>
      </xsl:when>
      <xsl:when test="$HairColorCode='WHI'">
        <xsl:text>White</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$HairColorCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="Race_to_text">
    <xsl:param name="RaceCode"/>
    <xsl:choose>
      <xsl:when test="$RaceCode='A'">
        <xsl:text>Asian</xsl:text>
      </xsl:when>
      <xsl:when test="$RaceCode='B'">
        <xsl:text>Black</xsl:text>
      </xsl:when>
      <xsl:when test="$RaceCode='H'">
        <xsl:text>Hispanic</xsl:text>
      </xsl:when>
      <xsl:when test="$RaceCode='I'">
        <xsl:text>Indian</xsl:text>
      </xsl:when>
      <xsl:when test="$RaceCode='W'">
        <xsl:text>White</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$RaceCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="Sex_to_text">
    <xsl:param name="SexCode"/>
    <xsl:choose>
      <xsl:when test="$SexCode='F'">
        <xsl:text>Female</xsl:text>
      </xsl:when>
      <xsl:when test="$SexCode='M'">
        <xsl:text>Male</xsl:text>
      </xsl:when>
      <xsl:when test="$SexCode='U'">
        <xsl:text>Unknown</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$SexCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="StatusCode_to_text">
    <xsl:param name="StatusCode"/>
    <xsl:choose>
      <xsl:when test="$StatusCode='BLANKS'">
        <xsl:text>Valid</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='CAN'">
        <xsl:text>Cancelled</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='DIS'">
        <xsl:text>Disqualified</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='EXP'">
        <xsl:text>Expired</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='OTH'">
        <xsl:text>Other</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='REV'">
        <xsl:text>Revoked</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='SUR'">
        <xsl:text>Surrendered</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='SUS'">
        <xsl:text>Suspended</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='VAL'">
        <xsl:text>Valid</xsl:text>
      </xsl:when>
      <xsl:when test="$StatusCode='MOS'">
        <xsl:text>Moved Out Of State</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$StatusCode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="true-false_to_Y-N">
    <xsl:param name="true-false"/>
    <xsl:choose>
      <xsl:when test="$true-false='true'">
        <xsl:text>Y</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>N</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="YYYY-MM-DD_to_MM-DD-YYYY">
    <xsl:param name="YYYY-MM-DD"/>
    <xsl:value-of select="substring($YYYY-MM-DD, 6, 2)"/>
    <xsl:text>/</xsl:text>
    <xsl:value-of select="substring($YYYY-MM-DD, 9, 2)"/>
    <xsl:text>/</xsl:text>
    <xsl:value-of select="substring($YYYY-MM-DD, 1, 4)"/>
  </xsl:template>
  
  <xsl:template name="replaceCharsInString">
    <xsl:param name="stringIn"/>
    <xsl:param name="charsIn"/>
    <xsl:param name="charsOut"/>
    <xsl:choose>
      <xsl:when test="contains($stringIn,$charsIn)">
        <xsl:value-of select="concat(substring-before($stringIn,$charsIn),$charsOut)"/>
        <xsl:call-template name="replaceCharsInString">
          <xsl:with-param name="stringIn" select="substring-after($stringIn,$charsIn)"/>
          <xsl:with-param name="charsIn" select="$charsIn"/>
          <xsl:with-param name="charsOut" select="$charsOut"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$stringIn"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
   <xsl:template match="j:PersonName" mode="PrimaryFirstMiddleLastSuffix">
	  <xsl:for-each select=".">
	  	<xsl:if test="not(@j:commentText)">
	  		<xsl:apply-templates select="." mode="FirstMiddleLastSuffix"/>
	  	</xsl:if>
	  </xsl:for-each>
	</xsl:template>
	
	<xsl:template match="j:PersonName" mode="RecordedFirstMiddleLastSuffix">
  	  <xsl:for-each select=".">
	  	<xsl:if test="@j:commentText = 'recorded'">
	      <xsl:text>Recorded Name: </xsl:text>
	  	  <xsl:apply-templates select="." mode="FirstMiddleLastSuffix"/>
	  	</xsl:if>
	  </xsl:for-each>
	</xsl:template>
	
  <xsl:template name="FormerFirstMiddleLastSuffix">
	  <xsl:for-each select="j:PersonName">
	  	<xsl:if test="not(./@j:commentText)">
	  		<xsl:apply-templates select="." mode="FirstMiddleLastSuffix"/>
	  	</xsl:if>
	  </xsl:for-each>
  </xsl:template>
  
  <xsl:template name="FormerRecordedFirstMiddleLastSuffix" >
    <xsl:for-each select="j:PersonName">
      <xsl:if test="@j:commentText = 'recorded'">
        <tr><td colspan="3" class="tealRegular">
	      <span class="detaillabel">
		  <xsl:text>FORMER RECORDED: </xsl:text>
		  </span>
  		  <xsl:apply-templates select="." mode="FirstMiddleLastSuffix"/>
  		  </td>
  		</tr>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>
  
</xsl:transform>