<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/dot/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
	xmlns:dot-veh="http://www.doj.state.wi.us/dles/cib/dot/response/broker/vehicle"
	xmlns:dot-drv="http://www.doj.state.wi.us/dles/cib/dot/response/broker/driver"
    xmlns:xalan="http://xml.apache.org/xslt"
    exclude-result-prefixes="xsl xsi cib-ext doj doj-ext j">
    
    <!--  DOT - NO FILE TYPE RECORD -->
	<xsl:import href="../common.xsl"/>
	<xsl:import href="../util.xsl"/>
  <xsl:param name="from"/>
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:DOTResponseDocument">
    <xsl:choose>
      <xsl:when test="$from='ebc'">
        <xsl:call-template name="html_main"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="html_head_extension"/>
        <xsl:call-template name="html_body"/>
      </xsl:otherwise>
    </xsl:choose>
	</xsl:template>
	
	<xsl:template name="html_body">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName"> 
				<xsl:apply-templates select="doj:Result/@doj-ext:resultStatusText"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="doj:Result">
		<xsl:choose>
			<xsl:when test="FormattedResultText">
				<xsl:apply-templates select="FormattedResultText"/>
			</xsl:when>
			<xsl:when test="dot-veh:DOTVehicle/dot-veh:Response/dot-veh:ResponseText">
				<xsl:call-template name="responseText">
					<xsl:with-param name="messageText"> 
						<xsl:value-of select="dot-veh:DOTVehicle/dot-veh:Response/dot-veh:ResponseText"></xsl:value-of>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="dot-drv:DOTDriver/dot-drv:Response/dot-drv:ResponseText">
				<xsl:call-template name="responseText">
					<xsl:with-param name="messageText"> 
						<xsl:value-of select="dot-drv:DOTDriver/dot-drv:Response/dot-drv:ResponseText"></xsl:value-of>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="doj:ResultText | doj:DOTLegacyText"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:apply-templates select="@doj-ext:resultStatusText"/>
	</xsl:template>
	
	<xsl:template match="doj:ResultText | doj:DOTLegacyText">
		<xsl:apply-templates select="." mode="header"/>
		<pre class="legacytext">
			<xsl:value-of select="."/>
		</pre>
	</xsl:template>
	
	<xsl:template name="responseText">
		<xsl:param name="messageText"/>
		<xsl:if test="string($messageText) != ''">
			<xsl:apply-templates select="." mode="header"/>
			<pre class="legacytext">
				<xsl:value-of select="$messageText"/>
			</pre>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="FormattedResultText">
		<xsl:apply-templates select="." mode="header"/>
		<pre class="legacytext">
			<xsl:value-of select="." disable-output-escaping="yes"/>
		</pre>
	</xsl:template>
	
	<!-- File Type Header -->
	<xsl:template match="*" mode="header"> 
		<!-- Data Service Logo -->	
		<xsl:call-template name="dotLogo"/>
		<!-- File Type Header Section -->
		<table>
			<tr>
				<td class="width90percent">
					<table>
						<tr><td>
							<span class="filetype">
								<xsl:text>DOT</xsl:text>
								<xsl:apply-templates select="../@doj-ext:resultStatusText"/>
								<xsl:text>Response</xsl:text>
							</span>
						</td></tr>
					</table>
				</td>
			</tr>
		</table>
		<!-- Horizontal Line -->
		<hr/>
	</xsl:template>
	
	<xsl:template match="@doj-ext:resultStatusText"> 
		<xsl:choose>
			<xsl:when test=".='Normal'">
				<!--  normal response with no hits -->
				<xsl:text>&#32;</xsl:text>
			</xsl:when>
			<xsl:when test="../doj:DOTLegacyText">
				<xsl:text>&#32;Legacy&#32;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<!-- For advisory, queued, reject or error (with no legacy) responses -->
				<xsl:text>&#32;</xsl:text>
				<xsl:value-of select="."/>
				<xsl:text>&#32;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<xsl:template name="dotLogo">
		<table width="100%" >
			<tr>
				<td align="right">
					<img src="../../images/DOT.gif" alt="DOT Logo"/>
				</td>
			</tr>
		</table>
	</xsl:template>
	
</xsl:transform>