<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:dot-veh="http://www.doj.state.wi.us/dles/cib/dot/response/broker/vehicle"
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/dot/response" 
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"
    xmlns:xalan="http://xml.apache.org/xslt"
    exclude-result-prefixes="xsl xsi dot-veh doj j xalan"
>
	<xsl:import href="../common.xsl"/>
	<xsl:import href="../util.xsl"/>
  <xsl:param name="from"/>
  <xsl:param name="responseId">
    <xsl:value-of select="doj:DOTResponseDocument/@doj-ext:responseID"/>
  </xsl:param>
	<xsl:output method="html"
                version="4.01"
                encoding="UTF-8" 
                omit-xml-declaration="yes"
                doctype-public="-//W3C//DTD HTML 4.01//EN"
                doctype-system="http://www.w3.org/TR/html4/strict.dtd"
                indent="yes"
                media-type="text/html"
                xalan:indent-amount="2"/>
	

	
	<xsl:template match="/">
    <xsl:choose>
      <xsl:when test="$from='ebc'">
        <xsl:call-template name="html_main"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="html_head_extension"/>
        <xsl:call-template name="html_body"/>
      </xsl:otherwise>
    </xsl:choose>
	</xsl:template>
	


	<xsl:template name="html_title">TIME - Vehicle Registration</xsl:template>



	<xsl:template name="html_head_extension">
		<style type="text/css">
			#dataserviceimage {
				float: right;
			}
			
			#owners, #lessees, #drivers {
				float: left;
				margin-right: 3%;
				min-width: 30%;
			}
			
			#recorddetails {
				clear: both;
			}
			
			h2.basiclabel {
				font-size: large;
				margin-bottom: 0px;
			}
			
			h3.detaillabel {
				font-weight: normal;
				margin-bottom: 0px;
			}
			
			.pageref {
				padding-right: 10%;
			}
			
			.label1, .label2 {
				padding-right: 2%;
			}
			
			.subjecttitle {
				text-transform: none;  /* Override the text-transform setting inherited from external stylesheets */
			}
			
			.newsection {
				margin-top: 15px;
				margin-bottom: 15px;
			}
			
			.filetype {
				float: none;  /* Override the float setting inherited from external stylesheets */
			}

      		.savexmlbuttonimage {
				width: 110px;
				height: 24px;
				border-style: none;
				background-color : transparent;
				cursor: pointer;
      		}
		</style>
		<script language="JavaScript">
			function copyxml(){
				document.form1.savexmltext1.value = document.form2.savexmltext2.value;
			}
		</script>
	</xsl:template>



	<xsl:template name="html_body">
		<img id="dataserviceimage" src="../../images/DOT.gif" alt="Wisconsin Department of Transportation"/>
		<!-- Not all of the following will be applicable on a single response -->
		<xsl:apply-templates select="doj:DOTResponseDocument/doj:Result/doj:ResultText"/>
		<xsl:apply-templates select="doj:DOTResponseDocument/doj:Result/doj:DOTLegacyText"/>
		<xsl:apply-templates select="doj:DOTResponseDocument/doj:Result/dot-veh:DOTVehicle/dot-veh:Response/dot-veh:ResponseText"/>
		<xsl:apply-templates select="doj:DOTResponseDocument/doj:Result/dot-veh:DOTVehicle/dot-veh:Response/dot-veh:VehicleRegistration"/>
	</xsl:template>



	<xsl:template match="doj:ResultText | dot-veh:ResponseText">
		<div class="resulttext">
			<h1 class="filetype"><xsl:value-of select="."/></h1>
		</div>
	</xsl:template>



	<xsl:template match="doj:DOTLegacyText">
		<!-- Currently not applicable for vehicles but since the schema allows it... -->
		<pre class="legacytext"><xsl:value-of select="."/></pre>
	</xsl:template>



	<xsl:template match="dot-veh:VehicleRegistration">
		<h1 class="filetype"><xsl:text>Vehicle Registration</xsl:text></h1>
		<!-- Display warnings at the top of the page -->
		<table border="0" width="100%" style="height: 100%;">
		<tr>
		  <td align="left">
			<xsl:apply-templates select="j:CaveatText 
		                           | dot-veh:RegistrationPlateDetails/j:CaveatText 
		                           | dot-veh:RegistrationVehicleDetails/j:CaveatText 
		                           | dot-veh:RegistrationAdditionalInformation/dot-veh:Title/j:CaveatText[@j:commentText='Warning']"/>
		  </td>
		  <td align="right">		
			<form name="form1" method="post" action="/servlet/SaveXMLResponseServlet">		
					<textarea name="saveresponsetext1" id="saveresponsetext1" style="display:none" rows="1" cols="1">
					    <xsl:text>VIN_</xsl:text>
						<xsl:value-of select="dot-veh:RegistrationVehicleDetails/j:VehicleID/j:ID"/>
					</textarea>
					<textarea name="savexmltext1" id="savexmltext1" style="display:none" rows="1" cols="1"/>		    	
   				<table border="0" align="right" cellspacing="0" cellpadding="0" width="100%" style="height: 100%;">
   					<tr>
   					    <td></td>   						
   						<td align="right" valign="bottom" height="24">
   							<button type="submit" class="savexmlbuttonimage" name="savexmlbutton1" onclick="copyxml();" >
   								<u><img src="../../images/savexmlfileicon.gif" alt="Save XML File" height="24" width="110"/></u>
   							</button>   							
   						</td>
   					</tr>
   				</table>   								
			</form>
		  </td>	                           
		</tr>
		</table>	
		<hr style="clear:right;"/>
		
		<xsl:if test="dot-veh:RegistrationVehicleDetails or dot-veh:RegistrationParty">
			<table class="newsection" style="width:auto;">
				<tr>
					<td style="padding-right: 25px;">
						<img src="../../images/VehicleIcon.jpg" alt="Vehicle Image"/>
					</td>
					<td class="subjecttitle">
            <xsl:if test="dot-veh:RegistrationVehicleDetails/j:PropertyStatus/j:StatusText">
              <div
                style="color:red;">
                <xsl:text>Status: </xsl:text>
                <xsl:apply-templates select="dot-veh:RegistrationVehicleDetails/j:PropertyStatus/j:StatusText" mode="TitleCase"/>
              </div>
            </xsl:if>
            <xsl:apply-templates select="dot-veh:RegistrationAdditionalInformation/dot-veh:Incident" mode="summary"/>
						<xsl:for-each select="dot-veh:RegistrationVehicleDetails"><!-- (1..1) -->
							<!-- [Year] [Make] [Model] [Style] [Type] [MajorColor]/[MinorColor] [Status] -->
							<div>
								<xsl:value-of select="j:VehicleModelYearDate"/>
								<xsl:text>&#32;</xsl:text>
								<xsl:apply-templates select="dot-veh:VehicleMakeCodeText" mode="TitleCase"/>
								<xsl:text>&#32;</xsl:text>
								<xsl:apply-templates select="j:VehicleModelCodeText" mode="TitleCase"/>
								<xsl:text>&#32;</xsl:text>
								<xsl:apply-templates select="dot-veh:VehicleStyleCodeText" mode="TitleCase"/>
								<xsl:text>&#32;</xsl:text>
								<xsl:apply-templates select="dot-veh:VehicleTypeText" mode="TitleCase"/>
								<xsl:text>&#32;</xsl:text>
								<xsl:apply-templates select="j:VehicleColorPrimaryText" mode="TitleCase"/>
								<xsl:if test="j:VehicleColorSecondaryText">
									<xsl:text>/</xsl:text>
									<xsl:apply-templates select="j:VehicleColorSecondaryText" mode="TitleCase"/>
								</xsl:if>
                <xsl:text>&#32;</xsl:text>
                <xsl:apply-templates select="j:PropertyStatus/j:StatusText" mode="TitleCase"/>
							</div>
						</xsl:for-each>
						<!-- VIN [VIN] Title # [Title#] -->
						<div>
							<xsl:for-each select="dot-veh:RegistrationVehicleDetails/j:VehicleID/j:ID"><!-- (0..1) -->
								<xsl:text>VIN&#32;</xsl:text>
								<xsl:value-of select="."/>
								<xsl:text>&#32;</xsl:text>
							</xsl:for-each>
							<xsl:for-each select="dot-veh:RegistrationAdditionalInformation/dot-veh:Title/j:TitleID/j:ID"><!-- (0..1) -->
								<xsl:text>Title&#160;#&#160;</xsl:text>
								<xsl:value-of select="."/>
								<xsl:text>&#32;</xsl:text>
							</xsl:for-each>
						</div>
						<!-- Owner(s) [Last, First, M] -->
						<xsl:for-each select="dot-veh:RegistrationParty"><!-- (0..*) -->
							<xsl:for-each select="j:RegistrationParty.Organization/j:OrganizationName | j:RegistrationParty.Person/j:PersonName">
								<div>
								<xsl:text>Owner(s)&#32;</xsl:text>
									<xsl:choose>
										<xsl:when test="local-name(.) = 'PersonName'">
											<xsl:apply-templates select="." mode="LastFirstMiddle"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:apply-templates select="." mode="TitleCase"/>
										</xsl:otherwise>
									</xsl:choose>
								</div>
							</xsl:for-each>
						</xsl:for-each>
					</td>
				</tr>
			</table>
		</xsl:if>
			
		<table class="newsection" style="width:auto;">
			<tr>
				<td style="padding-right: 25px;">
					<img src="../../images/Plate1.jpg" alt="License Plate Image"/>
				</td>
				<td class="subjecttitle">
					<!-- [Plate #] [Plate Type] [Status] -->
					<xsl:for-each select="dot-veh:RegistrationPlateDetails/dot-veh:RegistrationPlateEntry"><!-- (0..*) -->
						<div>
							<xsl:value-of select="j:VehicleRegistrationPlateID/j:ID"/>
							<xsl:text>&#32;</xsl:text>
							<xsl:apply-templates select="dot-veh:VehicleRegistrationPlateTypeDescriptionText" mode="TitleCase"/>
							<xsl:text>&#32;</xsl:text>
							<xsl:apply-templates select="dot-veh:VehicleRegistrationPlateStatus/j:StatusText" mode="TitleCase"/>
						</div>
					</xsl:for-each>
					<!-- [State (only if WI)] Expiration [MM/DD/YYYY] -->
					<xsl:for-each select="dot-veh:RegistrationDetails"><!-- (0..*) -->
						<div>
							<xsl:if test="j:RegistrationJurisdictionCode.ncicLIS != 'WI'">
								<xsl:value-of select="j:RegistrationJurisdictionCode.ncicLIS"/>
								<xsl:text>&#32;</xsl:text>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="j:RegistrationExpirationDate">
									<xsl:text>Expiration&#32;</xsl:text>
									<xsl:apply-templates select="j:RegistrationExpirationDate" mode="FormatFullDateAsMMDDYYYY"/>
								</xsl:when>
								<xsl:when test="j:VehicleRegistrationDecal/j:DecalPeriodText = 'NON EXPIRING'">
									<xsl:apply-templates select="j:VehicleRegistrationDecal/j:DecalPeriodText" mode="TitleCase"/>
								</xsl:when>
							</xsl:choose>
						</div>
					</xsl:for-each>
				</td>
			</tr>
		</table>
		
		<!-- Section Image Links (Record Details, Insurance Details, and Lien Holder Details) -->
		<table class="newsection">
			<tr>
				<td>
					<xsl:if test="dot-veh:RegistrationDetails">
						<span class="pageref">
							<a href="#recorddetails{$responseId}"><img src="../../images/RecordDetails.jpg"/></a>
						</span>
					</xsl:if>
					<xsl:if test="dot-veh:RegistrationAdditionalInformation/dot-veh:Insurance">
						<span class="pageref">
							<a href="#insurancedetails{$responseId}"><img src="../../images/InsuranceDetails.jpg"/></a>
						</span>
					</xsl:if>
					<xsl:if test="dot-veh:RegistrationAdditionalInformation/dot-veh:LienHolder">
						<span class="pageref">
							<a href="#lienholderdetails{$responseId}"><img src="../../images/LienHolderDetails.jpg"/></a>
						</span>
					</xsl:if>
				</td>
			</tr>
		</table>
		
		<div>
			<!-- Owner(s): -->
			<div id="owners">
				<xsl:apply-templates select="dot-veh:RegistrationParty[@dot-veh:ownershipType = 'Primary']"/>
				<xsl:apply-templates select="dot-veh:RegistrationParty[@dot-veh:ownershipType != 'Primary']"/>
			</div>
			<!-- Lessee(s): -->
			<div id="lessees">
				<xsl:apply-templates select="dot-veh:RegistrationAdditionalInformation/j:Lessee"/>
			</div>
			<!-- Driver(s):: -->
			<div id="drivers">
				<xsl:apply-templates select="dot-veh:RegistrationAdditionalInformation/dot-veh:Driver"/>
			</div>
		</div>
		
		<!-- Record Details: -->
		<xsl:if test="dot-veh:RegistrationDetails 
		              or dot-veh:RegistrationVehicleDetails/j:PropertyAssignedIDDetails 
		              or dot-veh:RegistrationVehicleDetails/dot-veh:VehicleBrandDetails
		              or dot-veh:RegistrationAdditionalInformation/dot-veh:Title/j:TitleStatusText
		              or dot-veh:RegistrationAdditionalInformation/dot-veh:Title/dot-veh:TitleStatusDescriptionText
		              or dot-veh:RegistrationAdditionalInformation/dot-veh:Title/dot-veh:TitleReturnedState/j:LocationStateName
		              or dot-veh:RegistrationAdditionalInformation/dot-veh:Title/j:CaveatText[@j:commentText='Notation']
		              or dot-veh:RegistrationVehicleDetails/j:LocationCityName
		              or dot-veh:RegistrationVehicleDetails/j:LocationCountyName">
			<div id="recorddetails" class="newsection">
				<a name="recorddetails{$responseId}">
					<h3 class="detaillabel">Record Details:</h3>
				</a>
				<table class="detailvalue" cellpadding="0" cellspacing="0">
					<xsl:call-template name="DefineLabelValueColumns"/>
					<!-- Renewal Period, Registration Type, Registration Status, Gross Weight, Carrier Class, and Last Updated -->
					<xsl:apply-templates select="dot-veh:RegistrationDetails"/>
					<!-- Alternate Id Type and Alternate Id Number -->
					<xsl:apply-templates select="dot-veh:RegistrationVehicleDetails/j:PropertyAssignedIDDetails"/>
					<!-- Brand and Brand Origin -->
					<xsl:apply-templates select="dot-veh:RegistrationVehicleDetails/dot-veh:VehicleBrandDetails"/>
					<!-- Title Status and Title Reason -->
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1" select="'Title Status:'"/>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="dot-veh:RegistrationAdditionalInformation/dot-veh:Title/j:TitleStatusText" mode="TitleCase"/>
						</xsl:with-param>
						<xsl:with-param name="label2" select="'Title Reason:'"/>
						<xsl:with-param name="value2">
							<xsl:apply-templates select="dot-veh:RegistrationAdditionalInformation/dot-veh:Title/dot-veh:TitleStatusDescriptionText" mode="TitleCase"/>
						</xsl:with-param>
					</xsl:call-template>
					<!-- Title Returned -->
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1" select="'Title Returned:'"/>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="dot-veh:RegistrationAdditionalInformation/dot-veh:Title/dot-veh:TitleReturnedState/j:LocationStateName" mode="TitleCase"/>
						</xsl:with-param>
						<xsl:with-param name="label2" select="'Title Notation:'"/>
						<xsl:with-param name="value2" select="dot-veh:RegistrationAdditionalInformation/dot-veh:Title/j:CaveatText[@j:commentText='Notation']"/>
					</xsl:call-template>
					<!-- Vehicle Kept In City and Vehicle Kept In County -->
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1" select="'Vehicle Kept In City:'"/>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="dot-veh:RegistrationVehicleDetails/j:LocationCityName" mode="TitleCase"/>
						</xsl:with-param>
						<xsl:with-param name="label2" select="'Vehicle Kept In County:'"/>
						<xsl:with-param name="value2">
							<xsl:apply-templates select="dot-veh:RegistrationVehicleDetails/j:LocationCountyName" mode="TitleCase"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:for-each select="dot-veh:RegistrationDetails/j:CaveatText">
						<tr>
							<td>
								<xsl:if test="position() = 1">
									<xsl:value-of select="'Comments:'"/>
								</xsl:if>
							</td>
							<td colspan="3"><xsl:value-of select="."/></td>
						</tr>
					</xsl:for-each>
				</table>
			</div>
		</xsl:if>
		
		<!-- Insurance Details: -->
		<xsl:apply-templates select="dot-veh:RegistrationAdditionalInformation/dot-veh:Insurance"/>
		
		<!-- Lien Holder Details: -->
		<xsl:apply-templates select="dot-veh:RegistrationAdditionalInformation/dot-veh:LienHolder"/>

		<!-- Incidents -->
		<xsl:apply-templates select="dot-veh:RegistrationAdditionalInformation/dot-veh:Incident/j:ActivityDocumentIssuerOrganization" mode="parkingTickets"/>
  
	</xsl:template><!-- dot-veh:VehicleRegistration -->



	<xsl:template match="j:CaveatText">
		<div class="caveat">
			<xsl:choose>
				<xsl:when test="parent::dot-veh:RegistrationPlateDetails">
					<xsl:text>Plate Warning:&#32;</xsl:text>
				</xsl:when>
				<xsl:when test="parent::dot-veh:RegistrationVehicleDetails and self::node()[@j:commentText='Warning']">
					<xsl:text>Vehicle Warning:&#32;</xsl:text>
				</xsl:when>
				<!--
				No label needed for the Vehicle Record Not Found text (per CIB 10/3/2006)
				<xsl:when test="parent::dot-veh:RegistrationVehicleDetails and self::node()[@j:commentText='NotFound']">
					<xsl:text>Vehicle Record Not Found:&#32;</xsl:text>
				</xsl:when>
				-->
				<xsl:when test="parent::dot-veh:Title and self::node()[@j:commentText='Warning']">
					<xsl:text>Title Warning:&#32;</xsl:text>
				</xsl:when>
			</xsl:choose>
			<xsl:value-of select="."/>
		</div>
	</xsl:template>



	<!-- Primary Owner -->
	<xsl:template match="dot-veh:RegistrationParty[@dot-veh:ownershipType = 'Primary']">
		<div class="newsection">
			<h2 class="basiclabel">Owner(s):</h2>
			<div class="basicvalue">
				<xsl:apply-templates select="j:RegistrationParty.Person | j:RegistrationParty.Organization"/>
			</div>
			<xsl:apply-templates select="@dot-veh:ownerOperatorIndicator">
				<xsl:with-param name="theType" select="'Owner'"/>
			</xsl:apply-templates>
		</div>
	</xsl:template>



	<!-- Non-Primary Owner(s) -->
	<xsl:template match="dot-veh:RegistrationParty[@dot-veh:ownershipType != 'Primary']">
		<!-- @dot-veh:ownershipType is either 'And' or 'Or'-->
		<div class="newsection">
			<div class="basicvalue">
				<p style="text-transform:uppercase;">
					<xsl:value-of select="@dot-veh:ownershipType"/>
				</p>
				<div>
					<xsl:apply-templates select="j:RegistrationParty.Organization | j:RegistrationParty.Person"/>
				</div>
				<xsl:apply-templates select="@dot-veh:ownerOperatorIndicator">
					<xsl:with-param name="theType" select="'Owner'"/>
				</xsl:apply-templates>
			</div>
		</div>
	</xsl:template>



	<!-- Lessee(s): -->
	<xsl:template match="j:Lessee">
		<div class="newsection">
			<xsl:if test="position() = 1">
				<a name="lessees{$responseId}"/>
				<h2 class="basiclabel">Lessee(s):</h2>
			</xsl:if>
			<div class="basicvalue">
				<xsl:apply-templates select="j:LesseeParty.Person | j:LesseeParty.Organization"/>
			</div>			
			<xsl:apply-templates select="@dot-veh:ownerOperatorIndicator">
				<xsl:with-param name="theType" select="'Lessee'"/>
			</xsl:apply-templates>
		</div>
	</xsl:template>


	
	<!-- Driver(s): -->
	<xsl:template match="dot-veh:Driver">
		<div class="newsection">
			<xsl:if test="position() = 1">
				<h2 class="basiclabel">Driver(s):</h2>
			</xsl:if>
			<div class="basicvalue">
				<xsl:apply-templates select="j:Person | j:Organization"/>
			</div>
			<xsl:apply-templates select="@dot-veh:ownerOperatorIndicator">
				<xsl:with-param name="theType" select="'Driver'"/>
			</xsl:apply-templates>
		</div>
	</xsl:template>



	<!-- Record Details: Renewal Period, Registration Type, Registration Status, Gross Weight, Carrier Class, and Last Updated -->
	<xsl:template match="dot-veh:RegistrationDetails">
		<div>
			<xsl:if test="position() > 1">
				<xsl:attribute name="class">newsection</xsl:attribute>
			</xsl:if>
			
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Renewal Period:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:VehicleRegistrationDecal/j:DecalPeriodText" mode="TitleCase"/>
				</xsl:with-param>
				<xsl:with-param name="label2" select="'Registration Type:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="dot-veh:RegistrationTypeText" mode="TitleCase"/>
				</xsl:with-param>
			</xsl:call-template>
			
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Registration Status:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:RegistrationStatus/j:StatusText" mode="TitleCase"/>
				</xsl:with-param>
				<xsl:with-param name="label2" select="'Registration Reason:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="j:RegistrationStatus/j:StatusDescriptionText" mode="TitleCase"/>
				</xsl:with-param>
			</xsl:call-template>
			
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Gross Weight:'"/>
				<xsl:with-param name="value1" select="j:VehicleRegistrationGrossWeightMeasure"/>
				<xsl:with-param name="label2" select="'Carrier Class:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="dot-veh:CarrierClassText" mode="TitleCase"/>
				</xsl:with-param>
			</xsl:call-template>
			
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Last Updated:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="dot-veh:RegistrationLastModifiedDate" mode="FormatFullDateAsMMDDYYYY"/>
					<xsl:if test="dot-veh:RegistrationLastModifiedTime">
						<xsl:text>&#32;</xsl:text>
						<xsl:value-of select="dot-veh:RegistrationLastModifiedTime"/>
					</xsl:if>
				</xsl:with-param>
			</xsl:call-template>
		</div>
	</xsl:template>



	<!-- Record Details:  Alternate Id Type and Alternate Id Number -->
	<xsl:template match="j:PropertyAssignedIDDetails">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Alternate Id Type:'"/>
			<xsl:with-param name="value1">
				<xsl:apply-templates select="dot-veh:PropertyOtherIDTypeText" mode="TitleCase"/>
			</xsl:with-param>
			<xsl:with-param name="label2" select="'Alternate Id Number:'"/>
			<xsl:with-param name="value2" select="j:PropertyOtherID/j:ID"/>
		</xsl:call-template>
	</xsl:template>



	<!-- Record Details:  Brand and Brand Origin -->
	<xsl:template match="dot-veh:VehicleBrandDetails">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Brand:'"/>
			<xsl:with-param name="value1">
				<xsl:apply-templates select="j:VehicleBrand/j:VehicleBrandText" mode="TitleCase"/>
			</xsl:with-param>
			<xsl:with-param name="label2" select="'Brand Origin:'"/>
			<xsl:with-param name="value2" select="j:VehicleBrander/j:BranderID/j:ID"/>
		</xsl:call-template>
	</xsl:template>



	<!-- Insurance Details: -->
	<xsl:template match="dot-veh:RegistrationAdditionalInformation/dot-veh:Insurance">
		<div class="newsection">
			<a name="insurancedetails{$responseId}">
				<h3 class="detaillabel">Insurance Details:</h3>
			</a>
			<table class="detailvalue" cellpadding="0" cellspacing="0">
				<xsl:call-template name="DefineLabelValueColumns"/>
				<!-- US DOT Number and WI Account Number -->
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'US DOT Number:'"/>
					<xsl:with-param name="value1" select="dot-veh:USDepartmentOfTransportationInsuranceNumber"/>
					<xsl:with-param name="label2" select="'WI Account Number:'"/>
					<xsl:with-param name="value2" select="dot-veh:WisconsinInsuranceAccountNumber"/>
				</xsl:call-template>
				<!-- Insurance Type and Insurance Number (0..*) -->
				<xsl:for-each select="dot-veh:InsuranceEntryDetails">
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1" select="'Insurance Type:'"/>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="dot-veh:InsuranceTypeText" mode="TitleCase"/>
						</xsl:with-param>
						<xsl:with-param name="label2" select="'Insurance Number:'"/>
						<xsl:with-param name="value2" select="dot-veh:InsuranceNumber"/>
					</xsl:call-template>
				</xsl:for-each>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Record Not Found:'"/>
					<xsl:with-param name="value1" select="j:CaveatText[@j:commentText='NotFound']"/>
					<xsl:with-param name="label2" select="'Insurance Error:'"/>
					<xsl:with-param name="value2" select="j:CaveatText[@j:commentText='Error']"/>
				</xsl:call-template>
			</table>
		</div>
	</xsl:template>



	<!-- Lien Holder Details: -->
	<xsl:template match="dot-veh:RegistrationAdditionalInformation/dot-veh:LienHolder">
		<div class="newsection">
			<a name="lienholderdetails{$responseId}">
				<h3 class="detaillabel">Lien Holder Details:</h3>
			</a>
			<table class="detailvalue" cellpadding="0" cellspacing="0">
				<colgroup>
					<col width="25%" class="label1"/>
				</colgroup>
				<!-- Secured Party -->
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Secured Party:'"/>
					<xsl:with-param name="value1" select="dot-veh:LienHolderSecuredPartyNumber"/>
				</xsl:call-template>
				<!-- Secured Party Name -->
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Secured Party Name:'"/>
					<xsl:with-param name="value1">
						<xsl:apply-templates select="dot-veh:LienHolderName" mode="TitleCase"/>
					</xsl:with-param>
				</xsl:call-template>
				<!-- Address -->
				<xsl:if test="j:LocationAddress">
					<tr>
						<td style="padding-left:10%;">
							<xsl:text>Address:</xsl:text>
						</td>
						<td>
							<xsl:apply-templates select="j:LocationAddress"/>
						</td>
					</tr>
				</xsl:if>
			</table>
		</div>
	</xsl:template>



	<!-- Incidents: -->
  <xsl:template match="dot-veh:RegistrationAdditionalInformation/dot-veh:Incident" mode="summary">
    <div
      style="color:red;">
      <xsl:apply-templates select="dot-veh:IncidentEvent/dot-veh:EventActionText" mode="TitleCase"/>
      <xsl:text>-</xsl:text>
      <xsl:apply-templates select="dot-veh:IncidentEvent/j:EventTypeText" mode="TitleCase"/>
      <xsl:text> </xsl:text>
      <xsl:apply-templates select="j:Sanction/j:SanctionTypeText" mode="TitleCase"/>
      <xsl:if test="j:ActivityDocumentIssuerOrganization">
        <xsl:text> </xsl:text>
        <a href="#incidents{$responseId}" style="color:red;">Details</a>
      </xsl:if>
    </div>
  </xsl:template>
	<xsl:template match="dot-veh:RegistrationAdditionalInformation/dot-veh:Incident/j:ActivityDocumentIssuerOrganization" mode="parkingTickets">
		<div>
  		<xsl:if test="position() = 1">
		  	<a name="incidents{$responseId}" class="newsection">
					<h3 class="detaillabel">Unpaid Parking Ticket Details:</h3>
			  </a>
			</xsl:if>
			<table class="detailvalue" cellpadding="0" cellspacing="0">
        <colgroup>
          <col width="25%" class="label1"/>
        </colgroup>
        <tr>
          <td valign="top">
            Agency Name:
          </td>
          <td valign="top">
            <xsl:apply-templates select="j:OrganizationName" mode="TitleCase"/>
          </td>
        </tr>
        <tr>
          <td valign="top">
            Address:
          </td>
          <td valign="top">
            <xsl:apply-templates select="j:OrganizationLocation/j:LocationAddress"/>
          </td>
        </tr>
        <xsl:if test="../j:Fee.Detailed/j:FinancialObligationDueAmount">
          <tr>
            <td valign="top">
              Amount Due:
            </td>
            <td valign="top">
              <xsl:text>$</xsl:text><xsl:value-of select="../j:Fee.Detailed/j:FinancialObligationDueAmount"/>
            </td>
          </tr>
        </xsl:if>
			</table>
		</div>
	</xsl:template>



	<!-- 
	###################################
			REUSABLE TEMPLATES:
	###################################
	-->	
	
	<xsl:template name="DefineLabelValueColumns">
    <xsl:if test="$from='ebc'">
		<colgroup>
			<col width="25%" class="label1"/>
			<col width="25%"/>
			<col width="25%" class="label2"/>
		</colgroup>
    </xsl:if>
	</xsl:template>



	<xsl:template match="j:RegistrationParty.Person | j:Person | j:LesseeParty.Person">
		<div>
			<xsl:apply-templates select="j:PersonName" mode="LastFirstMiddle"/>
		</div>
		<xsl:if test="j:PersonBirthDate">
			<div>
				<xsl:text>DOB:&#160;&#160;</xsl:text>
				<xsl:apply-templates select="j:PersonBirthDate" mode="FormatFullDateAsMMDDYYYY"/>
				<xsl:text> </xsl:text>
				<xsl:variable name="lastName" select="j:PersonName/j:PersonSurName" />
				<xsl:variable name="firstName" select="j:PersonName/j:PersonGivenName" />
				<xsl:variable name="middleName" select="j:PersonName/j:PersonMiddleName" />
				<xsl:variable name="dob" select="j:PersonBirthDate" />
				<form id="fullRecordRequest_{$lastName}_{$firstName}" action="/secure/personsearch/builddl.jsp" method="post" style="display:inline">
					<input name="lastName" type="hidden" value="{$lastName}" />
					<input name="firstName" type="hidden" value="{$firstName}" />
					<input name="middleName" type="hidden" value="{$middleName}" />
					<input name="dob" type="hidden" value="{$dob}" />
					<input name="source" type="hidden" value="DOT" />
				</form>
				<a href="javascript:document.getElementById('fullRecordRequest_{$lastName}_{$firstName}').submit();">Click here to submit driver query</a>
			</div>
		</xsl:if>
    <xsl:if test="j:DriverLicense/j:DriverAuthorizationID.Detailed/j:ID">
      <div>
        <xsl:text>DL:&#160;&#160;</xsl:text>
        <xsl:value-of select="j:DriverLicense/j:DriverAuthorizationID.Detailed/j:ID"/>
      </div>
    </xsl:if>
		<xsl:apply-templates select="j:Residence/j:LocationAddress"/>
	</xsl:template>



	<xsl:template match="j:RegistrationParty.Organization | j:Organization | j:LesseeParty.Organization">
		<xsl:for-each select="j:OrganizationName[@j:commentText = 'Owner' or @j:commentText = 'Company']">
			<div>
				<xsl:apply-templates select="." mode="TitleCase"/>
			</div>
		</xsl:for-each>
		<xsl:for-each select="j:OrganizationName[@j:commentText = 'Carrier']">
			<div>
				<xsl:text>Carrier:&#160;&#160;</xsl:text>
				<xsl:apply-templates select="." mode="TitleCase"/>
			</div>
		</xsl:for-each>
		<xsl:for-each select="j:OrganizationName[@j:commentText = 'DoingBusinessAs']">
			<div>
				<xsl:text>DBA:&#160;&#160;</xsl:text>
				<xsl:apply-templates select="." mode="TitleCase"/>
			</div>
		</xsl:for-each>
		<xsl:apply-templates select="j:OrganizationLocation/j:LocationAddress"/>
	</xsl:template>


	
	<xsl:template match="@dot-veh:ownerOperatorIndicator">
		<xsl:param name="theType"/>
		<div class="basicvalue">
			<xsl:value-of select="$theType"/>
			<xsl:text>&#32;Operator Indicator:&#160;&#160;</xsl:text>
			<xsl:apply-templates select="." mode="FormatBooleanAsYesNo"/>
		</div>
	</xsl:template>



	<xsl:template match="j:PersonName" mode="LastFirstMiddle">
		<xsl:apply-templates select="j:PersonSurName" mode="TitleCase"/>
		<xsl:text>,&#32;</xsl:text>
		<xsl:apply-templates select="j:PersonGivenName" mode="TitleCase"/>
		<xsl:text>&#32;</xsl:text>
		<xsl:apply-templates select="j:PersonMiddleName" mode="TitleCase"/>
	</xsl:template>



	<xsl:template match="j:LocationAddress">
    <xsl:for-each select="j:LocationStreet/j:StreetFullText"><!-- (0..2) -->
      <div>
        <xsl:apply-templates select="." mode="TitleCase"/>
      </div>
    </xsl:for-each>
    <xsl:if test="j:AddressMailDeliveryUnitText">
      <div>
        <xsl:text>PO Box&#160;</xsl:text>
        <xsl:value-of select="j:AddressMailDeliveryUnitText"/>
      </div>
    </xsl:if>
    <div>
      <xsl:apply-templates select="j:LocationCityName" mode="TitleCase"/>
      <xsl:if test="j:LocationStateName">
        <xsl:if test="j:LocationCityName">
          <xsl:text>,&#32;</xsl:text>
        </xsl:if>
        <xsl:value-of select="j:LocationStateName"/>
      </xsl:if>
      <xsl:if test="j:LocationPostalCodeID/j:ID">
        <xsl:if test="j:LocationCityName or j:LocationStateName">
          <xsl:text>&#160;&#160;</xsl:text>
        </xsl:if>
        <xsl:value-of select="j:LocationPostalCodeID/j:ID"/>
        <xsl:if test="j:LocationPostalCodeExtensionID/j:ID">
          <xsl:text>-</xsl:text>
          <xsl:value-of select="j:LocationPostalCodeExtensionID/j:ID"/>
        </xsl:if>
      </xsl:if>
      <xsl:if test="j:LocationCountyName">
          <xsl:text>&#32;County:&#160;&#160;</xsl:text>
          <xsl:apply-templates select="j:LocationCountyName" mode="TitleCase"/>
      </xsl:if>
    </div>
  </xsl:template>


	
</xsl:transform>