<?xml version="1.0"?>
<!-- xmlns:java="http://xml.apache.org/xslt/java" exclude-result-prefixes="java" -->

<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  xmlns:rap="http://www.nlets.org/rapsheet/3.0"
  xmlns:doj="http://www.doj.state.wi.us/dles/cib/nlets/response"
  xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
  xmlns:j="http://www.it.ojp.gov/jxdm/3.0"
  xmlns:j2="http://www.it.ojp.gov/jxdm/3.0.2"
  xmlns:n="http://www.nlets.org"
  xmlns:xalan="http://xml.apache.org/xslt"
  exclude-result-prefixes="xsl xsi doj doj-ext j j2 n rap xalan">

  <xsl:import href="../raputility.xsl" />
  <xsl:import href="../css.xsl" />
  <xsl:import href="../common.xsl" />
  <xsl:output method="html" />
  <xsl:param name="from" />
  <xsl:param name="responseId">
    <xsl:value-of
      select="doj:NLETSResponseDocument/@doj-ext:responseID" />
  </xsl:param>

  <xsl:template match="/">
    <xsl:choose>
      <xsl:when test="$from='ebc'">
        <xsl:call-template name="html_main" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="html_head_extension" />
        <xsl:call-template name="html_body" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="html_title">Rapsheet</xsl:template>

  <xsl:template name="html_head_extension">
    <xsl:call-template name="rapsheet_css" />
  </xsl:template>

  <xsl:template name="html_body">
    <xsl:apply-templates select="doj:NLETSResponseDocument" />
  </xsl:template>

  <!-- Main controlling template -->
  <xsl:template match="doj:NLETSResponseDocument">
    <div>
      <xsl:call-template name="subheader" />
    </div>
    <div>
      <p />
      <table width="100%">
        <tr>
          <td class="wisconsin_criminal_history width75percent">
            <xsl:value-of select="substring(doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseHeader/j:DocumentSource.Organization/j:OrganizationORIID/j:ID,1,2)" />
            <xsl:text> Criminal History</xsl:text>
          </td>
          <td class="reported_date">
            <xsl:text>Date:&#32;</xsl:text>
            <xsl:call-template name="currentDate" />
          </td>
        </tr>
      </table>
      <p />
    </div>
    <xsl:choose>
      <xsl:when test="doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/rap:RapSheet">
        <div>
          <xsl:apply-templates
            select="doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/rap:RapSheet/j2:Subject"
            mode="header_flag_section" />
        </div>
        <div>
          <xsl:apply-templates
            select="doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/rap:RapSheet/rap:Introduction" />
        </div>
        <div>
          <xsl:apply-templates
            select="doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/rap:RapSheet/j2:Subject"
            mode="caution_other" />
        </div>
        <div>
          <xsl:call-template name="header_buttons" />
        </div>
        <div>
          <hr />
        </div>
        <a name="identification{$responseId}"></a>
        <div class="identification">
          <xsl:text>Identification</xsl:text>
        </div>
        <div>
          <xsl:apply-templates
            select="doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/rap:RapSheet/j2:Subject"
            mode="caution_death" />
        </div>
        <div>
          <xsl:apply-templates
            select="doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/rap:RapSheet/j2:Subject"
            mode="subject_details" />
        </div>
        <div>
          <hr />
        </div>
        <xsl:if test="doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/rap:RapSheet/rap:Cycle">
	        <a name="history{$responseId}"></a>
	        <span class="criminal_history">Criminal History</span>
	        <p />
	        <xsl:apply-templates
	          select="doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/rap:RapSheet/rap:Cycle" />
	        <div>
	          <hr />
	        </div>
        </xsl:if>
        <xsl:apply-templates
          select="doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/rap:RapSheet/j2:Organization" />
      </xsl:when>
      <xsl:otherwise>
        <pre>
          <xsl:value-of select="doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/n:ResponseText"/>
        </pre>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- images under navigation bar -->
  <xsl:template name="subheader">
    <div align="right">
      <xsl:element name="img">
        <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'nlets.gif')"/></xsl:attribute>
        <xsl:attribute name="alt">nletslogo</xsl:attribute>
        <xsl:attribute name="id">dataserviceimage</xsl:attribute>
        <xsl:attribute name="width">100</xsl:attribute>
      </xsl:element>
      <xsl:element name="img">
        <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'spacer.gif')"/></xsl:attribute>
        <xsl:attribute name="height">1</xsl:attribute>
        <xsl:attribute name="width">100</xsl:attribute>
      </xsl:element>
    </div>
  </xsl:template>

  <!-- flags -->
  <xsl:template match="j2:Subject" mode="header_flag_section">
    <table>
      <xsl:if
        test="j2:PersonFirearmSalesDisqualifiedIndicator = 'true'">
        <tr>
          <td>
            <xsl:text>&#160;&#160;&#160;</xsl:text>
            <xsl:element name="img">
              <xsl:attribute name="class">flag_img</xsl:attribute>
              <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'firearmDisqualifier.jpg')"/></xsl:attribute>
              <xsl:attribute name="alt">gun</xsl:attribute>
            </xsl:element>
          </td>
          <td class="flag">
            <xsl:text>Firearm&#32;Sale&#32;Disqualified&#32;</xsl:text>
            <xsl:apply-templates
              select="j2:PersonFirearmSalesDisqualifiedIndicator[.='true']"
              mode="all_attributes" />
          </td>
        </tr>
      </xsl:if>

      <xsl:if
        test="j2:SubjectCautionInformationCaveat = 'Convicted Felon'">
        <tr>
          <td>
            <xsl:element name="img">
              <xsl:attribute name="class">flag_img</xsl:attribute>
              <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'convictedfelon.gif')"/></xsl:attribute>
              <xsl:attribute name="alt">felon</xsl:attribute>
            </xsl:element>
          </td>
          <td class="flag">
            <xsl:text>Convicted Felon</xsl:text>
            <xsl:apply-templates
              select="j2:SubjectCautionInformationCaveat[.='Convicted Felon']"
              mode="all_attributes" />
          </td>
        </tr>
      </xsl:if>

      <xsl:if test="j2:PersonRegisteredOffenderIndicator = 'true'">
        <tr>
          <td>
            <xsl:element name="img">
              <xsl:attribute name="class">flag_img</xsl:attribute>
              <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'sexOffender.gif')"/></xsl:attribute>
              <xsl:attribute name="alt">sex_offender</xsl:attribute>
            </xsl:element>
          </td>
          <td class="flag">
            <xsl:text>Registered&#32;Sex&#32;Offender&#32;</xsl:text>
            <xsl:apply-templates
              select="j2:PersonRegisteredOffenderIndicator[.='true']"
              mode="all_attributes" />
          </td>
        </tr>
      </xsl:if>
    </table>
  </xsl:template>

  <!-- Introduction -->
  <xsl:template match="rap:Introduction">
    <p />
    <table border="0">
      <xsl:if test="rap:RapSheetRequest/rap:PurposeCode">
        <tr>
          <td class="purpose_code width25percent">
            <xsl:text>Purpose Code:</xsl:text>
          </td>
          <td class="purpose_code width75percent">
            <xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
            <xsl:value-of select="rap:RapSheetRequest/rap:PurposeCode" />
          </td>
        </tr>
      </xsl:if>
      <xsl:if test="rap:RapSheetRequest/rap:Attention">
        <tr>
          <td class="purpose_code width25percent">
            <xsl:text>Attention:</xsl:text>
          </td>
          <td class="purpose_code width75percent mixedcase">
            <xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
            <xsl:value-of select="rap:RapSheetRequest/rap:Attention" />
          </td>
          <!-- <td class="purpose_code width75percent">
            <xsl:value-of select="rap:RapSheetRequest"/>
            </td> -->
        </tr>
      </xsl:if>
    </table>
    <p />
    <xsl:apply-templates select="rap:Caveat" />
  </xsl:template>

  <!-- Caveat -->
  <xsl:template match="rap:Caveat">
    <!-- div class="caveat uppercase">
      <xsl:text>SEPARATE CAVEAT:&#32;</xsl:text>
      <xsl:value-of select="j2:CaveatIssuingAuthorityName"/>
      </div -->
    <table border="0">
      <tr>
        <td class="caveat" style="max-width:750px;">
          <xsl:value-of select="j2:CaveatText" />
        </td>
      </tr>
    </table>
    <div class="caveat uppercase">
      <xsl:apply-templates select="j2:CaveatReferenceDate"
        mode="FormatFullDateAsMMDDYYYY" />
    </div>
    <p />
  </xsl:template>

  <xsl:template match="j2:Subject" mode="caution_other">
    <table>
      <xsl:if
        test="j2:SubjectCautionInformationCaveat != 'Convicted Felon'">
        <tr>
          <td class="caution width10percent" valign="top">
            <xsl:text>CAUTION:</xsl:text>
          </td>
          <td class="caution width75percent" valign="top" colspan="2">
            <xsl:for-each select="j2:SubjectCautionInformationCaveat">
              <xsl:value-of select="." />
              <xsl:apply-templates select="." mode="reportedDate" />
              <br />
            </xsl:for-each>
          </td>
        </tr>
      </xsl:if>
    </table>
  </xsl:template>

  <!-- buttons under caveat-->
  <xsl:template name="header_buttons">
    <div align="center">
      <span style="background-color: blue;">
        &#160;
        <a style="color: white; font-size: medium"
          href="#identification{$responseId}">
          Identification
        </a>
        &#160;
      </span>
      <xsl:text>&#160;&#160;</xsl:text>
      <span style="background-color: blue;">
        &#160;
        <a style="color: white; font-size: medium"
          href="#history{$responseId}">
          Criminal History
        </a>
        &#160;
      </span>
      <xsl:text>&#160;&#160;</xsl:text>
      <span style="background-color: blue;">
        &#160;
        <a style="color: white; font-size: medium"
          href="#contributing{$responseId}">
          Contributing Agencies
        </a>
        &#160;
      </span>
      <xsl:text>&#160;&#160;</xsl:text>
      <xsl:if test="$from='ebc'">
        <span style="background-color: blue;">
          &#160;
          <a style="color: white; font-size: medium"
            href="#request{$responseId}">
            Your Request
          </a>
          &#160;
        </span>
        <xsl:text>&#160;&#160;</xsl:text>
      </xsl:if>
    </div>
  </xsl:template>

  <!-- Subject Caution Information and Death Information -->
  <xsl:template match="j2:Subject" mode="caution_death">
    <table width="100%">
      <tr>
        <td class="death_living" colspan="2">
          <xsl:for-each select="j2:PersonLivingIndicator">
            <xsl:text>Living status:&#160;</xsl:text>
            <xsl:choose>
              <xsl:when test=".='true'">
                <xsl:text>LIVING</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>DECEASED</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
            <xsl:apply-templates select="." mode="reportedDate" />
            <xsl:apply-templates select="."
              mode="reportingOrganizationText" />
            <xsl:apply-templates select="." mode="commentText" />
            <br />
          </xsl:for-each>
          <xsl:for-each select="j2:PersonDeathDate">
            <xsl:text>Death date:&#160;</xsl:text>
            <xsl:apply-templates select="."
              mode="FormatFullDateAsMMDDYYYY" />
            <br />
          </xsl:for-each>
        </td>
      </tr>
    </table>
  </xsl:template>

  <!-- Controlling template for subject details -->
  <xsl:template match="j2:Subject" mode="subject_details">
    <table width="100%">
      <tr>
        <td class="width80percent">
          <table width="100%">
            <xsl:apply-templates select="j2:PersonName" mode="subject_name"/>
            <tr>
              <td colspan="2">
               <div class="detailvalue">
                  <xsl:apply-templates select="j2:PersonPhysicalDetails" mode="gender_race" />
                  <xsl:apply-templates select="j2:PersonBirthLocation" mode="birth_location" />
                  <xsl:apply-templates select="j2:PersonSocialDetails" />
                  <xsl:apply-templates select="j2:PersonBirthDate" />
                  <xsl:apply-templates select="j2:PersonPhysicalDetails" mode="height_to_skin" />
                  <xsl:apply-templates select="j2:PersonBiometricDetails" mode="blood_type" />
                  <xsl:apply-templates select="j2:Residence" mode="subject_residence" />
                </div>
              </td>
            </tr>
          </table>
        </td>
        <td class="width20percent centered_top" align="right">
			<br/>
				<xsl:apply-templates select="j2:PersonBiometricDetails/j2:PersonDigitalImage" mode="image" />
		</td>
		</tr>
		<tr>
			<td><br/></td><td></td>
		</tr>
    </table>
    <xsl:call-template name="SMT_Photo_Links" />
    <xsl:apply-templates select="." mode="ssn_to_notice" />
    <xsl:apply-templates
      select="j2:PersonPhysicalDetails/j2:PersonPhysicalFeature"
      mode="subject_physical" />
    <xsl:apply-templates select="." mode="alias_name" />
    <xsl:apply-templates select="j2:PersonBiometricDetails/j2:PersonDigitalImage" />
  </xsl:template>

  <!-- Matches any element - if element has reportedDate attribute it attaches a phrase -->
  <xsl:template match="*" mode="reportedDate">
    <xsl:text>&#32;</xsl:text>
    <xsl:if test="@j2:reportedDate">
      <xsl:text>as of&#160;</xsl:text>
      <xsl:apply-templates select="@j2:reportedDate"
        mode="FormatFullDateAsMMDDYYYY" />
      <xsl:text>&#32;</xsl:text>
    </xsl:if>
  </xsl:template>

  <!-- Matches any element - if element has reportingOrganizationText attribute it attaches a phrase -->
  <xsl:template match="*" mode="reportingOrganizationText">
   <xsl:text>&#32;</xsl:text>
    <xsl:if test="@j2:reportingOrganizationText">
      <xsl:text>reported by&#160;</xsl:text>
      <xsl:value-of select="@j2:reportingOrganizationText" />
      <xsl:text>&#32;</xsl:text>
    </xsl:if>
  </xsl:template>

  <!-- Matches any element - if element has commentText attribute it attaches a phrase -->
  <xsl:template match="*" mode="commentText">
    <xsl:text>&#32;</xsl:text>
    <xsl:if test="@j2:commentText">
      <xsl:text>--</xsl:text>
      <xsl:text>&#32;</xsl:text>
      <xsl:value-of select="@j2:commentText" />
      <xsl:text>&#32;</xsl:text>
    </xsl:if>
  </xsl:template>

  <!-- an alternate way to display attributes -->
  <xsl:template match="*" mode="all_attributes">
    <xsl:apply-templates select="." mode="reportedDate" />
    <xsl:apply-templates select="." mode="reportingOrganizationText" />
    <xsl:apply-templates select="." mode="commentText" />
  </xsl:template>

  <!-- If calling template has match containing person name information, name will print out -->
  <xsl:template name="person_type">
    <xsl:if test="j2:PersonPrefixName">
      <xsl:for-each select="j2:PersonPrefixName">
        <xsl:value-of select="." />
        <xsl:if test="position() != last()">
          <xsl:text>;</xsl:text>
        </xsl:if>
      </xsl:for-each>
      <xsl:text>&#32;</xsl:text>
    </xsl:if>
    <xsl:if test="j2:PersonGivenName">
      <xsl:value-of select="j2:PersonGivenName" />
      <xsl:text>&#32;</xsl:text>
    </xsl:if>
    <xsl:if test="j2:PersonMiddleName">
      <xsl:for-each select="j2:PersonMiddleName">
        <xsl:value-of select="." />
        <xsl:if test="position() != last()">
          <xsl:text>;</xsl:text>
        </xsl:if>
      </xsl:for-each>
      <xsl:text>&#32;</xsl:text>
    </xsl:if>
    <xsl:if test="j2:PersonSurName">
      <xsl:value-of select="j2:PersonSurName" />
      <xsl:text>&#32;</xsl:text>
    </xsl:if>
    <xsl:if test="j2:PersonSuffixName">
      <xsl:for-each select="j2:PersonSuffixName">
        <xsl:value-of select="." />
        <xsl:if test="position() != last()">
          <xsl:text>;</xsl:text>
        </xsl:if>
      </xsl:for-each>
      <xsl:text>&#32;</xsl:text>
    </xsl:if>
    <xsl:if test="j2:PersonFullName">
      <xsl:value-of select="j2:PersonFullName" />
      <xsl:text>&#32;</xsl:text>
    </xsl:if>
  </xsl:template>

  <!-- Elements of type "LocationType" can have their info printed here-->
  <xsl:template
    match="j2:EmploymentLocation | j2:Residence | j2:PersonBirthLocation | j2:OrganizationLocation">
    <xsl:if test="j2:LocationName">
      <xsl:apply-templates select="j2:LocationName" mode="TitleCase" />
      <xsl:text>&#160;</xsl:text>
    </xsl:if>
    <xsl:if test="j2:LocationAddress/j2:AddressFullText">
      <xsl:apply-templates
        select="j2:LocationAddress/j2:AddressFullText" mode="TitleCase" />
      <xsl:text>,&#160;</xsl:text>
    </xsl:if>
	<xsl:if test="j2:LocationAddress/j2:LocationStreet/j2:StreetFullText">
		<xsl:apply-templates select="j2:LocationAddress/j2:LocationStreet/j2:StreetFullText" mode="TitleCase"/>
		<xsl:text>,&#160;</xsl:text>
	</xsl:if>
    <xsl:if test="j2:LocationAddress/j2:LocationSecondaryUnitText">
      <xsl:apply-templates
        select="j2:LocationAddress/j2:LocationSecondaryUnitText"
        mode="TitleCase" />
      <xsl:text>,&#160;</xsl:text>
    </xsl:if>
    <xsl:if test="j2:LocationAddress/j2:AddressMailDeliveryUnitText">
      <xsl:apply-templates
        select="j2:LocationAddress/j2:AddressMailDeliveryUnitText"
        mode="TitleCase" />
      <xsl:text>,&#160;</xsl:text>
    </xsl:if>
    <xsl:if test="j2:LocationAddress/j2:LocationCityName">
      <xsl:apply-templates
        select="j2:LocationAddress/j2:LocationCityName"
        mode="TitleCase" />
      <xsl:text>,&#160;</xsl:text>
    </xsl:if>
    <xsl:if test="j2:LocationAddress/j2:LocationCountyName">
      <xsl:apply-templates
        select="j2:LocationAddress/j2:LocationCountyName"
        mode="TitleCase" />
      <xsl:text>,&#160;</xsl:text>
    </xsl:if>
    <xsl:if test="j2:LocationAddress/j2:LocationStateName">
      <xsl:value-of select="j2:LocationAddress/j2:LocationStateName" />
      <xsl:text>&#160;</xsl:text>
    </xsl:if>
    <xsl:if test="j2:LocationAddress/j2:LocationPostalCodeID">
      <xsl:value-of select="j2:LocationAddress/j2:LocationPostalCodeID" />
      <xsl:text>&#160;</xsl:text>
    </xsl:if>
    <xsl:if test="j2:LocationAddress/j2:LocationCountyName">
      <xsl:value-of select="j2:LocationAddress/j2:LocationCountryName" />
    </xsl:if>
    <xsl:if test="j2:LocationContactInformation">
      <xsl:text>Contact information:&#160;</xsl:text>
    </xsl:if>
    <xsl:if
      test="j2:LocationContactInformation/j2:ContactInformationDescriptionText">
      <xsl:value-of
        select="j2:LocationContactInformation/j2:ContactInformationDescriptionText" />
      <xsl:text>&#160;</xsl:text>
    </xsl:if>
    <xsl:for-each
      select="j2:LocationContactInformation/j2:ContactTelephoneNumber">
      <xsl:value-of select="." />
      <xsl:call-template name="if_not_last_than_separator" />
    </xsl:for-each>
    <xsl:for-each
      select="j2:LocationContactInformation/j2:ContactFacsimileNumber">
      <xsl:if test="position() = 1">
        <xsl:text>Fax:</xsl:text>
      </xsl:if>
      <xsl:value-of select="." />
      <xsl:call-template name="if_not_last_than_separator" />
    </xsl:for-each>
    <xsl:for-each
      select="j2:LocationContactInformation/j2:ContactEmailID">
      <a href="mailto:{.}">
        <xsl:value-of select="." />
      </a>
      <xsl:call-template name="if_not_last_than_separator" />
    </xsl:for-each>
  </xsl:template>

  <!-- name of subject -->
  <xsl:template match="j2:PersonName" mode="subject_name">
    <!-- div class="subject_name" -->
    <xsl:if test="position()=1">
      <tr>
        <td class="subject_name">
          <xsl:call-template name="person_type" />
        </td>
        <td align="center">
          <a href="#alias{$responseId}">
            <xsl:element name="img">
              <xsl:attribute name="border">0</xsl:attribute>
              <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'aliasfraudlink.jpg')"/></xsl:attribute>
              <xsl:attribute name="alt">aliases</xsl:attribute>
            </xsl:element>
          </a>
        </td>
        <br />
      </tr>
    </xsl:if>
    <!-- /div -->
  </xsl:template>

  <!-- gender and race of subject -->
  <xsl:template match="j2:PersonPhysicalDetails" mode="gender_race">
    <xsl:for-each select="j2:PersonSexText">
      <xsl:value-of select="." />
      <xsl:call-template name="if_not_last_than_separator" />
      <xsl:call-template name="if_last_than_separator" />
      <xsl:text>/</xsl:text>
      <xsl:call-template name="if_last_than_separator" />
    </xsl:for-each>
    <xsl:for-each select="j2:PersonRaceText">
      <xsl:value-of select="." />
      <xsl:call-template name="if_not_last_than_separator" />
    </xsl:for-each>
    <br />
  </xsl:template>

  <!-- birth location of subject -->
  <xsl:template match="j2:PersonBirthLocation" mode="birth_location">
    <xsl:if test="position() = 1">
      <xsl:text>Born in&#160;</xsl:text>
    </xsl:if>
    <xsl:apply-templates select="." />
    <xsl:if test="position() = 1">
      <xsl:text>;</xsl:text>
    </xsl:if>
    <xsl:call-template name="if_not_last_than_separator" />
    <xsl:call-template name="if_last_than_separator" />
  </xsl:template>

  <!-- social detials of subject -->
  <xsl:template match="j2:PersonSocialDetails">
    <xsl:for-each select="j2:PersonCitizenshipText">
      <xsl:if test="position() = 1">
        <xsl:text>Citizen of&#160;</xsl:text>
      </xsl:if>
      <xsl:value-of select="." />
      <xsl:text>&#160;</xsl:text>
      <xsl:apply-templates select="." mode="reportedDate" />
      <xsl:call-template name="if_not_last_than_separator" />
      <xsl:call-template name="if_last_than_separator" />
    </xsl:for-each>
    <xsl:for-each select="j2:PersonEthnicityText">
      <xsl:value-of select="." />
      <xsl:text>&#160;</xsl:text>
      <xsl:call-template name="if_not_last_than_separator" />
      <xsl:call-template name="if_last_than_separator" />
    </xsl:for-each>
    <xsl:for-each select="j2:PersonMaritalStatusText">
      <xsl:value-of select="." />
      <xsl:text>&#160;</xsl:text>
      <xsl:apply-templates select="." mode="reportedDate" />
      <xsl:call-template name="if_not_last_than_separator" />
      <xsl:call-template name="if_last_than_separator" />
    </xsl:for-each>
    <xsl:for-each select="j2:PersonReligionText">
      <xsl:value-of select="." />
      <xsl:text>&#160;</xsl:text>
      <xsl:apply-templates select="." mode="reportedDate" />
      <xsl:call-template name="if_not_last_than_separator" />
      <xsl:call-template name="if_last_than_break" />
    </xsl:for-each>
    <br />
  </xsl:template>

  <!-- birthdate of subject -->
  <xsl:template match="j2:PersonBirthDate">
    <xsl:apply-templates select="." mode="FormatFullDateAsMMDDYYYY" />
    <xsl:call-template name="if_not_last_than_separator" />
    <xsl:call-template name="if_last_than_break" />
  </xsl:template>

  <!-- height, weight, eye color , hair color, and skin tone of subject -->
  <xsl:template match="j2:PersonPhysicalDetails"
    mode="height_to_skin">
    <xsl:for-each select="j2:PersonHeightMeasure">
      <xsl:value-of select="substring(.,1,1)" />
      <xsl:text>'</xsl:text>
      <xsl:value-of select="substring(.,2,2)" />
      <xsl:text>"&#32;</xsl:text>
      <xsl:apply-templates select="." mode="reportedDate" />
      <xsl:call-template name="if_not_last_than_separator" />
      <xsl:call-template name="if_last_than_separator" />
    </xsl:for-each>
    <xsl:for-each select="j2:PersonWeightMeasure">
      <xsl:value-of select="." />
      <xsl:text>lbs&#32;</xsl:text>
      <xsl:apply-templates select="." mode="reportedDate" />
      <xsl:call-template name="if_not_last_than_separator" />
      <xsl:call-template name="if_last_than_separator" />
    </xsl:for-each>
    <xsl:for-each select="j2:PersonEyeColorText">
      <!-- xsl:if test="position() = 1">
        <xsl:text>Eye Color:&#32;</xsl:text>
        </xsl:if -->
      <xsl:value-of select="." />
      <xsl:text>&#32;</xsl:text>
      <xsl:if test="position() = 1">
        <xsl:text>Eyes&#32;</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="." mode="reportedDate" />
      <xsl:text>;</xsl:text>
      <xsl:call-template name="if_not_last_than_separator" />
      <xsl:call-template name="if_last_than_separator" />
    </xsl:for-each>
    <xsl:for-each select="j2:PersonHairColorText">
      <!-- xsl:if test="position() = 1">
        <xsl:text>Hair Color:&#32;</xsl:text>
        </xsl:if -->
      <xsl:value-of select="." />
      <xsl:text>&#32;</xsl:text>
      <xsl:if test="position() = 1">
        <xsl:text>Hair&#32;</xsl:text>
      </xsl:if>
      <xsl:apply-templates select="." mode="reportedDate" />
      <xsl:call-template name="if_not_last_than_separator" />
      <xsl:call-template name="if_last_than_separator" />
    </xsl:for-each>
    <xsl:for-each select="j2:PersonSkinToneText">
      <xsl:if test="position() = 1">
        <xsl:text>Skin Tone:&#32;</xsl:text>
      </xsl:if>
      <xsl:value-of select="." />
      <xsl:text>&#32;</xsl:text>
      <xsl:call-template name="if_not_last_than_separator" />
      <xsl:call-template name="if_last_than_separator" />
    </xsl:for-each>
  </xsl:template>

  <!-- blood type of subject -->
  <xsl:template match="j2:PersonBiometricDetails" mode="blood_type">
    <xsl:for-each select="j2:PersonBloodTypeText">
      <xsl:value-of select="." />
      <xsl:text>&#32;</xsl:text>
      <xsl:call-template name="if_not_last_than_separator" />
      <xsl:call-template name="if_last_than_break" />
    </xsl:for-each>
  </xsl:template>

  <!-- residence of subject -->
  <xsl:template match="j2:Residence" mode="subject_residence">
    <br />
    <xsl:apply-templates select="." />
    <xsl:apply-templates select="." mode="reportedDate" />
    <!-- xsl:call-template name="if_not_last_than_separator"/ -->
  </xsl:template>

  <!-- links under state ID and FBI number -->
  <xsl:template name="SMT_Photo_Links">
    <table width="100%">
      <tr>
        <td class="width50percent centered no_decoration">
          <a href="#smt{$responseId}">
            <xsl:element name="img">
              <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'scarsMarksTattoos.jpg')"/></xsl:attribute>
              <xsl:attribute name="border">0</xsl:attribute>
              <xsl:attribute name="alt">SMT</xsl:attribute>
            </xsl:element>
          </a>
        </td>
        <td class="width50percent centered no_decoration">
          <a href="#photo{$responseId}">
            <xsl:element name="img">
              <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'photoInformation.jpg')"/></xsl:attribute>
              <xsl:attribute name="border">0</xsl:attribute>
              <xsl:attribute name="alt">photo</xsl:attribute>
            </xsl:element>
          </a>
        </td>
      </tr>
    </table>
  </xsl:template>

  <!-- SSN, Misc #, Driver License, fingerprint, palm print, AFIS, DNA, Employer, Occupation, Employment, Offender Notice -->
  <xsl:template match="j2:Subject" mode="ssn_to_notice">
    <table>
      <tr>
      	<xsl:call-template name="ConditionalLabelWithValue">
			<xsl:with-param name="label" select="'FBI:'"/>
			<xsl:with-param name="value">
				<xsl:value-of select="j2:PersonAssignedIDDetails/j2:PersonFBIID"/>
			</xsl:with-param>
			<xsl:with-param name="label_class_name" select="'black_header width20percent'"/>
			<xsl:with-param name="value_class_name" select="'detailvalue width25percent'"/>
		</xsl:call-template>
		<td class="width5percent"></td>
        <xsl:call-template name="ConditionalLabelWithValue">
          <xsl:with-param name="label" select="'SOCIAL SECURITY #:'" />
          <xsl:with-param name="value">
            <xsl:for-each
              select="j2:PersonAssignedIDDetails/j2:PersonSSNID">
              <xsl:value-of select="substring(j2:ID,1,3)" />
              <xsl:text>-</xsl:text>
              <xsl:value-of select="substring(j2:ID,4,2)" />
              <xsl:text>-</xsl:text>
              <xsl:value-of select="substring(j2:ID,6,4)" />
              <xsl:call-template name="if_not_last_than_separator" />
              <xsl:text>&#32;</xsl:text>
            </xsl:for-each>
          </xsl:with-param>
          <xsl:with-param name="label_class_name"
            select="'black_header width20percent'" />
          <xsl:with-param name="value_class_name"
            select="'detailvalue width25percent'" />
        </xsl:call-template>
      </tr>
 	  <tr>
        <xsl:call-template name="ConditionalLabelWithValue">
			<xsl:with-param name="label" select="'SID:'"/>
			<xsl:with-param name="value">
				<xsl:for-each select="j2:PersonAssignedIDDetails/j2:PersonStateID">
				  <xsl:value-of select="j2:IDIssuingAuthorityText" />
              	  <xsl:text>-</xsl:text>
                  <xsl:value-of select="j2:ID" />
                  <xsl:call-template name="if_not_last_than_separator" />
                  <xsl:text>&#32;</xsl:text>
				</xsl:for-each>
			</xsl:with-param>
			<xsl:with-param name="label_class_name" select="'black_header width20percent'"/>
			<xsl:with-param name="value_class_name" select="'detailvalue width25percent'"/>
		</xsl:call-template>
        <td class="width5percent"></td>
        <xsl:call-template name="ConditionalLabelWithValue">
          <xsl:with-param name="label" select="'MISCELLANEOUS #:'" />
          <xsl:with-param name="value">
            <xsl:for-each
              select="j2:PersonAssignedIDDetails/j2:PersonOtherID">
              <xsl:value-of select="j2:IDTypeText" />
              <xsl:text>-</xsl:text>
              <xsl:value-of select="j2:IDIssuingAuthorityText" />
              <xsl:text>-</xsl:text>
              <xsl:value-of select="j2:ID" />
              <xsl:call-template name="if_not_last_than_separator" />
              <xsl:text>&#32;</xsl:text>
            </xsl:for-each>
          </xsl:with-param>
          <xsl:with-param name="label_class_name"
            select="'black_header width20percent'" />
          <xsl:with-param name="value_class_name"
            select="'detailvalue width30percent'" />
        </xsl:call-template>
      </tr>
    </table>

    <table>
      <tr>
        <xsl:call-template name="ConditionalLabelWithValue">
          <xsl:with-param name="label" select="'DRIVERS LICENSE #:'" />
          <xsl:with-param name="value">
            <xsl:for-each
              select="j2:PersonAssignedIDDetails/j2:PersonDriverLicenseID">
              <!-- xsl:value-of select="j2:IDIssuingAuthorityText"/>
                <xsl:text>-</xsl:text -->
              <xsl:value-of select="j2:ID" />
              <xsl:call-template name="if_not_last_than_separator" />
              <xsl:text>&#32;</xsl:text>
            </xsl:for-each>
          </xsl:with-param>
          <xsl:with-param name="label_class_name"
            select="'black_header width25percent'" />
          <xsl:with-param name="value_class_name"
            select="'detailvalue width75percent'" />
        </xsl:call-template>
        <td></td>
      </tr>
      <tr>
        <xsl:call-template name="ConditionalLabelWithValue">
          <xsl:with-param name="label" select="'FINGERPRINT CLASS:'" />
          <xsl:with-param name="value">
            <!-- xsl:value-of select="j2:PersonBiometricDetails/j2:PersonFingerprintSet/j2:BiometricEncodingMethodText"/ -->
            <!-- xsl:if test="j2:PersonBiometricDetails/j2:PersonFingerprintSet/j2:BiometricEncodingMethodText">
              <xsl:text>-</xsl:text>
              </xsl:if -->
            <!-- xsl:value-of select="j2:PersonBiometricDetails/j2:PersonFingerprintSet/j2:BiometricValueText"/ -->
            <xsl:apply-templates
              select="j2:PersonBiometricDetails/j2:PersonFingerprintSet/j2:BiometricValueText"
              mode="attributes" />
          </xsl:with-param>
          <xsl:with-param name="label_class_name"
            select="'black_header width25percent'" />
          <xsl:with-param name="value_class_name"
            select="'detailvalue width75percent'" />
        </xsl:call-template>
        <td></td>
      </tr>
      <xsl:for-each
        select="j2:PersonBiometricDetails/j2:PersonPalmPrint">
        <tr>
          <td valign="top" class="black_header width25percent">
            PALM PRINT, ORI and LITERAL:
          </td>
          <td class="detailvalue" valign="top">
            <xsl:value-of
              select="j2:BiometricImage/j2:BinaryCaptureOrganization/j2:OrganizationORIID/j2:ID" />
            <xsl:text>-</xsl:text>
            <xsl:value-of
              select="j2:BiometricImage/j2:BinaryCaptureOrganization/j2:OrganizationName" />
          </td>
          <td valign="top">
            <!-- img src="images/palm" alt=""/ -->
          </td>
        </tr>
      </xsl:for-each>
      <xsl:for-each
        select="j2:PersonBiometricDetails/j2:PersonFingerprintSet/j2:Fingerprint/j2:FingerprintFingerText">
        <tr>
          <xsl:call-template name="ConditionalLabelWithValue">
            <xsl:with-param name="label"
              select="'AFIS CLASSIFICATION:'" />
            <xsl:with-param name="value" select="." />
            <xsl:with-param name="label_class_name"
              select="'black_header width25percent'" />
            <xsl:with-param name="value_class_name"
              select="'detailvalue width75percent'" />
          </xsl:call-template>
          <td></td>
        </tr>
      </xsl:for-each>
      <xsl:for-each select="j2:PersonBiometricDetails/j2:PersonDNA">
        <tr>
          <xsl:call-template name="ConditionalLabelWithValue">
            <xsl:with-param name="label" select="'DNA:'" />
            <xsl:with-param name="value">
              <xsl:text>Method:&#32;</xsl:text>
              <xsl:value-of select="j2:BiometricEncodingMethodText" />
              <xsl:text>,&#32;</xsl:text>
              <xsl:for-each select="j2:BiometricDescriptionText">
                <xsl:if test="position()=1">
                  <xsl:text>Description:&#32;</xsl:text>
                </xsl:if>
                <xsl:value-of select="." />
                <xsl:call-template name="if_not_last_than_separator" />
                <xsl:if test="position() = last()">
                  <xsl:text>,</xsl:text>
                </xsl:if>
                <xsl:text>&#32;</xsl:text>
              </xsl:for-each>
              <xsl:if
                test="j2:BiometricCaptureOrganization/j2:OrganizationORIID/j2:ID">
                <!-- xsl:text>Agency:&#32;</xsl:text -->
                <xsl:value-of
                  select="j2:BiometricCaptureOrganization/j2:OrganizationORIID/j2:ID" />
                <xsl:text>,&#32;</xsl:text>
              </xsl:if>
              <!-- xsl:text>Name:&#32;</xsl:text -->
              <xsl:value-of
                select="j2:BiometricCaptureOrganization/j2:OrganizationName" />
              <xsl:text>,&#32;</xsl:text>
              <xsl:for-each select="j2:DNALocus">
                <xsl:if test="position() = 1">
                  <xsl:text>Locus(Type/Value(s)):&#32;</xsl:text>
                </xsl:if>
                <xsl:value-of select="j2:DNALocusTypeText" />
                <xsl:text>/</xsl:text>
                <xsl:for-each select="j2:DNALocusValue">
                  <xsl:value-of select="." />
                  <xsl:if test="position() != last()">
                    <xsl:text>,</xsl:text>
                  </xsl:if>
                </xsl:for-each>
                <xsl:text>&#32;</xsl:text>
              </xsl:for-each>
            </xsl:with-param>
            <xsl:with-param name="label_class_name"
              select="'black_header width25percent'" />
            <xsl:with-param name="value_class_name"
              select="'detailvalue width75percent'" />
          </xsl:call-template>
          <td></td>
        </tr>
      </xsl:for-each>

      <!--Employment info -->
      <xsl:for-each select="j2:Employment">
        <tr>
          <xsl:call-template name="ConditionalLabelWithValue">
            <xsl:with-param name="label" select="'EMPLOYER:'" />
            <xsl:with-param name="value">
              <!-- xsl:value-of select="j2:EmploymentEmployerName"/ -->
              <xsl:apply-templates select="j2:EmploymentEmployerName"
                mode="TitleCase" />
            </xsl:with-param>
            <xsl:with-param name="label_class_name"
              select="'black_header width25percent'" />
            <xsl:with-param name="value_class_name"
              select="'detailvalue width75percent'" />
          </xsl:call-template>
          <td></td>
        </tr>
        <tr>
          <xsl:call-template name="ConditionalLabelWithValue">
            <xsl:with-param name="label" select="'OCCUPATION:'" />
            <xsl:with-param name="value">
              <!-- xsl:value-of select="j2:EmploymentOccupationText"/ -->
              <xsl:apply-templates select="j2:EmploymentOccupationText"
                mode="TitleCase" />
            </xsl:with-param>
            <xsl:with-param name="label_class_name"
              select="'black_header width25percent'" />
            <xsl:with-param name="value_class_name"
              select="'detailvalue width75percent'" />
          </xsl:call-template>
          <td></td>
        </tr>
        <tr>
          <xsl:call-template name="ConditionalLabelWithValue">
            <!-- xsl:with-param name="label" select="'EMPLOYMENT ADDRESS:'"/ -->
            <xsl:with-param name="value">
              <xsl:apply-templates select="j2:EmploymentLocation" />
            </xsl:with-param>
            <xsl:with-param name="label_class_name"
              select="'black_header width25percent'" />
            <xsl:with-param name="value_class_name"
              select="'detailvalue width75percent'" />
          </xsl:call-template>
          <td></td>
        </tr>
      </xsl:for-each>
      <tr>
        <xsl:call-template name="ConditionalLabelWithValue">
          <xsl:with-param name="label" select="'OFFENDER NOTICE:'" />
          <xsl:with-param name="value">
          	<xsl:for-each select="j2:SubjectOffenderNoticeCaveat">
	          	<xsl:value-of select="." />
	          	<xsl:choose>
		          	<xsl:when test="@j2:reportedDate or @j2:reportingOrganizationText">
			            <xsl:apply-templates select="." mode="reportedDate" />
			            <xsl:apply-templates select="." mode="reportingOrganizationText" />
			            <xsl:call-template name="if_not_last_than_separator" />
		            </xsl:when>
		            <xsl:otherwise>
		            	<xsl:call-template name="if_not_last_than_separator" />
		            </xsl:otherwise>
	            </xsl:choose>
	            <xsl:call-template name="if_last_than_break"/>
          	</xsl:for-each>
          </xsl:with-param>
          <xsl:with-param name="label_class_name"
            select="'black_header width25percent'" />
          <xsl:with-param name="value_class_name"
            select="'detailvalue width75percent'" />
        </xsl:call-template>
        <td></td>
      </tr>
    </table>
  </xsl:template>

  <!-- SMT of subject -->
  <xsl:template match="j2:PersonPhysicalFeature"
    mode="subject_physical">
    <a name="smt{$responseId}"></a>
    <table width="100%">
      <tr>
        <td class="width75percent detailvalue">
          <xsl:if test="position() = 1">
            <span class="black_header">
              <xsl:text>SCARS MARKS TATTOOS DATA&#32;</xsl:text>
            </span>
            <br />
          </xsl:if>

          <xsl:if test="j2:PhysicalFeatureCategoryText">
            <xsl:text>Category:&#32;</xsl:text>
            <xsl:value-of select="j2:PhysicalFeatureCategoryText" />
            <xsl:text>&#32;</xsl:text>
          </xsl:if>
          <xsl:choose>
            <xsl:when test="j2:PhysicalFeatureDescriptionText">
              <xsl:apply-templates
                select="j2:PhysicalFeatureDescriptionText"
                mode="TitleCase" />
              <xsl:text>&#32;</xsl:text>
            </xsl:when>
            <xsl:otherwise>
             <xsl:if test="j2:PhysicalFeatureTypeCode">
               <xsl:value-of select="j2:PhysicalFeatureTypeCode" />
                <xsl:text>&#32;</xsl:text>
             </xsl:if>
            </xsl:otherwise>
          </xsl:choose>
          <br />
          <xsl:if
            test="j2:PhysicalFeatureImage/j2:BinaryCaptureOrganization/j2:OrganizationORIID">
            <xsl:value-of
              select="j2:PhysicalFeatureImage/j2:BinaryCaptureOrganization/j2:OrganizationORIID/j2:ID" />
            <xsl:text>&#32;</xsl:text>
          </xsl:if>
          <!-- xsl:value-of select="j2:PhysicalFeatureImage/j2:BinaryCaptureOrganization/j2:OrganizationName"/ -->
          <xsl:apply-templates
            select="j2:PhysicalFeatureImage/j2:BinaryCaptureOrganization/j2:OrganizationName"
            mode="TitleCase" />
        </td>
        <td class="width25percent">
          <!-- img src="images/smtimage" alt=""/ -->
        </td>
      </tr>
    </table>
    <xsl:call-template name="if_last_than_break" />
    <xsl:call-template name="if_last_than_break" />
  </xsl:template>

  <!-- alias names of subject -->
  <xsl:template match="j2:Subject" mode="alias_name">
    <a name="alias{$responseId}"></a>
    <xsl:if test="j2:PersonName or j2:PersonAlternateName">
      <span class="black_header">
        <xsl:text>ALIAS NAMES:</xsl:text>
      </span>
      <br />
    </xsl:if>
    <span class="detailvalue">
      <xsl:for-each select="j2:PersonName">
        <xsl:if test="position() != 1">
          <xsl:call-template name="person_type" />
          <xsl:choose>
            <xsl:when test="position() != last()">
              <xsl:call-template name="same_field_separator" />
            </xsl:when>
            <xsl:otherwise>
              <xsl:if test="../j2:PersonAlternateName">
                <xsl:call-template name="same_field_separator" />
              </xsl:if>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:if>
      </xsl:for-each>
      <xsl:for-each select="j2:PersonAlternateName">
        <xsl:call-template name="person_type" />
        <xsl:call-template name="if_not_last_than_separator" />
      </xsl:for-each>
    </span>
    <br />
    <br />
  </xsl:template>

  <!-- photo information -->
  <xsl:template match="j2:PersonDigitalImage">
    <a name="photo{$responseId}"></a>
    <xsl:if test="position()=1">
      <span class="black_header">
        <xsl:text>PHOTO INFORMATION:</xsl:text>
      </span>
      <br />
    </xsl:if>
    <table width="100%">
      <tr>
        <td class="detailvalue width15percent">
          <xsl:apply-templates select="j2:BinaryCaptureDate"
            mode="FormatFullDateAsMMDDYYYY" />
        </td>
        <td class="detailvalue width15percent">
          <xsl:value-of
            select="j2:BinaryCaptureOrganization/j2:OrganizationORIID/j2:ID" />
        </td>
        <td class="detailvalue width50percent">
          <xsl:apply-templates
            select="j2:BinaryCaptureOrganization/j2:OrganizationName"
            mode="TitleCase" />
        </td>
        <td class="width20percent">
          <!-- img src="images/mugshot" alt=""/> -->
        </td>
      </tr>
    </table>
  </xsl:template>

  <!-- Controlling template for cycle info -->
  <xsl:template match="rap:Cycle">
    <span class="cycle">
      Cycle
      <xsl:text>&#32;</xsl:text>
      <xsl:number value="position()" />
    </span>
    <p />
    <span class="history_black_header">
      EARLIEST EVENT DATE:&#160;&#160;
    </span>
    <span class="history_data">
      <xsl:apply-templates select="rap:CycleEarliestDate"
        mode="FormatLongDate" />
    </span>
    <br />
    <xsl:if test="rap:CycleTrackingID/j2:ID">
      <span class="history_black_header">
        ARREST TRACKING NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="rap:CycleTrackingID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:Incident/j2:ActivityDate">
      <span class="history_black_header">
        DATE OF OFFENSE:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:Incident/j2:ActivityDate"
          mode="FormatLongDate" />
      </span>
      <br />
    </xsl:if>
    <xsl:apply-templates select="j2:Arrest" />
    <xsl:apply-templates select="j2:Booking" />
    <xsl:apply-templates select="j2:Arrest/j2:ArrestCharge" />
    <xsl:apply-templates select="rap:Prosecution" />
    <xsl:apply-templates select="rap:Prosecution/j2:ProsecutionCharge" />
    <xsl:apply-templates select="rap:CourtAction" />
    <xsl:apply-templates select="rap:CourtAction/j2:CourtCharge" />
    <xsl:apply-templates select="rap:Sentencing" />
    <xsl:apply-templates select="rap:Supervision" />
  </xsl:template>

  <xsl:template match="j2:Arrest">
    <br />
    <span class="major_history_header">ARREST DATA</span>
    <br />
    <xsl:if test="j2:ArrestSubject/j2:PersonName">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        SUBJECT NAME:&#160;&#160;
      </span>
      <span class="arrest_name">
        <xsl:apply-templates select="j2:ArrestSubject/j2:PersonName"
          mode="Arrest_Prosecution_Court_Supervision" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ActivityTypeText">
      <xsl:call-template name="indent" />
      <span class="history_black_header">TYPE:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ActivityTypeText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ActivityDate">
      <xsl:call-template name="indent" />
      <span class="history_black_header">DATE:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ActivityDate"
          mode="FormatLongDate" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ArrestAgencyRecordID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ArrestAgencyRecordID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ArrestAgency/j2:OrganizationName">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        ARREST AGENCY:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:ArrestAgency/j2:OrganizationORIID/j2:ID"
          mode="history_unbounded" />
        <xsl:text>&#160;&#160;</xsl:text>
        <xsl:apply-templates
          select="j2:ArrestAgency/j2:OrganizationName"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ArrestSubject/j2:SubjectID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        LOCAL IDENTIFICATION NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:ArrestSubject/j2:SubjectID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ActivityCommentText">
      <xsl:call-template name="indent" />
      <span class="history_black_header">COMMENTS:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ActivityCommentText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
  </xsl:template>

  <xsl:template match="j2:Booking">
    <span class="minor_history_header">BOOKING</span>
    <br />
    <xsl:if test="j2:BookingAgencyRecordID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:BookingAgencyRecordID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:BookingAgency/j2:OrganizationName">
      <xsl:call-template name="indent" />
      <span class="history_black_header">AGENCY:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:BookingAgency/j2:OrganizationORIID/j2:ID"
          mode="history_unbounded" />
        <span class="history_black_header">&#160;&#160;</span>
        <xsl:apply-templates
          select="j2:BookingAgency/j2:OrganizationName"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
  </xsl:template>

  <xsl:template match="j2:ArrestCharge">
    <span class="minor_history_header">CHARGE</span>
    <br />
    <xsl:if test="j2:ChargeSequenceID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        SEQUENCE NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeSequenceID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeTrackingID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        TRACKING NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeTrackingID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:apply-templates select="j2:ChargeStatute" />
    <xsl:apply-templates select="." mode="literal_to_comments" />
  </xsl:template>

  <xsl:template match="rap:Prosecution">
    <br />
    <span class="major_history_header">PROSECUTION</span>
    <br />
    <xsl:if test="rap:ProsecutionSubject/j2:PersonName">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        SUBJECT NAME:&#160;&#160;
      </span>
      <span class="other_criminal_name">
        <xsl:apply-templates
          select="rap:ProsecutionSubject/j2:PersonName"
          mode="Arrest_Prosecution_Court_Supervision" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ActivityDate">
      <xsl:call-template name="indent" />
      <span class="history_black_header">DATE:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ActivityDate"
          mode="FormatLongDate" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="rap:ProsecutionAgencyRecordID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates
          select="rap:ProsecutionAgencyRecordID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="rap:ProsecutionAgency">
      <xsl:call-template name="indent" />
      <span class="history_black_header">PROSECUTOR:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates
          select="rap:ProsecutionAgency/j2:OrganizationORIID/j2:ID"
          mode="history_unbounded" />
        <xsl:text>&#160;&#160;</xsl:text>
        <xsl:apply-templates
          select="rap:ProsecutionAgency/j2:OrganizationName"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="rap:ProsecutionSubject/j2:SubjectID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        LOCAL IDENTIFICATION NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates
          select="rap:ProsecutionSubject/j2:SubjectID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ActivityCommentText">
      <xsl:call-template name="indent" />
      <span class="history_black_header">COMMENTS:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ActivityCommentText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
  </xsl:template>

  <xsl:template match="j2:ProsecutionCharge">
    <span class="minor_history_header">CHARGE</span>
    <br />
    <xsl:if test="j2:ChargeSequenceID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        SEQUENCE NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeSequenceID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeTrackingID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        TRACKING NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeTrackingID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:apply-templates select="j2:ChargeStatute" />
    <xsl:apply-templates select="." mode="literal_to_comments" />
  </xsl:template>

  <xsl:template match="rap:CourtAction">
    <br />
    <span class="major_history_header">COURT</span>
    <br />
    <xsl:if test="rap:CourtSubject/j2:PersonName">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        SUBJECT NAME:&#160;&#160;
      </span>
      <span class="other_criminal_name">
        <xsl:apply-templates select="rap:CourtSubject/j2:PersonName"
          mode="Arrest_Prosecution_Court_Supervision" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ActivityDate">
      <xsl:call-template name="indent" />
      <span class="history_black_header">DATE:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ActivityDate"
          mode="FormatLongDate" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="rap:CourtRecordID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="rap:CourtRecordID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:Court">
      <xsl:call-template name="indent" />
      <span class="history_black_header">COURT:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:Court/j2:OrganizationORIID/j2:ID"
          mode="history_unbounded" />
        <xsl:text>&#160;&#160;</xsl:text>
        <xsl:apply-templates select="j2:Court/j2:OrganizationName"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ActivityCommentText">
      <xsl:call-template name="indent" />
      <span class="history_black_header">COMMENTS:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ActivityCommentText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
  </xsl:template>

  <xsl:template match="j2:CourtCharge">
    <span class="minor_history_header">CHARGE</span>
    <br />
    <xsl:if test="j2:ChargeSequenceID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        SEQUENCE NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeSequenceID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeTrackingID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        TRACKING NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeTrackingID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:apply-templates select="j2:ChargeStatute" />
    <xsl:apply-templates select="." mode="literal_to_comments" />
  </xsl:template>

  <xsl:template match="rap:Sentencing">
    <span class="minor_history_header">SENTENCING</span>
    <br />
    <xsl:if test="j2:ActivityDate">
      <xsl:call-template name="indent" />
      <span class="history_black_header">DATE:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ActivityDate"
          mode="FormatLongDate" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="rap:CourtRecordID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="rap:CourtRecordID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:Court">
      <xsl:call-template name="indent" />
      <span class="history_black_header">COURT:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:Court/j2:OrganizationORIID/j2:ID"
          mode="history_unbounded" />
        <xsl:text>&#160;&#160;</xsl:text>
        <xsl:apply-templates select="j2:Court/j2:OrganizationName"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:call-template name="indent" />
    <xsl:apply-templates select="j2:Sentence/j2:SentenceCharge" />
    <xsl:if test="j2:Sentence/j2:SentenceDescriptionText">
      <xsl:call-template name="indent" />
      <span class="history_black_header">SENTENCE:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:Sentence/j2:SentenceDescriptionText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ActivityCommentText">
      <xsl:call-template name="indent" />
      <span class="history_black_header">COMMENTS:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ActivityCommentText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
  </xsl:template>

  <xsl:template match="rap:Supervision">
    <br />
    <span class="major_history_header">SUPERVISION</span>
    <br />
    <xsl:if test="j2:SupervisionSubject/j2:PersonName">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        SUBJECT NAME:&#160;&#160;
      </span>
      <span class="other_criminal_name">
        <xsl:apply-templates
          select="j2:SupervisionSubject/j2:PersonName"
          mode="Arrest_Prosecution_Court_Supervision" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ActivityDate">
      <xsl:call-template name="indent" />
      <span class="history_black_header">DATE:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ActivityDate"
          mode="FormatLongDate" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="rap:SupervisionRecordID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        CORRECTIONS OR JAIL CASE NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="rap:SupervisionRecordID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="rap:CourtRecordID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        COURT CASE NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="rap:CourtRecordID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:SupervisionAgency">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        SUPERVISION AGENCY:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:SupervisionAgency/j2:OrganizationORIID/j2:ID"
          mode="history_unbounded" />
        <xsl:text>&#160;&#160;</xsl:text>
        <xsl:apply-templates
          select="j2:SupervisionAgency/j2:OrganizationName"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:SupervisionSubject/j2:SubjectID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        LOCAL IDENTIFICATION NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:SupervisionSubject/j2:SubjectID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ActivityCommentText">
      <xsl:call-template name="indent" />
      <span class="history_black_header">COMMENTS:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ActivityCommentText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:apply-templates select="rap:SupervisionCharge" />
    <br />
    <span class="minor_history_header">SUPERVISION ACTION</span>
    <br />
    <xsl:if test="j2:SupervisionCustodyStatus/j2:StatusText">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        RELEASE DATE:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:SupervisionCustodyStatus/j2:StatusText"
          mode="history_unbounded" />
        <!--  <xsl:value-of select="j2:SupervisionCustodyStatus/j2:StatusText"/> -->
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:SupervisionRelease/j2:ActivityDate">
      <xsl:call-template name="indent" />
      <span class="history_black_header">LITERAL:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:SupervisionRelease/j2:ActivityDate"
          mode="FormatLongDate" />
      </span>
      <br />
    </xsl:if>
  </xsl:template>

  <xsl:template match="rap:SupervisionCharge">
    <span class="minor_history_header">CHARGE</span>
    <br />
    <xsl:if test="j2:ChargeSequenceID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        SEQUENCE NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeSequenceID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeTrackingID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        TRACKING NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeTrackingID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:apply-templates select="j2:ChargeStatute" />
    <xsl:apply-templates select="." mode="literal_to_comments" />
  </xsl:template>

  <xsl:template
    match="j2:ArrestCharge | j2:ProsecutionCharge | j2:CourtCharge | rap:SupervisionCharge"
    mode="literal_to_comments">
    <xsl:if test="j2:ChargeText">
      <xsl:call-template name="indent" />
      <span class="history_black_header">LITERAL:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeReporting/j2:ChargeNCICCode">
      <xsl:call-template name="indent" />
      <span class="history_black_header">NCIC CODE:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:ChargeReporting/j2:ChargeNCICCode"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeCountQuantity">
      <xsl:call-template name="indent" />
      <span class="history_black_header">COUNTS:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeCountQuantity"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:call-template name="indent" />
    <span class="history_black_header">
      CLASSIFICATION:&#160;&#160;
    </span>
    <br />
    <xsl:if test="j2:ChargeClassification/j2:ChargeApplicabilityText">
      <xsl:call-template name="indent" />
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        INCHOATE CHARGE:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:ChargeClassification/j2:ChargeApplicabilityText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if
      test="j2:ChargeClassification/j2:ChargeReducingFactorText">
      <xsl:call-template name="indent" />
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        CHARGE REDUCING FACTOR:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:ChargeClassification/j2:ChargeReducingFactorText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if
      test="j2:ChargeClassification/j2:ChargeSpecialAllegationText">
      <xsl:call-template name="indent" />
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        CHARGE ENHANCING FACTOR:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:ChargeClassification/j2:ChargeSpecialAllegationText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeClassification/j2:ChargeSeverityText">
      <xsl:call-template name="indent" />
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        CHARGE SEVERITY:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:ChargeClassification/j2:ChargeSeverityText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeDescriptionText">
      <xsl:call-template name="indent" />
      <span class="history_black_header">COMMENTS:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeDescriptionText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:apply-templates select="j2:ChargeDisposition" />
  </xsl:template>

  <xsl:template match="j2:SentenceCharge">
    <span class="history_black_header">CONVICTED OFFENSE:</span>
    <br />
    <xsl:if test="j2:ChargeID/j2:ID">
      <xsl:call-template name="indent" />
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        CHARGE NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeText">
      <xsl:call-template name="indent" />
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        CHARGE LITERAL:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeSequenceID/j2:ID">
      <xsl:call-template name="indent" />
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        CHARGE SEQUENCE NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeSequenceID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeTrackingID/j2:ID">
      <xsl:call-template name="indent" />
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        CHARGE TRACKING NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeTrackingID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
  </xsl:template>

  <xsl:template match="j2:ChargeStatute">
    <xsl:if test="j2:StatuteJurisdiction/j2:LocationStateName">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        CHARGE STATE:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:StatuteJurisdiction/j2:LocationStateName"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:StatuteOffenseID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        STATE OFFENSE CODE:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:StatuteOffenseID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:StatuteCodeID/j2:ID">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        STATUTE NUMBER:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:StatuteCodeID/j2:ID"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
  </xsl:template>

  <xsl:template match="j2:ChargeDisposition">
    <xsl:if test="name(..)='j2:ArrestCharge'">
      <span class="minor_history_header">
        ARREST ACTION:&#160;&#160;
      </span>
      <br />
    </xsl:if>
    <xsl:if test="name(..)='j2:ProsecutionCharge'">
      <span class="minor_history_header">
        PROSECUTION ACTION:&#160;&#160;
      </span>
      <br />
    </xsl:if>
    <xsl:if test="name(..)='j2:CourtCharge'">
      <span class="minor_history_header">
        COURT ACTION:&#160;&#160;
      </span>
      <br />
    </xsl:if>
    <xsl:if test="name(..)='rap:SupervisionCharge'">
      <span class="minor_history_header">DISPOSITION&#160;&#160;</span>
      <br />
    </xsl:if>
    <xsl:if test="@j2:commentText">
      <xsl:call-template name="indent" />
      <span class="history_black_header">LITERAL:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates select="@j2:commentText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeDispositionDate">
      <xsl:call-template name="indent" />
      <span class="history_black_header">
        DISPOSITION DATE:&#160;&#160;
      </span>
      <span class="history_data">
        <xsl:apply-templates select="j2:ChargeDispositionDate"
          mode="FormatLongDate" />
      </span>
      <br />
    </xsl:if>
    <xsl:if test="j2:ChargeDispositionDescriptionText">
      <xsl:call-template name="indent" />
      <span class="history_black_header">DISPOSITION:&#160;&#160;</span>
      <span class="history_data">
        <xsl:apply-templates
          select="j2:ChargeDispositionDescriptionText"
          mode="history_unbounded" />
      </span>
      <br />
    </xsl:if>
  </xsl:template>

  <xsl:template match="j2:PersonName"
    mode="Arrest_Prosecution_Court_Supervision">
    <xsl:call-template name="person_type" />
    <xsl:call-template name="if_not_last_than_separator" />
  </xsl:template>

  <xsl:template match="*" mode="history_unbounded">
    <xsl:value-of select="." />
    <xsl:call-template name="if_not_last_than_separator" />
  </xsl:template>

  <xsl:template match="j2:Organization">
    <a name="contributing{$responseId}"></a>
    <xsl:if test="position() = 1">
      <div class="contributing_agencies">
        <xsl:text>Contributing Agencies</xsl:text>
      </div>
      <br />
    </xsl:if>
    <span class="detailvalue">
      <xsl:value-of select="j2:OrganizationORIID/j2:ID" />
      <xsl:text>&#160;&#160;&#160;</xsl:text>
      <!-- xsl:value-of select="j2:OrganizationName"/ -->
      <xsl:apply-templates select="j2:OrganizationName"
        mode="TitleCase" />
      <xsl:text>&#160;</xsl:text>
      <xsl:apply-templates select="j2:OrganizationLocation" />
    </span>
    <br />
  </xsl:template>

	<xsl:template match="j2:PersonDigitalImage" mode="image">
		<xsl:if test="position()=1">
			<xsl:choose>
				<xsl:when test="j2:BinaryObject.Base64">
					<xsl:variable name="responseID" select="/doj:NLETSResponseDocument/@doj-ext:responseID"/>
					<img ignoreNightMode="true" src="image?ETIMEResponseId={$responseID}&amp;ImageIndex=0&amp;Resize=true"/>
					<br/>
					<a href="javascript: void(0)" onclick="window.open('imageDetail.jsp?ETIMEResponseId={$responseID}&amp;DataServiceCode=CCH&amp;WhatToDo=showImages&amp;ShowOneImage=true', '', 'directories=no, location=no, menubar=no, resizable=yes, toolbar=no, scrollbars=yes, status=no');return false;">
						<img src="../../images/detail.jpg"/>
					</a>
					<!-- 
					<xsl:if test="count(//j:PersonDigitalImage) > 1">
						<a href="javascript: void(0)" onclick="window.open('imageDetail.jsp?ETIMEResponseId={$responseID}&amp;WhatToDo=showImages', '', 'directories=no, location=no, menubar=no, resizable=yes, toolbar=no, scrollbars=yes, status=no');return false;">
							<img src="../../images/additionalimages.jpg"/>
						</a>
					</xsl:if>
					-->
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test="j2:BinaryAvailableIndicator='true'">
						<span class="textTealSmall">Image Available</span>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>