<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/cib/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
    <!--  CIB - LICENSE PLATE RECORD -->
    <xsl:import href="cib_common.xsl"/>
	
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:CIBResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - CIB Stolen Plate</xsl:text>
	</xsl:template>
	
	<!-- ################## -->
	<!-- doj:InquiryResult  -->
	<!-- ################## -->
	<xsl:template match="doj:InquiryResult">
		<xsl:param name="fileName" select="."/>
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="cib-ext:LicensePlateIncident" />
		<xsl:apply-templates select="." mode="property_details_all"/>
		<xsl:apply-templates select="cib-ext:MiscellaneousText"  mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="." mode="record_details_all"/>
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>

	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.-->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true'	
					or cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true'">
					<xsl:text>../../images/flag.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="fileLogoPicture">
		<xsl:choose>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:LocatedIndicator = 'true'">
				<xsl:text>../../images/locatedPlate.gif</xsl:text>
				<xsl:text>-</xsl:text>
				<xsl:text>Located Plate</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>../../images/stolenPlate.gif</xsl:text>
				<xsl:text>-</xsl:text>
				<xsl:text>Stolen Plate</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- Details about a stolen plate ...	-->
	<xsl:template match="cib-ext:LicensePlateIncident">
		<table>
			<tr>
				<td class="width10percent">
					<a href="#recorddetails{$responseId}"><img src="../../images/RecordDetails.jpg"/></a>
				</td>
				<td class="width90percent">
					<xsl:apply-templates select="cib-ext:LicensePlate"/>
					<br/>
					<xsl:apply-templates select="cib-ext:LicensePlateCountQuantity"/>
				</td>
			</tr>
		</table>
		<br/>
	</xsl:template>

	<xsl:template match="cib-ext:LicensePlate">
		<span class="propertyinfo">
			<!-- plate# -->
			<xsl:value-of select="j:VehicleRegistrationPlateID"/>
			<xsl:text>&#160;</xsl:text>
			<!-- state name -->
			<xsl:apply-templates select="j:RegistrationJurisdictionName"/>
			<xsl:text>&#160;</xsl:text> 
			<!--  plate year -->
			<xsl:value-of select="cib-ext:RegistrationExpirationYear"/>
			<xsl:text>&#160; </xsl:text>
			<!-- plate type text -->
			<xsl:apply-templates select="j:VehicleRegistrationPlateTypeText"/>
			<xsl:text></xsl:text>
		</span>
	</xsl:template> 
	
	<xsl:template match="cib-ext:LicensePlateCountQuantity">
		<div  class="propertyinfo">
			<xsl:text>Number of Plates: &#160;</xsl:text>
			<xsl:value-of select="." />
		</div>
	</xsl:template> 
	
</xsl:transform>