<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/cib/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
	<xsl:import href="person_common.xsl"/> 
	
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:CIBResponseDocument"> 
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - CIB Missing Person</xsl:text>
	</xsl:template>
	
	<!-- ################################# -->
	<!-- main doj:InquiryResult template   -->
	<!-- ################################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="cib-ext:MissingPersonIncident/j:MissingPerson" mode="subject_details_all"/>
		<xsl:apply-templates select="cib-ext:MissingPersonIncident/j:MissingPerson" mode="FBItoSMT"/>
		<xsl:apply-templates select="cib-ext:MissingPersonIncident/j:MissingPerson" mode="DLtoDNALoc"/>	
		<xsl:apply-templates select="cib-ext:MissingPersonIncident/j:MissingPerson" mode="PersonOtherInfo"/>
		<xsl:apply-templates select="cib-ext:MissingPersonIncident/j:MissingPerson" mode="JewelryInfo"/>
		<xsl:call-template name="vehicle_all">
			<xsl:with-param name="parent" select="cib-ext:MissingPersonIncident/j:MissingPerson"/>
		</xsl:call-template>
		<xsl:call-template name="licensePlate_all" >
			<xsl:with-param name="parent" select="cib-ext:MissingPersonIncident/j:MissingPerson"/>
		</xsl:call-template>
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/> 
		<xsl:apply-templates select="cib-ext:MissingPersonIncident/j:MissingPerson" mode="alias"/>
		<xsl:call-template name="PersonWithInformation"/>
		<xsl:apply-templates select="." mode="record_details_all"/>
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>

	<!-- ###########################  -->
	<!-- The File Type Header	      -->
	<!-- ###########################  -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file. -->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:CautionIndicator = 'true'">
					<xsl:value-of select="concat($imageBase, 'flag.gif')"/>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if> 
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="fileLogoPicture">
		<xsl:choose>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:JuvenileIndicator = 'true'">
				<xsl:value-of select="concat($imageBase, 'missingJuvenile.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Missing Juvenile</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:OtherIndicator = 'true'">
				<xsl:value-of select="concat($imageBase, 'missingOther.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Mising Order</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:EmancipatedIndicator = 'true'">
				<xsl:value-of select="concat($imageBase, 'missingEmancipatedJuvenile.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Missing Emancipated Juvenile</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:EndangeredIndicator = 'true'">
				<xsl:value-of select="concat($imageBase, 'missingEndangered.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Missing Endangered</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:InvoluntaryIndicator = 'true'">
				<xsl:value-of select="concat($imageBase, 'missingInvoluntary.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Missing Involuntary</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:DisabilityIndicator = 'true'">
				<xsl:value-of select="concat($imageBase, 'missingDisability.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Missing Disability</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:DisasterCatastropheVictimIndicator = 'true'">
				<xsl:value-of select="concat($imageBase, 'missingCatastropheVictim.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Missing Catastrophe Victim</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:AdultIndicator = 'true'">
				<xsl:value-of select="concat($imageBase, 'missingAdult.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Missing Adult</xsl:text>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Subject Caution Text -->
		<xsl:apply-templates select="cib-ext:MissingPersonIncident/j:MissingPerson" mode="subject_caution_all"/>
		<!-- Missing Person Details-->	
		<br/>
		<table>
			<!-- Date of Last Contact :-->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Date of Last Contact:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates 
							select="cib-ext:MissingPersonIncident/j:MissingPerson/j:MissingPersonLastSeenDate" 
							mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width50percent'"/>
			</xsl:call-template>	
			<!-- Entering Agency -->
			<xsl:call-template name="EnteringAgency"/>
		</table>
	
	</xsl:template>
	
	<xsl:template match="j:MissingPerson" mode="PersonOtherInfo">
		<table>
			<!-- MNP and Blood Type -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'MNP:'"/>
				<xsl:with-param name="value1" select="j:MissingPersonDisappearanceTypeText"/>
				<xsl:with-param name="label_class_name1" select="'detaillabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Blood Type:'"/>
				<xsl:with-param name="value2" select="j:PersonBiometricDetails/j:PersonBloodTypeText"/> 
				<xsl:with-param name="label_class_name2" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>			
			</xsl:call-template>
			<!-- Fottprints and Body X-RAYS -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Footprints:'"/>
				<xsl:with-param name="value1">
					<xsl:if test="j:PersonBiometricDetails/j:PersonFootPrint/@j:commentText = 'available'">
						<xsl:text>Yes</xsl:text>
					</xsl:if>
					<xsl:if test="j:PersonBiometricDetails/j:PersonFootPrint/@j:commentText = 'unavailable'">
						<xsl:text>No</xsl:text>
					</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Body X-RAYS:'"/>
				<xsl:with-param name="value2" select="j:PersonBiometricDetails/j:PersonBodyXRaysAvailableText"/>
				<xsl:with-param name="label_class_name2" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>	 		
			</xsl:call-template>
		</table>
	</xsl:template>
		
	<xsl:template match="j:MissingPerson" mode="JewelryInfo">
		<table>
			<tr>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Jewelry Type:'"/>
					<xsl:with-param name="value1">
						<xsl:for-each select="cib-ext:Jewelry">
							<xsl:value-of select="cib-ext:JewelryTypeText"/>
							<xsl:if test="position() != last()">
								<xsl:text>,&#32;</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
				</xsl:call-template>
			</tr>
			<tr>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Jewelry Description:'"/>
					<xsl:with-param name="value1" select="j:PersonPhysicalDetails/j:PersonJewelryDescriptionText"/>
					<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
				</xsl:call-template>
			</tr>
		</table>
	</xsl:template>

</xsl:transform>