<?xml version="1.0"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/internal/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/internal/cib/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
	<xsl:import href="person_common.xsl"/>
	
	<!--  CIB - WANTED PERSON RECORD -->
	<!-- ############  -->
	<!-- main template -->
	<!-- ############  -->
	<xsl:template match="/doj:CIBResponseDocument"> 
		<xsl:call-template name="html_title"/>
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:value-of select="//cib-ext:RecordTypeText"/>
		<hr></hr>
	</xsl:template>
	
	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="//doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="j:CourtOrder/j:CourtOrderDesignatedSubject" mode="subject_details_all"/>
		<div>
		<!-- Entering Agency -->
			<xsl:call-template name="EnteringAgencyDetails">
				<xsl:with-param name="enteringAgencyDetails" select="cib-ext:EnteringAgencyDetails"></xsl:with-param>
			</xsl:call-template>
		</div>
		<xsl:apply-templates select="." mode="record_details"/>	 
	</xsl:template>
	
	<xsl:template name="fileLogoPicture">
		<xsl:if test="cib-ext:FileTypeDetails/cib-ext:LocatedIndicator = 'true'">
			<xsl:choose>
				<xsl:when test="cib-ext:FileTypeDetails/cib-ext:EmancipatedIndicator = 'true'  
					and cib-ext:FileTypeDetails/cib-ext:JuvenileIndicator = 'true'  
					and cib-ext:FileTypeDetails/cib-ext:AdjudgedIndicator = 'true'">
					<xsl:value-of select="concat($imageBase, 'locatedWantedEmancipatedJuvenileAdjudged.gif')"/>
					<xsl:text>-</xsl:text>
					<xsl:text>Located Emancipated Adjudged Juvenile</xsl:text>
				</xsl:when>
				<xsl:when test="cib-ext:FileTypeDetails/cib-ext:JuvenileIndicator = 'true' 
					and cib-ext:FileTypeDetails/cib-ext:AdjudgedIndicator = 'true'">
					<xsl:value-of select="concat($imageBase, 'locatedWantedJuvenileAdjudged.gif')"/>
					<xsl:text>-</xsl:text>
					<xsl:text>Located Adjudged Juvenile</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="not(cib-ext:FileTypeDetails/cib-ext:LocatedIndicator)">
			<xsl:choose>
				<xsl:when test="cib-ext:FileTypeDetails/cib-ext:EmancipatedIndicator = 'true' 
					and cib-ext:FileTypeDetails/cib-ext:JuvenileIndicator = 'true' 
					and cib-ext:FileTypeDetails/cib-ext:AdjudgedIndicator = 'true'">
					<xsl:value-of select="concat($imageBase, 'wantedEmancipatedJuvenileAdjudged.gif')"/>
					<xsl:text>-</xsl:text>
					<xsl:text>Emancipated Adjudged Juvenile</xsl:text>
				</xsl:when>
				<xsl:when test="cib-ext:FileTypeDetails/cib-ext:JuvenileIndicator = 'true' 
					and  cib-ext:FileTypeDetails/cib-ext:AdjudgedIndicator = 'true'">
					<xsl:value-of select="concat($imageBase, 'wantedJuvenileAdjudged.gif')"/>
					<xsl:text>-</xsl:text>
					<xsl:text>Adjudged Juvenile</xsl:text>
				</xsl:when>
				<xsl:when test="cib-ext:FileTypeDetails/cib-ext:TemporaryIndicator = 'true'">
					<xsl:value-of select="concat($imageBase, 'wantedTemporary.gif')"/>
					<xsl:text>-</xsl:text>
					<xsl:text>Temporary</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Court Order Details-->	
		<table style="width:70%">
			<!-- Court order status and case No-->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Status:'"/>
				<xsl:with-param name="value1" select="j:CourtOrder/j:ActivityStatus/j:StatusText"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width20percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Court Case No:'"/>
				<xsl:with-param name="value2">
					<xsl:value-of select="j:CourtOrder/j:CaseDocketID/j:ID"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'basiclabel width20percent'"/>
				<xsl:with-param name="value_class_name2" select="'basicvalue width25percent'"/>
			</xsl:call-template>
			<!-- Court Name -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'CourtName :'"/>
				<xsl:with-param name="value1">
					<xsl:value-of select="j:CourtOrder/j:CourtOrderIssuingCourt/j:OrganizationName"/>
				</xsl:with-param> 
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width20percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width25percent'"/>
			</xsl:call-template>
			<!-- Restriction Begin and End Dates -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Restriction Begin Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:CourtOrder/j:CourtOrderIssuingDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width20percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Restriction End Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="j:CourtOrder/j:CourtOrderIssuingDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width20percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Offense Date and Form Date -->   
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Offense Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:CourtOrder/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width20percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Form Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="j:CourtOrder/j:ActivityDocket/j:DocumentDescriptiveMetadata/j:DocumentFiledDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width20percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Submitted By Name -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Form Submitted By Name:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:CourtOrder/j:ActivityDocket/j:DocumentDescriptiveMetadata/j:DocumentSubmitter.Person/j:PersonName"></xsl:apply-templates>
				</xsl:with-param> 
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width20percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="record_details">
		<table>
			<!-- Warrant Number and Warrant Date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Warrant Number:'"/>
				<xsl:with-param name="value1" select="j:ArrestWarrant/j:ActivityID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/> 
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Warrant Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="j:ArrestWarrant/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Court ORI -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Court ORI:'"/>
				<xsl:with-param name="value1" select="j:ArrestWarrant/j:CourtOrderIssuingCourt/j:OrganizationORIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template> 
	
</xsl:stylesheet>