<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
    <!--  NCIC - ARTICLE RECORD -->
	<xsl:import href="ncic_common.xsl"/>
	
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:NCICResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - NCIC Article</xsl:text>
	</xsl:template>
	
	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="cib-ext:SingleArticleIncident"/>  
		<xsl:apply-templates select="cib-ext:GroupArticlesIncident"/> 
		<xsl:apply-templates select="." mode="property_details_all"/>
		<xsl:apply-templates select="cib-ext:MiscellaneousText"  mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />
		<xsl:apply-templates select="." mode="record_details_all"/>
		<xsl:apply-templates select="cib-ext:SingleArticleIncident/cib-ext:SingleArticleDetails | cib-ext:GroupArticlesIncident/cib-ext:GroupArticlesDetails" mode="record_details"/>	
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.-->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="fileLogoPicture">
		<xsl:choose>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:LostIndicator = 'true'">   
				<xsl:text>../../images/lostArticle.gif</xsl:text> 
				<xsl:text>-</xsl:text>
				<xsl:text>Lost Article</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>../../images/stolenArticle.gif</xsl:text> 
				<xsl:text>-</xsl:text>
				<xsl:text>Stolen Article</xsl:text>
			</xsl:otherwise>								
		</xsl:choose>
	</xsl:template>

	<!-- Details about a stolen article	-->
	<xsl:template match="cib-ext:SingleArticleIncident | cib-ext:GroupArticlesIncident">
		<table>
			<tr>
				<td class="width10percent">
					<a href="#recorddetails{$responseId}"><img src="../../images/RecordDetails.jpg" alt="Record Details"/></a>
				</td>
				<td class="width90percent">
					<xsl:apply-templates select="cib-ext:SingleArticleDetails"/>
					<xsl:apply-templates select="cib-ext:GroupArticlesDetails"/>
				</td>
			</tr>
		</table>
		<br/>
	</xsl:template>
	
	<!-- Details about a stolen part ..	-->
	<xsl:template match="cib-ext:SingleArticleDetails | cib-ext:GroupArticlesDetails">
		<span class="propertyinfo">
			<!-- Property Detail Text  -->
			<xsl:value-of select="j:PropertyPhysicalDetails/j:PropertyDetail/j:PropertyDetailText"/>
			<xsl:text>;&#160;</xsl:text>
			<!-- Property Brand Name -->
			<xsl:value-of select="j:PropertyPhysicalDetails/j:PropertyBrandName"/>
			<!-- Property Model Name -->
			<xsl:if test="j:PropertyPhysicalDetails/j:PropertyModelName">
				<xsl:text>;&#160;</xsl:text>
				<xsl:value-of select="j:PropertyPhysicalDetails/j:PropertyModelName"/>
			</xsl:if>
			<br/>
			<!-- Serial # -->
			<xsl:apply-templates select="j:PropertyAssignedIDDetails"/>
			<xsl:apply-templates select="cib-ext:PropertyAssignedIDDetails"/>
		</span>
	</xsl:template>
	
	<!--  single article serial # -->
	<xsl:template match="j:PropertyAssignedIDDetails">
		<!-- Serial ID -->
		<xsl:if test="j:PropertySerialID/j:ID">
			<xsl:text>Serial&#160;#&#160;</xsl:text>
			<xsl:value-of select="j:PropertySerialID/j:ID"/>
			<xsl:if test="j:PropertyOwnerAppliedID"> 
				<xsl:text>;&#160;</xsl:text>
			</xsl:if>	
		</xsl:if>
		<!-- Owner Applied ID -->
		<xsl:if test="j:PropertyOwnerAppliedID"> 
			<xsl:text>OAN:&#160;</xsl:text>
			<xsl:value-of select="j:PropertyOwnerAppliedID/j:ID" />
		</xsl:if>	
	</xsl:template>
	
	<!-- group article serial # -->
	<xsl:template match="cib-ext:PropertyAssignedIDDetails">
		<!-- Serial ID -->
		<xsl:if test="cib-ext:PropertyBeginingSerialID or cib-ext:PropertyEndingSerialID">
			<xsl:text>Serial&#160;#&#160;</xsl:text>
			<xsl:value-of select="cib-ext:PropertyBeginingSerialID/j:ID"/>
			<xsl:text>&#160;-&#160;</xsl:text>
			<xsl:value-of select="cib-ext:PropertyEndingSerialID/j:ID"/>
			<xsl:if test="j:PropertyOwnerAppliedID"> 
				<xsl:text>;&#160;</xsl:text>
			</xsl:if>	
		</xsl:if>
		<!-- Owner Applied ID -->
		<xsl:if test="j:PropertyOwnerAppliedID"> 
			<xsl:text>OAN:&#160;</xsl:text>
			<xsl:value-of select="j:PropertyOwnerAppliedID/j:ID" />
		</xsl:if>	
	</xsl:template>

	<xsl:template match="cib-ext:SingleArticleDetails | cib-ext:GroupArticlesDetails" mode="record_details"> 
		<table>
			<!-- Lot Number and Harz Material Container -->
			<xsl:call-template name="ConditionalRow">
				<!-- Lot Number -->
				<xsl:with-param name="label1" select="'Lot Number:'"/>
				<xsl:with-param name="value1">
					<xsl:choose>
						<xsl:when test="cib-ext:PropertyAssignedIDDetails/j:PropertyOtherID"> 
							<xsl:value-of select="cib-ext:PropertyAssignedIDDetails/j:PropertyOtherID/j:ID"/>
						</xsl:when>
						<xsl:when test="j:PropertyAssignedIDDetails/j:PropertyOtherID"> 
							<xsl:value-of select="j:PropertyAssignedIDDetails/j:PropertyOtherID/j:ID"/>
						</xsl:when>
					</xsl:choose>	
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<!-- Hazmat Container Text -->
				<xsl:with-param name="label2" select="'Haz Material Container:'"/>
				<xsl:with-param name="value2" select="cib-ext:HazMatContainerDescriptionText"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Partial Lot Indicator and United Nations Number -->
			<xsl:call-template name="ConditionalRow">
				<!-- Partial Lot Indicator -->
				<xsl:with-param name="label1" select="'Partial Lot Indicator:'"/>
				<xsl:with-param name="value1" select="cib-ext:PropertyPartialLotText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<!-- United Nations Number -->
				<xsl:with-param name="label2" select="'United Nations Number:'"/>
				<xsl:with-param name="value2" select="cib-ext:PropertyAssignedIDDetails/j:PropertyFederalID/j:ID"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
</xsl:transform>