<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
    <!--  NCIC - STOLEN SECURITY RECORD -->
	<xsl:import href="ncic_common.xsl"/>
	
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:NCICResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - NCIC Stolen Security</xsl:text>
	</xsl:template>
	
	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="cib-ext:GroupSecuritiesIncident"/> 
		<xsl:apply-templates select="cib-ext:SingleSecurityIncident"/> 
		<xsl:apply-templates select="." mode="property_details_all"/>
		<xsl:apply-templates select="cib-ext:MiscellaneousText"  mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />
		<xsl:apply-templates select="." mode="record_details_all"/>
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.-->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="fileLogoPicture">
		<xsl:text>../../images/stolenSecurity.gif</xsl:text>
		<xsl:text>-</xsl:text>
		<xsl:text>Stolen Security</xsl:text>
	</xsl:template>

	<!-- Details about a stolen security -->
	<xsl:template match="cib-ext:SingleSecurityIncident | cib-ext:GroupSecuritiesIncident">
		<table>
			<tr>
				<td class="width10percent">
					<a href="#recorddetails{$responseId}"><img src="../../images/RecordDetails.jpg" alt="Record Details"/></a>
				</td>
				<td class="width90percent">
					<xsl:apply-templates select="cib-ext:SingleSecurityDetails"/>
					<xsl:apply-templates select="cib-ext:GroupSecuritiesDetails"/>
				</td>
			</tr>
		</table>
		<br/>
	</xsl:template>
	
	<!-- Details about a stolen security --> 
	<xsl:template match="cib-ext:SingleSecurityDetails | cib-ext:GroupSecuritiesDetails">
		<span class="propertyinfo">
			<!-- Security Type -->
			<xsl:value-of select="cib-ext:SecurityTypeText"/>
			<!-- Issuer -->
			<xsl:text>;&#32;Issuer&#160;</xsl:text>
			<xsl:value-of select="j:SecurityIssuer.Organization/j:OrganizationName"/>
			<br/>
			<xsl:if test="cib-ext:PropertyOwner/cib-ext:OwnerName">
				<xsl:text>Owner&#160;</xsl:text>
				<xsl:value-of select="cib-ext:PropertyOwner/cib-ext:OwnerName"/>
				<xsl:if test="cib-ext:PropertyOwner/j:PersonSSNID/j:ID">
					<xsl:text>&#160;-&#160;SOC:&#160;</xsl:text>
					<xsl:value-of select="cib-ext:PropertyOwner/j:PersonSSNID/j:ID"/>
				</xsl:if>
			</xsl:if>
			<!-- Denomination Text -->
			<xsl:if test="j:SecurityDenominationText">
				<xsl:text>;&#32;Denomination&#160;</xsl:text>
				<xsl:value-of select="j:SecurityDenominationText" />
			</xsl:if>
			<br/>
			<!-- Serial # --> 
			<xsl:text>Serial&#160;#&#160;</xsl:text>
			<xsl:apply-templates select="j:PropertyAssignedIDDetails"/>
			<xsl:apply-templates select="cib-ext:PropertyAssignedIDDetails"/>
			<!-- Date Series -->
			<xsl:if test="j:SecurityDateSeriesText">
				<br/>
				<xsl:text>Security&#160;Date&#160;</xsl:text>
				<xsl:value-of select="j:SecurityDateSeriesText" />
			</xsl:if>
			<!-- Ransom Money -->
			<xsl:if test="cib-ext:RansomMoneyTypeText">
				<br/>
				<xsl:text>Money&#160;Indicator&#160;</xsl:text>
				<xsl:value-of select="cib-ext:RansomMoneyTypeText" />
			</xsl:if>
		</span>
	</xsl:template>
	
	<!--  single security -->
	<xsl:template match="j:PropertyAssignedIDDetails">
		<xsl:value-of select="j:PropertySerialID/j:ID"/>
	</xsl:template>
	
	<!-- group security -->
	<xsl:template match="cib-ext:PropertyAssignedIDDetails">
		<xsl:value-of select="cib-ext:PropertyBeginingSerialID/j:ID"/>
		<xsl:text>&#160;-&#160;</xsl:text>
		<xsl:value-of select="cib-ext:PropertyEndingSerialID/j:ID"/>
	</xsl:template>
</xsl:transform>