<?xml version="1.0"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
	<xsl:import href="person_common.xsl"/>
	
	<!--  NCIC - VIOLENT GANG RECORD / POSSIBLE TERRORIST --> 
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	
	<xsl:template match="/doj:NCICResponseDocument">  
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName"> 
				<xsl:choose>
					<xsl:when test="doj:Result/doj:ViolentGangResponse/doj:InquiryResult/cib-ext:GroupMemberDetails">
						<xsl:choose>
							<xsl:when test="doj:Result/doj:ViolentGangResponse/doj:InquiryResult/cib-ext:FileTypeDetails/cib-ext:TerroristIndicator = 'true'">
								<xsl:text>TIME - NCIC Known or Suspected Terrorist</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>TIME - NCIC Gang Member</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>TIME - NCIC Gang Organization</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:choose>
			<xsl:when test="doj:ViolentGangResponse/doj:InquiryResult/cib-ext:GroupMemberDetails">
				<xsl:choose>
					<xsl:when test="doj:ViolentGangResponse/doj:InquiryResult/cib-ext:FileTypeDetails/cib-ext:TerroristIndicator = 'true'">
						<xsl:text>TIME - NCIC Known or Suspected Terrorist</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>TIME - NCIC Gang Member</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>TIME - NCIC Gang Organization</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	 
	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:if test="cib-ext:GroupMemberDetails">
			<xsl:apply-templates select="cib-ext:GroupMemberDetails" mode="subject_details_all"/>
			<xsl:apply-templates select="cib-ext:GroupMemberDetails" mode="FBItoSMT"/>
			<xsl:apply-templates select="cib-ext:GroupMemberDetails" mode="DLtoDNALoc"/>
			<xsl:call-template name="vehicle_all">
				<xsl:with-param name="parent" select="cib-ext:GroupMemberDetails"/>
			</xsl:call-template>
			<xsl:call-template name="licensePlate_all" >
				<xsl:with-param name="parent" select="cib-ext:GroupMemberDetails"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="cib-ext:GroupMemberDetails" mode="alias"/>
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />
		<xsl:apply-templates select="." mode="record_details_all"/>
		<xsl:apply-templates select="." mode="record_details"/>	 	 
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>
	
	<!-- ################# -->
	<!-- File Type Header  -->
	<!-- ################# -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.  -->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:CautionIndicator = 'true'">
					<xsl:value-of select="concat($imageBase, 'flag.gif')"/>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="fileLogoPicture">
		<xsl:choose>
			<xsl:when test="cib-ext:GroupMemberDetails">
				<xsl:choose>
					<xsl:when test="cib-ext:FileTypeDetails/cib-ext:TerroristIndicator = 'true'">
						<xsl:value-of select="concat($imageBase, 'terroristMember.gif')"/>
						<xsl:text>-</xsl:text>
						<xsl:text>Known or Suspected Terrorist</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="concat($imageBase, 'gangMember.gif')"/>
						<xsl:text>-</xsl:text>
						<xsl:text>Gang Member</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="concat($imageBase, 'gangOrganization.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Gang Organization</xsl:text>
			</xsl:otherwise>								
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Caution Text -->
		<xsl:apply-templates select="cib-ext:GroupMemberDetails" mode="subject_caution_all"/>
		<xsl:apply-templates select="cib-ext:GroupOrganizationDetails" mode="subject_caution_all"/>
		<!-- Record Details-->	
		<br/>
		<table>
			<!--  Organization Name -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Organization Name:'"/>
				<xsl:with-param name="value1">
					<!-- group organization name -->
					<xsl:value-of select="cib-ext:GroupOrganizationDetails/j:OrganizationName"/>
					<!-- member organization name -->
					<xsl:value-of select="cib-ext:GroupMemberDetails/j:SubjectInvolvementCriminalOrganization/j:OrganizationName"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>	
			<!--  Subgroup -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Subgroup:'"/>
				<xsl:with-param name="value1">
					<!-- group subunit name -->
					<xsl:value-of select="cib-ext:GroupOrganizationDetails/j:OrganizationUnitName"/>
					<!-- member subunit name -->
					<xsl:value-of select="cib-ext:GroupMemberDetails/j:SubjectInvolvementCriminalOrganization/j:OrganizationUnitName"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>	
			<!-- Entering Agency -->
			<xsl:call-template name="EnteringAgency"/>	 
		</table>
	</xsl:template>	
	
	<xsl:template match="doj:InquiryResult" mode="record_details">
		<table>
			<!-- Entry Criteria -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Entry Criteria:'"/>
				<xsl:with-param name="value1">
				 <xsl:apply-templates select="cib-ext:GroupMemberDetails/cib-ext:SubjectCriminalOrganizationInvolvement/cib-ext:SubjectCriminalOrganizationInvolvementText"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
	<xsl:template match="cib-ext:SubjectCriminalOrganizationInvolvementText">
		<xsl:value-of select="." />
		<xsl:text>&#160;</xsl:text>
	</xsl:template>
</xsl:stylesheet>